@@ -30,8 +30,9 @@
 
 G_BEGIN_DECLS
 
-const gchar *kz_actions_download_open_save_dialog (const gchar *uri,
-						   gboolean content);
+gchar *kz_actions_download_open_save_dialog (GtkWindow *window,
+    					     const gchar *uri,
+					     gboolean content);
 
 G_END_DECLS
 
