@@ -76,16 +76,21 @@ act_save (GtkAction *action, KzWindow *kz)
 {
 	GtkWidget *widget = KZ_WINDOW_CURRENT_PAGE(kz);
 	KzEmbed *kzembed;
-	const gchar *filename;
+	gchar *filename;
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 	g_return_if_fail(KZ_IS_EMBED(widget));
 	
 	kzembed = KZ_EMBED(widget);
 	
-	filename = kz_actions_download_open_save_dialog(kz_embed_get_location(kzembed), TRUE);
+	filename = kz_actions_download_open_save_dialog(GTK_WINDOW(kz),
+	    						kz_embed_get_location(kzembed),
+							TRUE);
 	if (filename)
+	{
 		kz_embed_save_with_content(kzembed, filename);
+		g_free(filename);
+	}	
 }
 
 
@@ -140,7 +145,7 @@ idle_focus_to_loc_ent(gpointer data)
 	action = gtk_action_group_get_action(kz->actions,"FocusLocationEntry");
 
 	gtk_action_activate(action);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(kz),
+	g_signal_handlers_disconnect_by_func(kz,
 					     G_CALLBACK(cb_remove_idle), NULL);
 	return FALSE;
 }
@@ -167,7 +172,7 @@ act_new_tab (GtkAction *action, KzWindow *kz)
 		if(focus)
 		{
 			g_idle_add(idle_focus_to_loc_ent, kz);
-			g_signal_connect(G_OBJECT(kz), "destroy",
+			g_signal_connect(kz, "destroy",
 					 G_CALLBACK(cb_remove_idle), NULL);
 		}
 	}
@@ -208,30 +213,47 @@ act_clear_loc_ent (GtkAction *action, KzWindow *kz)
 static void
 act_open_file (GtkAction *action, KzWindow *kz)
 {
-	GtkFileSelection *file_selector;
-	const gchar *filename = NULL;
+	GtkWidget *file_dialog;
+	gchar *filename = NULL;
 	gchar *uri = NULL;
 	gint result;
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	file_selector = GTK_FILE_SELECTION(gtk_file_selection_new ("Open file"));
-	file_selector = GTK_FILE_SELECTION(gtk_file_selection_new ("Open file"));
+	file_dialog = gtk_file_chooser_dialog_new (_("Open file"),
+						   GTK_WINDOW(kz),
+						   GTK_FILE_CHOOSER_ACTION_OPEN,
+						   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						   GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+						   NULL);
 
-	result = gtk_dialog_run(GTK_DIALOG(file_selector));
+	result = gtk_dialog_run(GTK_DIALOG(file_dialog));
 	
 	switch (result)
 	{
-	 case GTK_RESPONSE_OK:
-		filename = gtk_file_selection_get_filename(file_selector);
+	 case GTK_RESPONSE_ACCEPT:
+		filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_dialog));
 		break;
 	 default:
 		break;
 	}
-	if (filename)
-		uri = g_strdup_printf("file://%s", filename);
 
-	gtk_widget_destroy(GTK_WIDGET(file_selector));
+	if (filename)
+        {
+		gchar *utf8, *urlencode, *dirname, *basename;
+		basename = g_path_get_basename(filename);
+		dirname = g_path_get_dirname(filename);
+		utf8 = g_filename_to_utf8 (basename, -1, NULL, NULL, NULL);
+		urlencode = url_encode(utf8);
+		uri = g_strdup_printf("file://%s/%s", dirname, urlencode);
+                g_free(utf8);
+                g_free(basename);
+                g_free(dirname);
+		g_free(urlencode);
+		g_free(filename);
+        }
+
+	gtk_widget_destroy(file_dialog);
 
 	if (uri)
 	{
@@ -595,7 +617,6 @@ act_find (GtkAction *action, KzWindow *kz)
 	gtk_widget_grab_focus(kz->find_area);
 }
 
-
 static void
 act_prev_tab (GtkAction *action, KzWindow *kz)
 {
@@ -1224,7 +1245,7 @@ act_clip_selection (GtkAction *action, KzWindow *kz)
 	time_t t;
 	gchar time_string[20];
 	gchar *filename, *htmlname = NULL, *dirname, *link, *name;
-	gchar *pos;
+	gchar *pos, *full_htmlname;
 	GIOChannel *io;
 
 	if (!KZ_IS_WINDOW(kz)) return;
@@ -1258,19 +1279,19 @@ act_clip_selection (GtkAction *action, KzWindow *kz)
 		htmlname = g_strdup(name);
 	g_free(name);
 
+	full_htmlname = g_strconcat(htmlname, ".html", NULL);
+
 	dirname = g_strconcat("clips/", htmlname, time_string, NULL);
 	make_dir(dirname);
 
 	source  = kz_embed_get_html_with_contents(KZ_EMBED(embed),
 						  dirname);
 
-	filename = g_strconcat(g_get_home_dir(),
-			       "/.kazehakase/",
-			       dirname,
-			       "/",
-			       htmlname,
-			       ".html",
-			       NULL);
+	filename = g_build_filename(g_get_home_dir(),
+				    "."PACKAGE,
+				    dirname,
+				    full_htmlname,
+			       	    NULL);
 	
 	/* save */
 	io = g_io_channel_new_file(filename, "w", NULL);
@@ -1295,6 +1316,7 @@ act_clip_selection (GtkAction *action, KzWindow *kz)
 	g_free(filename);
 	g_free(dirname);
 	g_free(htmlname);
+	g_free(full_htmlname);
 }
 
 static void
@@ -1351,7 +1373,7 @@ act_restore_session (GtkAction *action, KzWindow *kz)
 
 	/* reload from current session file */
 	current_session  = g_build_filename(g_get_home_dir(),
-					    ".kazehakase",
+					    "."PACKAGE,
 					    "current_session.xml",
 					     NULL);
 	if (!g_file_test(current_session, G_FILE_TEST_EXISTS))
@@ -1712,7 +1734,7 @@ act_thumbnail_tablist (GtkAction *action, KzWindow *kz)
 		kz->popup_tablist = kz_popup_tablist_new(kz);
 
 	proxy = kz_proxy_folder_new(kz->tabs);
-	g_signal_connect(G_OBJECT(kz->popup_tablist), "selected",
+	g_signal_connect(kz->popup_tablist, "selected",
 			 G_CALLBACK(cb_thumbnail_tablist_selected), kz);
 /* to keep KzPopupTablist from adhering to KzWindow, I can't pass KzWindow to KzPopupTablist directly... */
 	kz_popup_tablist_show(KZ_POPUP_TABLIST(kz->popup_tablist), proxy);
@@ -1750,6 +1772,56 @@ act_toggle_proxy_use (GtkAction *action, KzWindow *kz)
 }
 
 
+static void
+act_show_hide_bookmarkbars (GtkAction *action, KzWindow *kz)
+{
+	gboolean active;
+	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+	g_return_if_fail(GTK_IS_WIDGET(kz->bookmark_bars_area));
+
+	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
+	if (active)
+		gtk_widget_show(kz->bookmark_bars_area);
+	else
+		gtk_widget_hide(kz->bookmark_bars_area);
+}
+
+static void
+act_view_fullscreen (GtkAction *action, KzWindow *kz)
+{
+	gboolean active;
+	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
+	if (active)
+	{
+		gtk_window_fullscreen(GTK_WINDOW(kz));
+		gtk_widget_hide(kz->bookmark_bars_area);
+		gtk_widget_hide(kz->statusbar_area);
+		gtk_widget_hide(kz->menu_box);
+		gtk_notebook_set_show_tabs(GTK_NOTEBOOK(kz->notebook), FALSE);
+	
+	}
+	else
+	{
+		GtkAction *toggle_action;
+		gboolean toggle_active;
+
+		gtk_window_unfullscreen(GTK_WINDOW(kz));
+		gtk_widget_show(kz->statusbar_area);
+		gtk_widget_show(kz->menu_box);
+		gtk_notebook_set_show_tabs(GTK_NOTEBOOK(kz->notebook), TRUE);
+		
+		toggle_action = gtk_action_group_get_action(kz->actions,
+						     	    "ShowHideBookmarkbars");
+		toggle_active = gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(toggle_action));
+		if (toggle_active)
+			gtk_widget_show(kz->bookmark_bars_area);
+	}
+}
+
 #define CTRL "<control>"
 #define SHFT "<shift>"
 #define SFCT "<shift><control>"
@@ -1885,7 +1957,9 @@ const gint kz_actions_len = G_N_ELEMENTS(kz_actions);
 static GtkToggleActionEntry kz_toggle_actions[] =
 {
   {"ShowHideSidebar", NULL, N_("Sidebar"),          NULL, NULL, G_CALLBACK(act_show_hide_sidebar)},
+  {"ShowHideBookmarkbars", NULL, N_("Bookmarkbar"), NULL, NULL, G_CALLBACK(act_show_hide_bookmarkbars)},
   {"ToggleProxyUse",  NULL, N_("Toggle Proxy Use"), NULL, NULL, G_CALLBACK(act_toggle_proxy_use)}, 
+  {"ToggleFullScreen",NULL, N_("Toggle Full Screen Mode"), "F11", NULL, G_CALLBACK(act_view_fullscreen)}, 
 };
 static const gint kz_toggle_actions_len = G_N_ELEMENTS(kz_toggle_actions);
 
@@ -2010,15 +2084,15 @@ combine_favicon(GtkAction *action, const gchar *uri, KzWindow *kz)
 			favicon = kz_favicon_get_pixbuf(kzfav, uri,
 							GTK_ICON_SIZE_BUTTON);
 			image = gtk_image_new();
+			gtk_tool_button_set_icon_widget(GTK_TOOL_BUTTON(widget),
+							image);
+			gtk_widget_show(image);
 			g_object_get(G_OBJECT(action),
 				     "stock_id", &stock_id,
 				     NULL);
 			gtkutil_superpose_pixbuf(image, favicon,
 						 stock_id,
 						 GTK_ICON_SIZE_BUTTON);
-			gtk_tool_button_set_icon_widget(GTK_TOOL_BUTTON(widget),
-							image);
-			gtk_widget_show(image);
 			g_free(stock_id);
 		}
 		if (favicon)
@@ -2266,6 +2340,8 @@ kz_actions_set_sensitive (KzWindow *kz, KzEmbed *kzembed)
 		kz_stop_reload_action_set_state(
 			KZ_STOP_RELOAD_ACTION(action),
 			state);
+		/* enable tab actions */
+		gtk_action_group_set_sensitive (kz->tabpop_actions, TRUE);
 	}
 	else
 	{
@@ -2292,6 +2368,8 @@ kz_actions_set_sensitive (KzWindow *kz, KzEmbed *kzembed)
 		kz_stop_reload_action_set_state(
 			KZ_STOP_RELOAD_ACTION(action),
 			KZ_STOP_RELOAD_ACTION_STATE_RELOAD);
+		/* disable tab actions */
+		gtk_action_group_set_sensitive (kz->tabpop_actions, FALSE);
 	}
 
 	kz_actions_set_selection_sensitive (kz, kzembed);
@@ -2443,13 +2521,13 @@ kz_actions_popup_bookmark_menu_modal (KzWindow *kz, KzBookmark *bookmark,
 					       "/BookmarkPopup");
 	if (!popup_menu) return;
 
-	g_signal_connect(G_OBJECT(popup_menu), "hide",
+	g_signal_connect(popup_menu, "hide",
 			 G_CALLBACK(cb_popup_menu_hide), NULL);
 	set_popup_menu_sensitive (kz, bookmark);
 	gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL,
 		       NULL, NULL, button, time);
 	gtk_main();
-	g_signal_handlers_disconnect_by_func(G_OBJECT(popup_menu),
+	g_signal_handlers_disconnect_by_func(popup_menu,
 					     G_CALLBACK(cb_popup_menu_hide),
 					     NULL);
 
@@ -2565,7 +2643,6 @@ kz_actions_update_smartbookmarks (KzWindow *kz, KzBookmark *bookmark)
 		GtkAction *action, *new_action = NULL;
 		KzBookmark *child= node->data;
 
-
 		if (!KZ_IS_SMART_BOOKMARK(child) &&
 	    	    !kz_bookmark_is_folder(child)) continue;
 		
@@ -2638,7 +2715,7 @@ void
 kz_actions_remove_smartbookmarks (KzWindow *kz, KzBookmark *bookmark)
 {
 	GList *children, *node;
-	
+
 	children = kz_bookmark_get_children(bookmark);
 	for (node = children; node; node = g_list_next(node))
 	{
@@ -2647,39 +2724,52 @@ kz_actions_remove_smartbookmarks (KzWindow *kz, KzBookmark *bookmark)
 		gchar *action_name;
 		const gchar *title;
 		GtkAction *action;
+		GSList *p_node, *proxies;
 		KzBookmark *child= node->data;
 
-
 		if (!KZ_IS_SMART_BOOKMARK(child) &&
 	    	    !kz_bookmark_is_folder(child)) continue;
 		
 		title = kz_bookmark_get_title(child);
-	 
+		if (title && !strncmp(title, "LocationEntry", 13))
+			action_name = g_strdup("LocationEntry");
+		else
+			action_name = g_strdup_printf("SmartBookmark:%p", child);
+
+		action = gtk_action_group_get_action(kz->actions,
+						     action_name);
+                if (!action) continue;
+
+		proxies = gtk_action_get_proxies(action);
+                if (proxies)
+		{
+			GSList *copy;
+	                /* disconenct proxy explicitly */
+	                copy = g_slist_copy(proxies);
+			for (p_node = copy; p_node; p_node = g_slist_next(p_node))
+			{
+				if (p_node->data && GTK_IS_WIDGET(p_node->data))
+        	                {
+                	                gtk_action_disconnect_proxy(action, GTK_WIDGET(p_node->data));
+	                        }
+        	        }
+	                g_slist_free(copy);
+		}
+
 		if (title && !strncmp(title, "LocationEntry", 13))
 		{
-			action = gtk_action_group_get_action(kz->actions,
-							     "LocationEntry");
-			kz_location_entry_action_set_bookmark(
-				KZ_LOCATION_ENTRY_ACTION(action),
-				child);
+			g_free(action_name);
 			continue;
 		}
 		
-		action_name = g_strdup_printf("SmartBookmark:%p", child);
-
 		/* remove old one */
-		action = gtk_action_group_get_action(kz->actions,
-						     action_name);
-		if (action)
+		p = g_object_get_data(G_OBJECT(action),
+				      action_name);
+		if (p)
 		{
-			p = g_object_get_data(G_OBJECT(action),
-					      action_name);
-			if (p)
-			{
-				id = GPOINTER_TO_UINT(p);
-				gtk_ui_manager_remove_ui(kz->menu_merge,
-							 id);
-			}
+			id = GPOINTER_TO_UINT(p);
+			gtk_ui_manager_remove_ui(kz->menu_merge,
+						 id);
 		}
 		
 		g_free(action_name);
