@@ -251,7 +251,7 @@ kz_history_action_activate (GtkAction *action)
 		}
 	}
 
-	g_signal_emit(G_OBJECT(action),
+	g_signal_emit(action,
 		      history_action_signals[HISTORY_CHANGED_SIGNAL], 0);
 
 	/* not needed */
@@ -260,6 +260,7 @@ kz_history_action_activate (GtkAction *action)
 }
 
 
+#if 0
 static gboolean
 cb_menu_item_combo_button_press (GtkWidget *widget)
 {
@@ -293,7 +294,7 @@ cb_menu_item_combo_leave (GtkWidget *widget, GdkEventCrossing *event)
 
 	return TRUE;
 }
-
+#endif
 
 static gboolean
 cb_match_selected (GtkEntryCompletion *completion,
@@ -350,9 +351,7 @@ completion_func (GtkEntryCompletion *completion,
 	{
 #if USE_MIGEMO
 		gboolean use_migemo;
-#endif /* USE_MIGEMO */
 
-#if USE_MIGEMO
 		KZ_CONF_GET("Global", "use_migemo", use_migemo, BOOL);
 		if (use_migemo)
 		{
@@ -420,19 +419,20 @@ kz_history_action_create_menu_item (GtkAction *action)
 				COLUMN_URI);
 	gtk_widget_show(combo);
 	gtk_container_add(GTK_CONTAINER(widget), combo);
-
-	g_signal_connect_after(G_OBJECT(widget), "button-press-event",
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
+#if 0
+	g_signal_connect_after(widget, "button-press-event",
 			       G_CALLBACK(cb_menu_item_combo_button_press),
 			       NULL);
-	g_signal_connect_after(G_OBJECT(widget), "button-release-event",
+	g_signal_connect_after(widget, "button-release-event",
 			       G_CALLBACK(cb_menu_item_combo_button_release),
 			       NULL);
 
-	g_signal_connect(G_OBJECT(widget), "enter-notify-event",
+	g_signal_connect(widget, "enter-notify-event",
 			 G_CALLBACK(cb_menu_item_combo_enter), NULL);
-	g_signal_connect(G_OBJECT(widget), "leave-notify-event",
+	g_signal_connect(widget, "leave-notify-event",
 			 G_CALLBACK(cb_menu_item_combo_leave), NULL);
-
+#endif
 	return widget;
 }
 
@@ -534,7 +534,7 @@ kz_history_action_real_set_history (KzHistoryAction *action, GList *list)
 		}
 	}
 
-	g_signal_emit(G_OBJECT(action),
+	g_signal_emit(action,
 		      history_action_signals[HISTORY_CHANGED_SIGNAL], 0);
 }
 
@@ -632,7 +632,7 @@ kz_history_unset_completion (KzHistoryAction *action,
 
 	gtk_entry_completion_set_model (action->completion, NULL);
 	g_signal_handlers_disconnect_by_func
-			(G_OBJECT(action->completion),
+			(action->completion,
 			 G_CALLBACK(cb_match_selected),
 			 entry);
 
