@@ -34,6 +34,8 @@
 #include "kz-smart-bookmark.h"
 #include "kz-actions.h"
 
+#define KZ_LOCATION_ENTRY_ACTION_KEY "KzLocationEntryAction::Action"
+
 enum {
 	PROP_0,
 	PROP_KZ_WINDOW,
@@ -67,7 +69,11 @@ static void     cb_entry_populate_popup         	 (GtkEntry *entry,
 						   	  GtkMenu *menu,
 	  			    	 	   	  KzLocationEntryAction *action);
 
-
+static void     cb_profile_entry_changed     (KzProfile       *profile,
+					       const gchar     *section,
+					       const gchar     *key,
+					       const gchar     *old_value,
+					       GtkEntry        *entry);
 static KzHistoryActionClass *parent_class = NULL;
 
 
@@ -259,10 +265,15 @@ kz_location_entry_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
 		if(autocompletion)
 			kz_history_set_completion (KZ_HISTORY_ACTION(action), entry);
 
-		g_signal_connect(G_OBJECT(entry), "key-press-event",
+		g_object_set_data(G_OBJECT(entry),
+				  KZ_LOCATION_ENTRY_ACTION_KEY,
+				  action);
+		g_signal_connect(entry, "key-press-event",
 				 G_CALLBACK(cb_entry_key_press), action);
-		g_signal_connect(G_OBJECT(entry), "populate-popup",
+		g_signal_connect(entry, "populate-popup",
 				 G_CALLBACK(cb_entry_populate_popup), action);
+		g_signal_connect(kz_global_profile, "changed::Entry",
+				 G_CALLBACK(cb_profile_entry_changed), entry);
 	}
 }
 
@@ -276,13 +287,20 @@ kz_location_entry_action_disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 	if (entry)
 	{
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(entry),
+			(entry,
 			 G_CALLBACK(cb_entry_key_press),
 			 action);
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(entry),
+			(entry,
 			 G_CALLBACK(cb_entry_populate_popup),
 			 action);
+		g_signal_handlers_disconnect_by_func
+			(kz_global_profile,
+			 G_CALLBACK(cb_profile_entry_changed),
+			 entry);
+	        g_object_set_data(G_OBJECT(entry),
+		        	  KZ_LOCATION_ENTRY_ACTION_KEY,
+			          NULL);
 	}
 
 	GTK_ACTION_CLASS (parent_class)->disconnect_proxy (action, proxy);
@@ -492,7 +510,7 @@ cb_entry_populate_popup (GtkEntry *entry, GtkMenu *menu,
 	gtk_widget_show(separator);
 
 	menuitem = gtk_menu_item_new_with_mnemonic(_("_Edit Smart Bookmark"));
-	g_signal_connect(G_OBJECT(menuitem), "activate",
+	g_signal_connect(menuitem, "activate",
 			 G_CALLBACK(cb_activate_edit_bookmark), action);
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 	gtk_widget_show(menuitem);
@@ -508,3 +526,36 @@ kz_location_entry_action_set_bookmark (KzLocationEntryAction *action,
 }
 
 
+static void
+cb_profile_entry_changed (KzProfile *profile,
+			  const gchar *section, const gchar *key,
+			  const gchar *old_value,
+			  GtkEntry    *entry)
+{
+     	if (!GTK_IS_ENTRY(entry)) return;
+	
+	switch (key[0])
+	{
+	case 'u':
+		if (strcmp(key, "use_auto_completion") == 0)
+		{
+			GtkAction *action;
+	                
+			action = g_object_get_data(G_OBJECT(entry),
+        			        	   KZ_LOCATION_ENTRY_ACTION_KEY);
+			if (action && KZ_IS_HISTORY_ACTION(action))
+                        {
+		                gboolean autocompletion = FALSE;
+        		        KZ_CONF_GET("Global", "use_auto_completion", autocompletion, BOOL);
+                                if(autocompletion)
+                                       kz_history_set_completion (KZ_HISTORY_ACTION(action), entry);
+                                else
+
+	                               kz_history_unset_completion (KZ_HISTORY_ACTION(action), entry);
+                        }
+		}
+	default:
+		break;
+	}
+}
+
