@@ -273,8 +273,6 @@ kz_bookmark_bar_button_release (GtkWidget *widget, GdkEventButton *event)
 {
 	KzBookmarkBar *bar;
 
-	g_return_val_if_fail(KZ_IS_BOOKMARK_BAR(widget), FALSE);
-
 	bar = KZ_BOOKMARK_BAR(widget);
 
 	switch (event->button)
@@ -347,13 +345,13 @@ kz_bookmark_bar_refresh_all (KzBookmarkBar *bar)
 static void
 kz_bookmark_bar_connect_signal (KzBookmarkBar *bar)
 {
-	g_signal_connect(G_OBJECT(bar->folder), "children-reordered",
+	g_signal_connect(bar->folder, "children-reordered",
 			 G_CALLBACK(cb_bookmark_list_updated),
 			 bar);	
-	g_signal_connect(G_OBJECT(bar->folder), "insert-child",
+	g_signal_connect(bar->folder, "insert-child",
 			 G_CALLBACK(cb_bookmark_list_insert_child),
 			 bar);
-	g_signal_connect(G_OBJECT(bar->folder), "remove-child",
+	g_signal_connect(bar->folder, "remove-child",
 			 G_CALLBACK(cb_bookmark_list_remove_child),
 			 bar);	
 }
@@ -363,13 +361,13 @@ static void
 kz_bookmark_bar_disconnect_signal (KzBookmarkBar *bar)
 {
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(bar->folder),
+		(bar->folder,
 		 G_CALLBACK(cb_bookmark_list_updated), bar);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(bar->folder),
+		(bar->folder,
 		 G_CALLBACK(cb_bookmark_list_insert_child), bar);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(bar->folder),
+		(bar->folder,
 		 G_CALLBACK(cb_bookmark_list_remove_child), bar);
 }
 
@@ -391,7 +389,6 @@ kz_bookmark_bar_drag_data_received (GtkWidget *widget,
 	GList *children;
 	gint index;
 
-	g_return_if_fail(KZ_IS_BOOKMARK_BAR(widget));
 	bar = KZ_BOOKMARK_BAR(widget);
 	index = gtk_toolbar_get_drop_index(GTK_TOOLBAR(bar->toolbar),
 					   x, y);
@@ -450,7 +447,8 @@ kz_bookmark_bar_drag_data_received (GtkWidget *widget,
 		
 		/* FIXME! we should also add normal bookmark. */
 		/* Create New KzBookmark */
-		if (strstr(strings[0], "rss") ||
+		if (strstr(strings[0], "xml") ||
+		    strstr(strings[0], "rss") ||
 		    strstr(strings[0], "rdf"))
 		{
 			bookmark = KZ_BOOKMARK(kz_bookmark_file_new(strings[0],
@@ -496,7 +494,6 @@ kz_bookmark_bar_drag_motion (GtkWidget *widget,
 	KzBookmarkBar *bar;
 	gint index;
 	
-	g_return_val_if_fail(KZ_IS_BOOKMARK_BAR(widget), FALSE);
 	bar = KZ_BOOKMARK_BAR(widget);
 	index = gtk_toolbar_get_drop_index(GTK_TOOLBAR(bar->toolbar),
 					   x, y);
@@ -545,7 +542,7 @@ create_tool_item (KzBookmarkBar *bar, KzBookmark *child)
 		 * We need to connect "destroy" signal to disconnect signals 
 		 * to bookmark folder associated with proxy.
 		 */
-		g_signal_connect(G_OBJECT(toolitem), "destroy",
+		g_signal_connect(toolitem, "destroy",
 				 G_CALLBACK(cb_toolitem_destroy), proxy);
 		
 		gtk_widget_show(proxy);
@@ -558,7 +555,6 @@ create_tool_item (KzBookmarkBar *bar, KzBookmark *child)
 static void
 cb_bookmark_list_updated (KzBookmark *folder, KzBookmarkBar *bar)
 {
-	g_return_if_fail(KZ_IS_BOOKMARK(folder));
 	g_return_if_fail(KZ_IS_BOOKMARK_BAR(bar));
 
 	kz_bookmark_bar_refresh_all(bar);
@@ -575,7 +571,6 @@ cb_bookmark_list_insert_child  (KzBookmark *folder,
 	GList *children;
 	GtkToolItem *toolitem;
 	
-	g_return_if_fail(KZ_IS_BOOKMARK(folder));
 	g_return_if_fail(KZ_IS_BOOKMARK(child));
 	g_return_if_fail(KZ_IS_BOOKMARK_BAR(bar));
 
@@ -602,7 +597,6 @@ cb_bookmark_list_remove_child  (KzBookmark *folder,
 	GList *children;
 	GtkToolItem *toolitem;
 
-	g_return_if_fail(KZ_IS_BOOKMARK(folder));
 	g_return_if_fail(KZ_IS_BOOKMARK(child));
 	g_return_if_fail(KZ_IS_BOOKMARK_BAR(bar));
 
