@@ -22,7 +22,7 @@
 
 #include "kz-bookmark-edit-win.h"
 
-#include "intl.h"
+#include <glib/gi18n.h>
 #include "gobject-utils.h"
 #include "kz-icons.h"
 #include "kz-bookmark-edit.h"
