@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-edit.c,v 1.32 2004/11/22 01:08:41 ikezoe Exp $
+ *  $Id: kz-bookmark-edit.c,v 1.34 2005/02/14 05:45:04 ikezoe Exp $
  */
 
 #include <glib/gi18n.h>
@@ -148,7 +148,7 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 1, 2, 0, 1,  /* xpos, ypos */
 			 GTK_FILL | GTK_EXPAND, 0,
 			 2, 2);       /* padding x, y  */
-	g_signal_connect(G_OBJECT(title_entry), "changed",
+	g_signal_connect(title_entry, "changed",
 			 G_CALLBACK(cb_title_entry_changed), edit);
 	gtk_widget_show(title_entry);
 
@@ -169,7 +169,7 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 1, 2, 1, 2,  /* xpos, ypos */
 			 GTK_FILL | GTK_EXPAND, 0,
 			 2, 2);       /* padding x, y  */
-	g_signal_connect(G_OBJECT(uri_entry), "changed",
+	g_signal_connect(uri_entry, "changed",
 			 G_CALLBACK(cb_uri_entry_changed), edit);
 	gtk_widget_show(uri_entry);
 
@@ -189,7 +189,7 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 1, 2, 2, 3,  /* xpos, ypos */
 			 GTK_FILL | GTK_EXPAND, 0,
 			 2, 2);       /* padding x, y  */
-	g_signal_connect(G_OBJECT(location_entry), "changed",
+	g_signal_connect(location_entry, "changed",
 			 G_CALLBACK(cb_location_entry_changed), edit);
 
 	/* Update interval */
@@ -205,7 +205,7 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 
 	interval_spin = gtk_spin_button_new_with_range(0, 60 * 24 * 7, 1);
 	gtk_box_pack_start(GTK_BOX(hbox), interval_spin, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(interval_spin), "value-changed",
+	g_signal_connect(interval_spin, "value-changed",
 			 G_CALLBACK(cb_interval_value_changed), edit);
 #if 1
 	/* XML-RPC interface for shared bookmark */
@@ -225,7 +225,7 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 1, 2, 4, 5,  /* xpos, ypos */
 			 GTK_FILL | GTK_EXPAND, 0,
 			 2, 2);       /* padding x, y  */
-	g_signal_connect(G_OBJECT(xmlrpc_entry), "changed",
+	g_signal_connect(xmlrpc_entry, "changed",
 			 G_CALLBACK(cb_xmlrpc_entry_changed), edit);
 	
 	/* User name */
@@ -244,7 +244,7 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 1, 2, 5, 6,  /* xpos, ypos */
 			 GTK_FILL | GTK_EXPAND, 0,
 			 2, 2);       /* padding x, y  */
-	g_signal_connect(G_OBJECT(xmlrpc_user_entry), "changed",
+	g_signal_connect(xmlrpc_user_entry, "changed",
 			 G_CALLBACK(cb_xmlrpc_user_entry_changed), edit);
 	
 	/* Password */
@@ -264,7 +264,7 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 			 1, 2, 6, 7,  /* xpos, ypos */
 			 GTK_FILL | GTK_EXPAND, 0,
 			 2, 2);       /* padding x, y  */
-	g_signal_connect(G_OBJECT(xmlrpc_pass_entry), "changed",
+	g_signal_connect(xmlrpc_pass_entry, "changed",
 			 G_CALLBACK(cb_xmlrpc_pass_entry_changed), edit);
 #endif
 	/* Memo */
@@ -295,7 +295,7 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(textview), GTK_WRAP_WORD);
 	gtk_container_add(GTK_CONTAINER(scrwin), textview);
 	textbuf = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
-	g_signal_connect(G_OBJECT(textbuf), "changed",
+	g_signal_connect(textbuf, "changed",
 			 G_CALLBACK(cb_description_changed), edit);
 	gtk_widget_show(textview);
 
@@ -348,7 +348,7 @@ kz_bookmark_edit_dispose (GObject *object)
 	{
 		g_object_unref(edit->bookmark);
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(edit->bookmark),
+			(edit->bookmark,
 			 G_CALLBACK(cb_bookmark_notify),
 			 edit);
 	}
@@ -393,7 +393,7 @@ kz_bookmark_edit_set (KzBookmarkEdit *edit, KzBookmark *bookmark)
 	if (!edit->bookmark) return;
 	g_object_ref(edit->bookmark);
 
-	g_signal_connect(G_OBJECT(edit->bookmark), "notify",
+	g_signal_connect(edit->bookmark, "notify",
 			 G_CALLBACK(cb_bookmark_notify), edit);
 
 	kz_bookmark_edit_sync_properties (edit, bookmark);
@@ -413,7 +413,7 @@ kz_bookmark_edit_clear (KzBookmarkEdit *edit)
 	{
 		g_object_unref(edit->bookmark);
 		g_signal_handlers_disconnect_by_func
-			(G_OBJECT(edit->bookmark),
+			(edit->bookmark,
 			 G_CALLBACK(cb_bookmark_notify),
 			 edit);
 	}
@@ -945,7 +945,7 @@ create_widget_for_smart_property(KzBookmarkEdit *edit)
 
 	/* Regex column */
 	cell = gtk_cell_renderer_text_new();
-	g_signal_connect(G_OBJECT(cell), "edited",
+	g_signal_connect(cell, "edited",
 			 G_CALLBACK(cb_smart_regex_edited), edit);
 	column = gtk_tree_view_column_new_with_attributes
 			(_("Regex"), cell,
@@ -957,7 +957,7 @@ create_widget_for_smart_property(KzBookmarkEdit *edit)
 
 	/* URI column */
 	cell = gtk_cell_renderer_text_new();
-	g_signal_connect(G_OBJECT(cell), "edited",
+	g_signal_connect(cell, "edited",
 			 G_CALLBACK(cb_smart_uri_edited), edit);
 	column = gtk_tree_view_column_new_with_attributes
 			(_("URI"), cell,
@@ -969,7 +969,7 @@ create_widget_for_smart_property(KzBookmarkEdit *edit)
 
         /* Encode column */
 	cell = gtk_cell_renderer_text_new();
-	g_signal_connect(G_OBJECT(cell), "edited",
+	g_signal_connect(cell, "edited",
 			 G_CALLBACK(cb_smart_encode_edited), edit);
 	column = gtk_tree_view_column_new_with_attributes
 		(_("ENCODE"), cell,
@@ -981,7 +981,7 @@ create_widget_for_smart_property(KzBookmarkEdit *edit)
         
 	/* URL encode flag  column */
 	cell = gtk_cell_renderer_toggle_new();
-	g_signal_connect(G_OBJECT(cell), "toggled",
+	g_signal_connect(cell, "toggled",
 			 G_CALLBACK(cb_smart_urlencode_toggled), edit);
 
 	gtk_cell_renderer_toggle_set_radio
@@ -1017,7 +1017,7 @@ create_widget_for_smart_property(KzBookmarkEdit *edit)
 	gtk_container_add(GTK_CONTAINER(button), arrow);
 	gtk_widget_show(arrow);
 	gtk_box_pack_start(GTK_BOX(vbox2), button, FALSE, FALSE, 5);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_smart_up_button), edit);
 	gtk_widget_show(button);
 
@@ -1027,7 +1027,7 @@ create_widget_for_smart_property(KzBookmarkEdit *edit)
 	gtk_container_add(GTK_CONTAINER(button), arrow);
 	gtk_widget_show(arrow);
 	gtk_box_pack_start(GTK_BOX(vbox2), button, FALSE, FALSE, 5);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_smart_down_button), edit);
 	gtk_widget_show(button);
 
@@ -1041,19 +1041,19 @@ create_widget_for_smart_property(KzBookmarkEdit *edit)
 	/* add button */
 	button = gtk_button_new_from_stock(GTK_STOCK_ADD);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_smart_add_button), edit);
 	gtk_widget_show(button);
 
 	/* remove button */
 	button = gtk_button_new_from_stock(GTK_STOCK_REMOVE);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_smart_remove_button), edit);
 	gtk_widget_show(button);
 
 	/* signal handler for GtkTreeView */
-	g_signal_connect(G_OBJECT(tree_view), "cursor-changed",
+	g_signal_connect(tree_view, "cursor-changed",
 			 G_CALLBACK(cb_smart_cursor_changed), edit);
 	return main_vbox;
 }
@@ -1076,7 +1076,6 @@ cb_title_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
 {
 	const gchar *title;
 
-	g_return_if_fail(GTK_IS_EDITABLE(editable));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
 
 	if (edit->changing) return;
@@ -1092,7 +1091,6 @@ cb_uri_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
 {
 	const gchar *uri;
 
-	g_return_if_fail(GTK_IS_EDITABLE(editable));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
 
 	if (edit->changing) return;
@@ -1108,7 +1106,6 @@ cb_location_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
 {
 	const gchar *uri;
 
-	g_return_if_fail(GTK_IS_EDITABLE(editable));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
 
 	if (edit->changing) return;
@@ -1143,7 +1140,6 @@ cb_description_changed (GtkTextBuffer *textbuf, KzBookmarkEdit *edit)
 	GtkTextIter start_iter, end_iter;
 	gchar *desc;
 
-	g_return_if_fail(GTK_IS_TEXT_BUFFER(textbuf));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
 
 	if (edit->changing) return;
@@ -1166,7 +1162,6 @@ cb_xmlrpc_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
 {
 	const gchar *xmlrpc;
 
-	g_return_if_fail(GTK_IS_EDITABLE(editable));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
 
 	if (edit->changing) return;
@@ -1182,7 +1177,6 @@ cb_xmlrpc_user_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
 {
 	const gchar *user;
 
-	g_return_if_fail(GTK_IS_EDITABLE(editable));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
 
 	if (edit->changing) return;
@@ -1198,7 +1192,6 @@ cb_xmlrpc_pass_entry_changed(GtkEditable *editable, KzBookmarkEdit *edit)
 {
 	const gchar *pass;
 
-	g_return_if_fail(GTK_IS_EDITABLE(editable));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDIT(edit));
 
 	if (edit->changing) return;
