@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-file.c,v 1.11 2005/02/07 13:11:24 ikezoe Exp $
+ *  $Id: kz-bookmark-file.c,v 1.14 2005/02/14 05:45:05 ikezoe Exp $
  */
 
 #include "kz-bookmark-file.h"
@@ -295,8 +295,6 @@ kz_bookmark_file_dispose (GObject *object)
 	guint timer_id, io_id;
 	KzIO *io;
 	
-	g_return_if_fail(KZ_IS_BOOKMARK_FILE(object));
-
 	timer_id = GPOINTER_TO_UINT(g_object_get_qdata(object, timer_quark));
 	if (timer_id)
 		g_source_remove(timer_id);
@@ -316,7 +314,7 @@ kz_bookmark_file_dispose (GObject *object)
 	if (io_id)
 	{
 		/* wait until disconnecting (i.e. loading stops  )*/
-		while (g_signal_handler_is_connected(G_OBJECT(io), io_id))
+		while (g_signal_handler_is_connected(io, io_id))
 			gtk_main_iteration();
 	}
 	g_object_set_qdata(object, io_quark, NULL);
@@ -684,14 +682,14 @@ kz_bookmark_file_load_start (KzBookmarkFile *bookmark_file)
 		return TRUE;
 	kz_bookmark_file_set_state(bookmark_file, KZ_BOOKMARK_FILE_STATE_LOADING);
 
-	g_signal_emit(G_OBJECT(bookmark_file),
+	g_signal_emit(bookmark_file,
 		      kz_bookmark_file_signals[LOAD_START_SIGNAL],
 		      0);
 
 	kz_bookmark_remove_all(KZ_BOOKMARK(bookmark_file));
 
 	io = kz_io_new(uri);
-	id = g_signal_connect(G_OBJECT(io), "io_completed",
+	id = g_signal_connect(io, "io_completed",
 			      G_CALLBACK(cb_io_load_complete),
 			      bookmark_file);
 	
@@ -803,7 +801,6 @@ cb_io_load_complete (KzIO *io, GError *error, KzBookmarkFile *bookmark_file)
 	guint size;
 
 	g_return_if_fail(KZ_IS_BOOKMARK_FILE(bookmark_file));
-	g_return_if_fail(KZ_IS_IO(io));
 
 	if (error) goto ERROR;
 
@@ -824,7 +821,7 @@ cb_io_load_complete (KzIO *io, GError *error, KzBookmarkFile *bookmark_file)
 
 ERROR:
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(io),
+		(io,
 		 G_CALLBACK(cb_io_load_complete),
 		 bookmark_file);
 	kz_bookmark_file_set_state(bookmark_file, KZ_BOOKMARK_FILE_STATE_NORMAL);
@@ -834,14 +831,14 @@ ERROR:
 
 	if (error)
 	{
-		g_signal_emit(G_OBJECT (bookmark_file),
+		g_signal_emit(bookmark_file,
 			      kz_bookmark_file_signals[ERROR_SIGNAL],
 			      0,
 			      "Load failed");
 	}
 	else 
 	{
-		g_signal_emit(G_OBJECT (bookmark_file),
+		g_signal_emit(bookmark_file,
 			      kz_bookmark_file_signals[LOAD_COMPLETED_SIGNAL],
 			      0);
 	}
@@ -960,7 +957,7 @@ cb_xml_rpc_completed(KzXMLRPC *xmlrpc, GError *error, gpointer data)
 	const GList *results;
 	KzBookmark *file;
 
-	g_signal_handlers_disconnect_by_func(G_OBJECT(xmlrpc),
+	g_signal_handlers_disconnect_by_func(xmlrpc,
 					     G_CALLBACK(cb_xml_rpc_completed),
 					     data);
 	results = kz_xml_rpc_get_results(xmlrpc);
@@ -973,7 +970,7 @@ cb_xml_rpc_completed(KzXMLRPC *xmlrpc, GError *error, gpointer data)
 			kz_bookmark_set_id(KZ_BOOKMARK(data), id);
 			file = kz_bookmark_get_parent_file (KZ_BOOKMARK(data));
 			/* fake signal */
-			g_signal_emit(G_OBJECT (file),
+			g_signal_emit(file,
 				      kz_bookmark_file_signals[LOAD_COMPLETED_SIGNAL],
 				      0);
 			kz_bookmark_file_set_state(KZ_BOOKMARK_FILE(file),
@@ -1017,7 +1014,7 @@ kz_bookmark_file_xmlrpc_insert (KzBookmarkFile *file,
 	desc  = kz_bookmark_get_description(child);
 
 	xmlrpc = kz_xml_rpc_new(xmlrpc_uri);
-	g_signal_connect(G_OBJECT(xmlrpc), "xml_rpc_completed", 
+	g_signal_connect(xmlrpc, "xml_rpc_completed", 
 			 G_CALLBACK(cb_xml_rpc_completed), child);
 	kz_xml_rpc_call(xmlrpc, "bookmark.insert",
 			kz_bookmark_file_get_location(file), 
@@ -1030,7 +1027,7 @@ kz_bookmark_file_xmlrpc_insert (KzBookmarkFile *file,
 			NULL);
 	/* fake signal */
 	kz_bookmark_file_set_state(file, KZ_BOOKMARK_FILE_STATE_LOADING);
-	g_signal_emit(G_OBJECT(file),
+	g_signal_emit(file,
 		      kz_bookmark_file_signals[LOAD_START_SIGNAL],
 		      0);
 }
@@ -1050,7 +1047,7 @@ kz_bookmark_file_xmlrpc_remove (KzBookmarkFile *file,
 	id = kz_bookmark_get_id(child);
 
 	xmlrpc = kz_xml_rpc_new(xmlrpc_uri);
-	g_signal_connect(G_OBJECT(xmlrpc), "xml_rpc_completed", 
+	g_signal_connect(xmlrpc, "xml_rpc_completed", 
 			 G_CALLBACK(cb_xml_rpc_completed), NULL);
 	kz_xml_rpc_call(xmlrpc, "bookmark.remove",
 			kz_bookmark_file_get_location(file), 
@@ -1083,7 +1080,7 @@ kz_bookmark_file_xmlrpc_move (KzBookmarkFile *file,
 	if (!sibling_id) sibling_id = "0";
 
 	xmlrpc = kz_xml_rpc_new(xmlrpc_uri);
-	g_signal_connect(G_OBJECT(xmlrpc), "xml_rpc_completed", 
+	g_signal_connect(xmlrpc, "xml_rpc_completed", 
 			 G_CALLBACK(cb_xml_rpc_completed), NULL);
 	kz_xml_rpc_call(xmlrpc, "bookmark.move",
 			kz_bookmark_file_get_location(file), 
