@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-item.c,v 1.4 2004/11/22 01:08:41 ikezoe Exp $
+ *  $Id: kz-bookmark-item.c,v 1.8 2005/02/14 05:45:05 ikezoe Exp $
  */
 
 #include "kz-bookmark-item.h"
@@ -193,7 +193,7 @@ kz_bookmark_item_constructor (GType                  type,
 	gtk_box_pack_start(hbox, button, FALSE, FALSE, 0);
 	if (is_file)
 	{
-		g_signal_connect(G_OBJECT(button), "clicked", 
+		g_signal_connect(button, "clicked", 
 				 G_CALLBACK(cb_update_button_clicked),
 				 menu);
 		menu->image = image
@@ -202,7 +202,7 @@ kz_bookmark_item_constructor (GType                  type,
 	}
 	else
 	{
-		g_signal_connect(G_OBJECT(button), "button_release_event",
+		g_signal_connect(button, "button_release_event",
 			 	 G_CALLBACK(cb_bookmark_menu_release), menu);
 		if(is_folder)
 		{
@@ -243,15 +243,15 @@ kz_bookmark_item_constructor (GType                  type,
 
 	if (is_file)
 	{
-		g_signal_connect(G_OBJECT(menu->bookmark),
+		g_signal_connect(menu->bookmark,
 				 "load_start", 
 				 G_CALLBACK(cb_bookmark_load_start),
 				 menu);
-		g_signal_connect(G_OBJECT(menu->bookmark),
+		g_signal_connect(menu->bookmark,
 				 "load_completed", 
 				 G_CALLBACK(cb_bookmark_load_stop),
 				 menu);
-		g_signal_connect(G_OBJECT(menu->bookmark),
+		g_signal_connect(menu->bookmark,
 				 "error", 
 				 G_CALLBACK(cb_bookmark_load_error),
 				 menu);
@@ -264,7 +264,7 @@ kz_bookmark_item_constructor (GType                  type,
 	eventbox = kz_input_event_box_new();
 	menu->eventbox = eventbox;
 	gtk_box_pack_start(hbox, eventbox, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(eventbox), "button_release_event",
+	g_signal_connect(eventbox, "button_release_event",
 			 G_CALLBACK(cb_bookmark_menu_release), menu);
 	gtk_widget_show (eventbox);
 
@@ -294,8 +294,6 @@ kz_bookmark_item_dispose (GObject *object)
 {
 	KzBookmarkItem *menu;
 
-	g_return_if_fail (KZ_IS_BOOKMARK_ITEM(object));
-
 	if (G_OBJECT_CLASS (parent_class)->dispose)
 		G_OBJECT_CLASS (parent_class)->dispose(object);
 
@@ -306,15 +304,15 @@ kz_bookmark_item_dispose (GObject *object)
 		if (KZ_IS_BOOKMARK_FILE(menu->bookmark))
 		{
 			g_signal_handlers_disconnect_by_func(
-				G_OBJECT(menu->bookmark),
+				menu->bookmark,
 				cb_bookmark_load_start,
 				menu);
 			g_signal_handlers_disconnect_by_func(
-				G_OBJECT(menu->bookmark),
+				menu->bookmark,
 				cb_bookmark_load_stop,
 				menu);
 			g_signal_handlers_disconnect_by_func(
-				G_OBJECT(menu->bookmark),
+				menu->bookmark,
 				cb_bookmark_load_error,
 				menu);
 		}
@@ -427,7 +425,6 @@ kz_bookmark_item_reset_submenu (KzBookmarkItem *menu)
 static void 
 cb_bookmark_load_start (KzBookmark *bookmark, KzBookmarkItem *menu)
 {
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_BOOKMARK_ITEM(menu));
 
 	gtk_image_set_from_stock(GTK_IMAGE(menu->image),
@@ -439,7 +436,6 @@ cb_bookmark_load_start (KzBookmark *bookmark, KzBookmarkItem *menu)
 static void 
 cb_bookmark_load_stop (KzBookmark *bookmark, KzBookmarkItem *menu)
 {
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_BOOKMARK_ITEM(menu));
 
 	kz_bookmark_item_reset_submenu(menu);
@@ -453,7 +449,6 @@ cb_bookmark_load_stop (KzBookmark *bookmark, KzBookmarkItem *menu)
 static void 
 cb_bookmark_load_error (KzBookmark *bookmark, const gchar *error, KzBookmarkItem *menu)
 {
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_BOOKMARK_ITEM(menu));
 
 	gtk_image_set_from_stock(GTK_IMAGE(menu->image),
@@ -481,7 +476,7 @@ bookmark_weak_ref (gpointer data, GObject *obj)
 
 	if (!widget) return;
 
-	g_signal_handlers_disconnect_by_func(GTK_OBJECT(widget),
+	g_signal_handlers_disconnect_by_func(widget,
 					     G_CALLBACK(cb_menuitem_destroy),
 					     item);
 }
@@ -561,7 +556,7 @@ cb_update_button_clicked (GtkWidget *widget, KzBookmarkItem *menu)
 static void
 cb_menuitem_destroy(GtkWidget *widget, KzBookmark *item)
 {
-	g_signal_handlers_disconnect_by_func(G_OBJECT(item),
+	g_signal_handlers_disconnect_by_func(item,
 					     G_CALLBACK(cb_notify_title),
 					     widget);
 	g_object_weak_unref(G_OBJECT(item), bookmark_weak_ref, widget);
@@ -592,8 +587,6 @@ kz_bookmark_item_drag_begin (GtkWidget *widget, GdkDragContext *context)
 	KzBookmark *bookmark;
 	const gchar *stock_id;
 
-	g_return_if_fail(KZ_IS_BOOKMARK_ITEM(widget));
-
 	item = KZ_BOOKMARK_ITEM(widget);
 	bookmark = item->bookmark;
 
@@ -611,10 +604,10 @@ kz_bookmark_item_drag_begin (GtkWidget *widget, GdkDragContext *context)
 static void
 connect_observe_signals (GtkWidget *widget, KzBookmark *item)
 {
-	g_signal_connect(G_OBJECT(item), "notify::title",
+	g_signal_connect(item, "notify::title",
 			 G_CALLBACK(cb_notify_title), widget);
 	g_object_weak_ref(G_OBJECT(item), bookmark_weak_ref, widget);
 
-	g_signal_connect(G_OBJECT(widget), "destroy",
+	g_signal_connect(widget, "destroy",
 			 G_CALLBACK(cb_menuitem_destroy), item);
 }
