@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-menu.c,v 1.1 2004/09/30 04:32:11 makeinu Exp $
+ *  $Id: kz-bookmark-menu.c,v 1.3 2005/02/13 13:20:34 ikezoe Exp $
  */
 
 #include "kz-bookmark-menu.h"
@@ -110,13 +110,13 @@ kz_bookmark_menu_create_menuitem (KzBookmark *bookmark, KzWindow *kz,
 			  KZ_BOOKMARK_MENU_PROXY_KEY,
 			  GINT_TO_POINTER(is_folder_proxy));
 
-	g_signal_connect(G_OBJECT(menu_item), "button_press_event",
+	g_signal_connect(menu_item, "button_press_event",
 			 G_CALLBACK(cb_menu_item_button_press),
 			 kz);
-	g_signal_connect(G_OBJECT(menu_item), "button_release_event",
+	g_signal_connect(menu_item, "button_release_event",
 			 G_CALLBACK(cb_menu_item_button_release),
 			 kz);
-	g_signal_connect(G_OBJECT(menu_item), "activate",
+	g_signal_connect(menu_item, "activate",
 			 G_CALLBACK(cb_menu_item_activate),
 			 kz);
 
@@ -378,14 +378,14 @@ cb_menuitem_destroy(GtkWidget *widget, KzBookmark *item)
 static void
 connect_bookmark_signals (GtkWidget *widget, KzBookmark *item)
 {
-	g_signal_connect(G_OBJECT(item), "notify::title",
+	g_signal_connect(item, "notify::title",
 			 G_CALLBACK(cb_notify_title),
 			 widget);
-	g_signal_connect(G_OBJECT(item), "notify::description",
+	g_signal_connect(item, "notify::description",
 			 G_CALLBACK(cb_notify_desc),
 			 widget);
 
-	g_signal_connect(G_OBJECT(widget), "destroy",
+	g_signal_connect(widget, "destroy",
 			 G_CALLBACK(cb_menuitem_destroy), item);
 	g_object_weak_ref(G_OBJECT(item), bookmark_weak_ref, widget);
 }
@@ -394,10 +394,10 @@ connect_bookmark_signals (GtkWidget *widget, KzBookmark *item)
 static void
 disconnect_bookmark_signals (GtkWidget *widget, KzBookmark *item)
 {
-	g_signal_handlers_disconnect_by_func(G_OBJECT(item),
+	g_signal_handlers_disconnect_by_func(item,
 					     G_CALLBACK(cb_notify_title),
 					     widget);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(item),
+	g_signal_handlers_disconnect_by_func(item,
 					     G_CALLBACK(cb_notify_desc),
 					     widget);
 
@@ -408,7 +408,7 @@ disconnect_bookmark_signals (GtkWidget *widget, KzBookmark *item)
 static void
 disconnect_menuitem_signals (GtkWidget *widget, KzBookmark *item)
 {
-	g_signal_handlers_disconnect_by_func(GTK_OBJECT(widget),
+	g_signal_handlers_disconnect_by_func(widget,
 					     G_CALLBACK(cb_menuitem_destroy),
 					     item);
 }
@@ -646,17 +646,17 @@ cb_root_menu_destroy(GtkWidget *widget, KzBookmark *folder)
 static void
 connect_folder_signals (KzBookmark *folder, GtkMenuShell *shell)
 {
-	g_signal_connect_after(G_OBJECT(folder), "insert-child",
+	g_signal_connect_after(folder, "insert-child",
 			       G_CALLBACK(cb_folder_insert_child),
 			       shell);
-	g_signal_connect_after(G_OBJECT(folder), "remove-child",
+	g_signal_connect_after(folder, "remove-child",
 			       G_CALLBACK(cb_folder_remove_child),
 			       shell);
-	g_signal_connect_after(G_OBJECT(folder), "children-reordered",
+	g_signal_connect_after(folder, "children-reordered",
 			       G_CALLBACK(cb_folder_reordered),
 			       shell);
 
-	g_signal_connect(G_OBJECT(shell), "destroy",
+	g_signal_connect(shell, "destroy",
 			 G_CALLBACK(cb_root_menu_destroy), folder);
 	g_object_weak_ref(G_OBJECT(folder), folder_weak_ref, shell);
 }
@@ -666,15 +666,15 @@ static void
 disconnect_folder_signals (KzBookmark *folder, GtkMenuShell *shell)
 {
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(folder),
+		(folder,
 		 G_CALLBACK(cb_folder_insert_child),
 		 shell);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(folder),
+		(folder,
 		 G_CALLBACK(cb_folder_remove_child),
 		 shell);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(folder),
+		(folder,
 		 G_CALLBACK(cb_folder_reordered),
 		 shell);
 
@@ -686,7 +686,7 @@ static void
 disconnect_menu_signals (KzBookmark *folder, GtkMenuShell *shell)
 {
 	g_signal_handlers_disconnect_by_func
-		(GTK_OBJECT(shell),
+		(shell,
 		 G_CALLBACK(cb_root_menu_destroy),
 		 folder);
 }
