@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-view.c,v 1.22 2004/11/25 02:40:11 ikezoe Exp $
+ *  $Id: kz-bookmarks-view.c,v 1.24 2005/02/14 05:45:05 ikezoe Exp $
  */
 
 #include "kz-bookmarks-view.h"
@@ -221,7 +221,7 @@ kz_bookmarks_view_new (void)
 	gtk_tree_view_column_add_attribute(column, cell,
 					   "pixbuf", COLUMN_ICON);
 	cell = gtk_cell_renderer_text_new();
-	g_signal_connect(G_OBJECT(cell), "edited",
+	g_signal_connect(cell, "edited",
 			 G_CALLBACK(cb_bookmark_title_edited), view);
 	gtk_tree_view_column_pack_start(column, cell, TRUE);
 	gtk_tree_view_column_set_attributes(column, cell,
@@ -237,7 +237,7 @@ kz_bookmarks_view_new (void)
 
 	/* Location column */
 	cell = gtk_cell_renderer_text_new();
-	g_signal_connect(G_OBJECT(cell), "edited",
+	g_signal_connect(cell, "edited",
 			 G_CALLBACK(cb_bookmark_location_edited), view);
 	column = gtk_tree_view_column_new_with_attributes
 			(_("Location"), cell,
@@ -263,11 +263,11 @@ kz_bookmarks_view_new (void)
 		 dnd_types_num,
 		 GDK_ACTION_ASK  | GDK_ACTION_COPY |
 		 GDK_ACTION_MOVE | GDK_ACTION_LINK);
-	g_signal_connect(G_OBJECT(view), "drag-motion",
+	g_signal_connect(view, "drag-motion",
 			 G_CALLBACK(cb_drag_motion), view);
-	g_signal_connect(G_OBJECT(view), "drag-data-get",
+	g_signal_connect(view, "drag-data-get",
 			 G_CALLBACK(cb_drag_data_get), view);
-	g_signal_connect(G_OBJECT(view), "drag-data-received",
+	g_signal_connect(view, "drag-data-received",
 			 G_CALLBACK(cb_drag_data_received), view);
 
 	return GTK_WIDGET(view);
@@ -864,11 +864,11 @@ connect_bookmark_signals (KzBookmarksView *view,
 
 	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 
-	g_signal_connect_after(G_OBJECT(bookmark), "insert-child",
+	g_signal_connect_after(bookmark, "insert-child",
 			       G_CALLBACK(cb_bookmark_insert_child), view);
-	g_signal_connect(G_OBJECT(bookmark), "remove-child",
+	g_signal_connect(bookmark, "remove-child",
 			 G_CALLBACK(cb_bookmark_remove_child), view);
-	g_signal_connect(G_OBJECT(bookmark), "notify",
+	g_signal_connect(bookmark, "notify",
 			 G_CALLBACK(cb_bookmark_notify), view);
 
 	if (!kz_bookmark_is_folder(bookmark)) return;
@@ -889,13 +889,13 @@ disconnect_bookmark_signals (KzBookmarksView *view,
 	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(bookmark),
+		(bookmark,
 		 G_CALLBACK(cb_bookmark_insert_child), view);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(bookmark),
+		(bookmark,
 		 G_CALLBACK(cb_bookmark_remove_child), view);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(bookmark),
+		(bookmark,
 		 G_CALLBACK(cb_bookmark_notify), view);
 
 	if (!kz_bookmark_is_folder(bookmark)) return;
@@ -975,7 +975,6 @@ cb_drag_motion (GtkWidget *widget,
 	KzBookmark *bookmark = NULL;
 	gboolean success, retval = FALSE;
 
-	g_return_val_if_fail(GTK_IS_TREE_VIEW(widget), TRUE);
 	g_return_val_if_fail(KZ_IS_BOOKMARKS_VIEW(view), TRUE);
 
 	success = gtk_tree_view_get_dest_row_at_pos(GTK_TREE_VIEW(widget),
