@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-khtml.c,v 1.12 2004/11/25 06:25:09 ikezoe Exp $
+ *  $Id: kz-khtml.c,v 1.15 2005/03/08 05:13:17 ikezoe Exp $
  */
 
 #include <glib/gi18n.h>
@@ -45,9 +45,6 @@ static void         kz_khtml_load_start       (GtkKHTML     *khtml);
 static void         kz_khtml_load_stop        (GtkKHTML     *khtml);
 static void         kz_khtml_location         (GtkKHTML     *khtml);
 static void         kz_khtml_title            (GtkKHTML     *khtml);
-static void         kz_khtml_progress         (GtkKHTML     *khtml,
-					       gint          curprogress,
-					       gint          maxprogress);
 static void         kz_khtml_req_js_prompt    (GtkKHTML     *khtml,
 					       GtkKHTMLPromptArgs* args);
 static void         kz_khtml_req_auth_prompt  (GtkKHTML     *khtml,
@@ -113,8 +110,9 @@ kz_khtml_class_init (KzKHTMLClass *klass)
 	khtml_class->load_stop  = kz_khtml_load_stop;
 	khtml_class->location   = kz_khtml_location;
 	khtml_class->title      = kz_khtml_title;
+#if 0	
 	khtml_class->progress   = kz_khtml_progress;
-	
+#endif	
 	khtml_class->req_js_prompt   = kz_khtml_req_js_prompt;
 	khtml_class->req_auth_prompt = kz_khtml_req_auth_prompt;
 	khtml_class->req_new_window  = kz_khtml_req_new_window;
@@ -172,6 +170,7 @@ kz_khtml_iface_init (KzEmbedIFace *iface)
 	iface->get_encoding           = NULL;
 	iface->print                  = NULL;
 	iface->print_preview          = NULL;
+	iface->get_printer_list       = NULL;
 	iface->create_thumbnail       = NULL;
 	iface->save_with_content      = NULL;
 	iface->set_text_into_textarea = NULL;
@@ -255,14 +254,20 @@ kz_khtml_status (GtkKHTML *khtml, GtkKHTMLLoadStatus *status)
 		KZ_KHTML(khtml)->is_loading = TRUE;
 		KZ_KHTML(khtml)->priv->cur_requests = 0;
 		KZ_KHTML(khtml)->priv->total_requests = 0;
-		g_signal_emit_by_name(G_OBJECT(khtml), "kz-net-start");
+		g_signal_emit_by_name(khtml, "kz-net-start");
+		break;
+	case GTK_KHTML_LOADING:
+		KZ_KHTML(khtml)->priv->cur_requests = status->totalReceived;
+		KZ_KHTML(khtml)->priv->total_requests = status->totalSize;
+		g_signal_emit_by_name(khtml, "kz-progress");
+		g_warning("oo");
 		break;
 	case GTK_KHTML_LOADING_COMPLETE:
 	case GTK_KHTML_LOADING_ERROR:
 		KZ_KHTML(khtml)->is_loading = FALSE;
 		KZ_KHTML(khtml)->priv->cur_requests = status->totalReceived;
 		KZ_KHTML(khtml)->priv->total_requests = status->totalSize;
-		g_signal_emit_by_name(G_OBJECT(khtml), "kz-net-stop");
+		g_signal_emit_by_name(khtml, "kz-net-stop");
 		break;
 	default:
 		break;
@@ -279,7 +284,7 @@ kz_khtml_load_start (GtkKHTML *khtml)
 
 	KZ_KHTML(khtml)->is_loading = TRUE;
 
-	g_signal_emit_by_name(G_OBJECT(khtml), "kz-net-start");
+	g_signal_emit_by_name(khtml, "kz-net-start");
 
 	/* call parent method */
 }
@@ -292,7 +297,7 @@ kz_khtml_load_stop (GtkKHTML *khtml)
 
 	KZ_KHTML(khtml)->is_loading = FALSE;
 
-	g_signal_emit_by_name(G_OBJECT(khtml), "kz-net-stop");
+	g_signal_emit_by_name(khtml, "kz-net-stop");
 
 	/* call parent method */
 }
@@ -303,7 +308,7 @@ kz_khtml_location (GtkKHTML *khtml)
 {
 	g_return_if_fail(KZ_IS_KHTML(khtml));
 
-	g_signal_emit_by_name(G_OBJECT(khtml), "kz-location");
+	g_signal_emit_by_name(khtml, "kz-location");
 
 	/* call parent method */
 }
@@ -314,24 +319,12 @@ kz_khtml_title (GtkKHTML *khtml)
 {
 	g_return_if_fail(KZ_IS_KHTML(khtml));
 
-	g_signal_emit_by_name(G_OBJECT(khtml), "kz-title");
+	g_signal_emit_by_name(khtml, "kz-title");
 
 	/* call parent method */
 }
 
 
-static void
-kz_khtml_progress (GtkKHTML *khtml, gint curprogress, gint maxprogress)
-{
-	g_return_if_fail(KZ_IS_KHTML(khtml));
-
-	KZ_KHTML(khtml)->priv->cur_requests = curprogress;
-	KZ_KHTML(khtml)->priv->total_requests = maxprogress;
-	
-	g_signal_emit_by_name(G_OBJECT(khtml), "kz-progress");
-}
-
-
 static void
 kz_khtml_req_js_prompt (GtkKHTML *khtml, GtkKHTMLPromptArgs* args)
 {
@@ -351,7 +344,7 @@ kz_khtml_req_new_window (GtkKHTML *khtml, GtkKHTML *newkhtml)
 {
 	g_return_val_if_fail(KZ_IS_KHTML(khtml), FALSE);
 	
-	g_signal_emit_by_name(G_OBJECT(khtml), "kz-new-window", newkhtml);
+	g_signal_emit_by_name(khtml, "kz-new-window", newkhtml);
 	return TRUE;
 }
 
