@@ -19,12 +19,12 @@
  */
 
 #include <string.h>
+#include <glib/gi18n.h>
 
 #include "kz-download-box.h"
 #include "kz-actions-download.h"
 #include "gobject-utils.h"
 #include "gtk-utils.h"
-#include "intl.h"
 
 static void kz_download_box_class_init (KzDownloadBoxClass *klass);
 static void kz_download_box_init       (KzDownloadBox      *dlbox);
@@ -111,17 +111,17 @@ kz_download_box_new (KzWindow *kz)
 {
 	KzDownloadBox *dlbox;
 
-	dlbox = KZ_DOWNLOAD_BOX(g_object_new(KZ_TYPE_DOWNLOAD_BOX, NULL));
+	dlbox = g_object_new(KZ_TYPE_DOWNLOAD_BOX, NULL);
 
 	dlbox->kz = kz;
 	
 	dlbox->dlgrp = kz_downloader_group_get_instance();
 
-	g_signal_connect(G_OBJECT(dlbox->dlgrp), "add",
+	g_signal_connect(dlbox->dlgrp, "add",
 			 G_CALLBACK(cb_add_item), dlbox);
-	g_signal_connect(G_OBJECT(dlbox->dlgrp), "remove",
+	g_signal_connect(dlbox->dlgrp, "remove",
 			 G_CALLBACK(cb_remove_item), dlbox);	
-	g_signal_connect(G_OBJECT(dlbox->dlgrp), "progress",
+	g_signal_connect(dlbox->dlgrp, "progress",
 			 G_CALLBACK(cb_progress_item), dlbox);	
 
 	return GTK_WIDGET(dlbox);
@@ -141,13 +141,13 @@ kz_download_box_dispose (GObject *object)
 	
 	if (dlbox->dlgrp)
 	{
-		g_signal_handlers_disconnect_by_func(G_OBJECT(dlbox->dlgrp),
+		g_signal_handlers_disconnect_by_func(dlbox->dlgrp,
 						     G_CALLBACK(cb_add_item),
 						     dlbox);
-		g_signal_handlers_disconnect_by_func(G_OBJECT(dlbox->dlgrp),
+		g_signal_handlers_disconnect_by_func(dlbox->dlgrp,
 						     G_CALLBACK(cb_remove_item),
 						     dlbox);
-		g_signal_handlers_disconnect_by_func(G_OBJECT(dlbox->dlgrp),
+		g_signal_handlers_disconnect_by_func(dlbox->dlgrp,
 						     G_CALLBACK(cb_progress_item),
 						     dlbox);
 		g_object_unref(dlbox->dlgrp);
@@ -170,7 +170,6 @@ kz_download_box_drag_data_received (GtkWidget *widget,
 	KzDownloadBox *dlbox;
 	gchar **strings, *basename;
 
-	g_return_if_fail(KZ_IS_DOWNLOAD_BOX(widget));
 	dlbox = KZ_DOWNLOAD_BOX(widget);
 
 	switch (info)
@@ -189,7 +188,8 @@ kz_download_box_drag_data_received (GtkWidget *widget,
 							   basename);
 			if (!ret)
 			{
-				kz_actions_download_open_save_dialog(strings[0], FALSE);
+				kz_actions_download_open_save_dialog(GTK_WINDOW(dlbox->kz),
+				    				     strings[0], FALSE);
 				g_strfreev(strings);
 				g_free(basename);
 				break;
@@ -287,7 +287,7 @@ cb_add_item (KzDownloaderGroup *dlgrp,
 	gtk_widget_show(icon->event_box);
 	gtk_box_pack_start(GTK_BOX(dlbox), icon->event_box, FALSE, FALSE, 0);
 
-	g_signal_connect(G_OBJECT(icon->event_box), "button_press_event",
+	g_signal_connect(icon->event_box, "button_press_event",
 			 G_CALLBACK(cb_icon_clicked), icon);
 
 }
@@ -301,7 +301,6 @@ cb_remove_item (KzDownloaderGroup *dlgrp,
 	GSList *list;
 
 	g_return_if_fail(KZ_IS_DOWNLOADER(dl));
-	g_return_if_fail(KZ_IS_DOWNLOADER_GROUP(dlgrp));
 	g_return_if_fail(KZ_IS_DOWNLOAD_BOX(dlbox));
 
 	for (list = dlbox->icon_list; list; list = g_slist_next(list))
