@@ -44,6 +44,7 @@ enum {
 	DOM_MOUSE_DBL_CLICK_SIGNAL,
 	DOM_MOUSE_OVER_SIGNAL,
 	DOM_MOUSE_OUT_SIGNAL,
+	SELECTION_SIGNAL,
 	LAST_SIGNAL
 };
 
@@ -254,6 +255,16 @@ kz_embed_base_init (gpointer g_class)
 				NULL, NULL,
 				_kz_marshal_INT__POINTER,
 				G_TYPE_INT, 1, G_TYPE_POINTER);
+	
+	kz_embed_signals[SELECTION_SIGNAL]
+		= g_signal_new ("kz-selection",
+				KZ_TYPE_EMBED,
+				G_SIGNAL_RUN_FIRST,
+				G_STRUCT_OFFSET(KzEmbedIFace, selection),
+				NULL, NULL,
+				g_cclosure_marshal_VOID__VOID,
+				G_TYPE_NONE, 0);
+
 
 	initialized = TRUE;
 }
@@ -763,6 +774,16 @@ kz_embed_print_preview (KzEmbed *kzembed)
 }
 
 
+GList *
+kz_embed_get_printer_list (KzEmbed *kzembed)
+{
+	g_return_val_if_fail(KZ_IS_EMBED(kzembed), NULL);
+	g_return_val_if_fail(KZ_EMBED_GET_IFACE(kzembed)->get_printer_list, NULL);
+
+	return KZ_EMBED_GET_IFACE(kzembed)->get_printer_list(kzembed);
+}
+
+
 void
 kz_embed_create_thumbnail (KzEmbed *kzembed)
 {
