@@ -170,6 +170,7 @@ struct _KzEmbedIFace {
 						 gboolean      *forced);
 	void		(*print)		(KzEmbed       *kzembed);
 	void		(*print_preview)	(KzEmbed       *kzembed);
+	GList	       *(*get_printer_list)	(KzEmbed       *kzembed);
 	void		(*create_thumbnail)	(KzEmbed       *kzembed);
 
 
@@ -247,6 +248,7 @@ struct _KzEmbedIFace {
 					 KzEmbedEvent  event);
 	gint     (*dom_mouse_out)       (KzEmbed      *embed,
 					 KzEmbedEvent  event);
+	void     (*selection)           (KzEmbed      *embed);
 #if 1 /* not implemented yet */
 	void     (*security_change)     (KzEmbed      *embed,
 					 gpointer      request,
@@ -357,6 +359,7 @@ void		kz_embed_get_encoding		(KzEmbed       *kzembed,
 						 gboolean      *forced);
 void		kz_embed_print			(KzEmbed       *kzembed);
 void		kz_embed_print_preview		(KzEmbed       *kzembed);
+GList	       *kz_embed_get_printer_list	(KzEmbed       *kzembed);
 void		kz_embed_create_thumbnail	(KzEmbed       *kzembed);
 
 
