@@ -25,13 +25,15 @@
 #include "utils.h"
 #include "glib-utils.h"
 
-struct _KzFaviconPriv
+typedef struct _KzFaviconPrivate	KzFaviconPrivate;
+struct _KzFaviconPrivate
 {
 	GHashTable *uri_hash;
 	KzProfile  *uri_list;
 
 	guint n_favicon;
 };
+#define KZ_FAVICON_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_FAVICON, KzFaviconPrivate))
 
 enum {
 	READY_SIGNAL,
@@ -43,16 +45,12 @@ enum {
 static void kz_favicon_class_init   (KzFaviconClass *klass);
 static void kz_favicon_init         (KzFavicon *kzfav);
 static void kz_favicon_dispose      (GObject *object);
-static void kz_favicon_finalize     (GObject *object);
 
 static void kz_favicon_load_uri_list        (KzFavicon *kzfav);
 static void kz_favicon_uri_hash_to_uri_list (gpointer key,
 					     gpointer value,
 					     KzFavicon *kzfav);
 
-static void cb_favicon_uri_notify       (KzMozEmbed *kzembed,
-					 const gchar *favicon_uri,
-					 KzFavicon *kzfav);
 static void cb_downloader_load_complete (KzDownloader *dl,
 					 const gchar *uri);
 static void cb_downloader_load_error    (KzDownloader *dl,
@@ -76,7 +74,6 @@ kz_favicon_class_init (KzFaviconClass *klass)
 	object_class = (GObjectClass *) klass;
 
 	object_class->dispose  = kz_favicon_dispose;
-	object_class->finalize = kz_favicon_finalize;
 	
 	klass->ready = NULL;
 
@@ -89,6 +86,7 @@ kz_favicon_class_init (KzFaviconClass *klass)
 				g_cclosure_marshal_VOID__STRING,
 				G_TYPE_NONE, 1,
 				G_TYPE_STRING);
+	g_type_class_add_private (object_class, sizeof(KzFaviconPrivate));
 }
 
 
@@ -96,70 +94,62 @@ static void
 kz_favicon_init (KzFavicon *kzfav)
 {
 	gchar *favicon_file;
-	kzfav->priv = g_new0(KzFaviconPriv, 1);
-
-	/* make dir which stores icon file */
-	make_dir("favicon");
+	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
 
 	favicon_file = g_build_filename(g_get_home_dir(),
-				        ".kazehakase",
+				        "."PACKAGE,
 					"faviconrc",
 				   	NULL);
-	kzfav->priv->uri_list = kz_profile_open(favicon_file, NULL);
+	priv->uri_list = kz_profile_open(favicon_file, NULL);
 	g_free(favicon_file);
 
-	kzfav->priv->uri_hash = g_hash_table_new_full (g_str_hash,
-						       g_str_equal,
-						       (GDestroyNotify)g_free,
-						       (GDestroyNotify)g_free);
+	priv->uri_hash = g_hash_table_new_full (g_str_hash,
+						g_str_equal,
+						(GDestroyNotify)g_free,
+						(GDestroyNotify)g_free);
 	kz_favicon_load_uri_list(kzfav);
-	kz_profile_close(kzfav->priv->uri_list);
+	kz_profile_close(priv->uri_list);
 }
 
 
 static void
 kz_favicon_dispose (GObject *object)
 {
-	KzFavicon *kzfav;
+	KzFavicon *kzfav = KZ_FAVICON(object);
 	gchar *favicon_file;
-
-	g_return_if_fail(KZ_IS_FAVICON(object));
-
-	kzfav = KZ_FAVICON(object);
+	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
+	
 	favicon_file = g_build_filename(g_get_home_dir(),
-				   	".kazehakase",
+				   	"."PACKAGE,
 					"faviconrc",
 				   	NULL);
 	
-	kzfav->priv->uri_list = kz_profile_open(favicon_file, NULL);
+	priv->uri_list = kz_profile_open(favicon_file, NULL);
 	g_free(favicon_file);
 
-	kz_profile_delete_section(kzfav->priv->uri_list, "URI");
-	kzfav->priv->n_favicon = 0;
+	kz_profile_delete_section(priv->uri_list, "URI");
+	priv->n_favicon = 0;
 	
 	/* convert hash table to KzProfileList */
-	g_hash_table_foreach(kzfav->priv->uri_hash,
+	g_hash_table_foreach(priv->uri_hash,
 			     (GHFunc)kz_favicon_uri_hash_to_uri_list,
 			     kzfav);
 
-	kz_profile_close(kzfav->priv->uri_list);
-	g_hash_table_destroy(kzfav->priv->uri_hash);
+	kz_profile_close(priv->uri_list);
+	g_hash_table_destroy(priv->uri_hash);
 	
-	kzfav->priv->uri_list = NULL;
-	kzfav->priv->uri_hash = NULL;
+	priv->uri_list = NULL;
+	priv->uri_hash = NULL;
 
 	if (G_OBJECT_CLASS (parent_class)->dispose)
 		G_OBJECT_CLASS (parent_class)->dispose(object);
 }
 
 
-KZ_OBJECT_FINALIZE(kz_favicon, KzFavicon)
-
-
 KzFavicon *
 kz_favicon_new (void)
 {
-	KzFavicon *kzfav = KZ_FAVICON(g_object_new(KZ_TYPE_FAVICON, NULL));
+	KzFavicon *kzfav = g_object_new(KZ_TYPE_FAVICON, NULL);
 
 	return kzfav;
 }
@@ -181,14 +171,15 @@ static void
 kz_favicon_load_uri_list (KzFavicon *kzfav)
 {
 	KzProfileList *p;
-	KzProfile *uri_list = kzfav->priv->uri_list;
+	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
+	KzProfile *uri_list = priv->uri_list;
 	
 	for (p = uri_list->list; p; p = p->next)
 	{
 		if (p->type == KZ_PROFILE_DATA_TYPE_KEY 
 		    && g_strcmp(p->section, "URI") == 0)
 		{
-			g_hash_table_insert(kzfav->priv->uri_hash,
+			g_hash_table_insert(priv->uri_hash,
 					    g_strdup(p->key),
 					    g_strdup(p->value));
 		}
@@ -199,82 +190,16 @@ kz_favicon_load_uri_list (KzFavicon *kzfav)
 static void
 kz_favicon_uri_hash_to_uri_list (gpointer key, gpointer value, KzFavicon *kzfav)
 {
-	if (kzfav->priv->n_favicon > MAX_FAVICONS)
+	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
+	if (priv->n_favicon > MAX_FAVICONS)
 		return;
 
-	kz_profile_set_value(kzfav->priv->uri_list, "URI",
+	kz_profile_set_value(priv->uri_list, "URI",
 			     (const gchar*)key, (const gchar *)value,
 			     strlen((gchar *)value) + 1,
 			     KZ_PROFILE_VALUE_TYPE_STRING);
 
-	kzfav->priv->n_favicon++;
-}
-
-
-static void
-cb_favicon_uri_notify (KzMozEmbed *kzembed,
-		       const gchar *favicon_uri,
-		       KzFavicon *kzfav)
-{
-	const gchar *location;
-	gchar *favicon_filename;
-	gchar *favicon_file_location;
-	gchar *hash_key;
-	const gchar *old_value;
-	KzDownloader *dl;
-
-	g_return_if_fail(KZ_IS_MOZ_EMBED(kzembed));
- 	g_return_if_fail(KZ_IS_FAVICON(kzfav));
-
-	if (!favicon_uri)
-		return;
-	location = kz_moz_embed_get_location(kzembed);
-	hash_key = create_profile_key_from_uri(location);
-
-	favicon_filename = create_filename_from_uri(favicon_uri);
-	favicon_file_location = g_build_filename(g_get_home_dir(),
-					    	 ".kazehakase",
-						 "favicon",
-					    	 favicon_filename,
-					    	 NULL);
-	g_free(favicon_filename);
-	
-	old_value = g_hash_table_lookup(kzfav->priv->uri_hash,
-					hash_key);
-	
-	if (old_value && !strcmp(old_value, favicon_file_location))
-	{
-		GQuark quark;
-		quark = g_quark_from_string(location);
-		
-		g_signal_emit(kzfav,
-			      kz_favicon_signals[READY_SIGNAL],
-			      quark,
-			      location);
-		g_free(hash_key);
-		g_free(favicon_file_location);
-		return;
-	}
-
-	g_hash_table_insert(kzfav->priv->uri_hash,
-			    g_strdup(hash_key),
-			    g_strdup(favicon_file_location));
-
-	/* start download */
-	dl = kz_downloader_new_with_filename(favicon_uri, favicon_file_location);
-	if (dl)
-	{
-		g_signal_connect(G_OBJECT(dl), "completed",
-				 G_CALLBACK(cb_downloader_load_complete),
-				 (gpointer)location);
-		g_signal_connect(G_OBJECT(dl), "error",
-				 G_CALLBACK(cb_downloader_load_error),
-				 (gpointer)location);
-		kz_downloader_to_file(dl);
-	}
-
-	g_free(hash_key);
-	g_free(favicon_file_location);
+	priv->n_favicon++;
 }
 
 
@@ -292,10 +217,10 @@ idle_unref_dl(gpointer data)
 static void
 kz_downloader_disconnect_signal(KzDownloader *dl, const gchar *uri)
 {
-	g_signal_handlers_disconnect_by_func(G_OBJECT(dl),
+	g_signal_handlers_disconnect_by_func(dl,
 					     G_CALLBACK(cb_downloader_load_complete),
 					     (gpointer)uri);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(dl),
+	g_signal_handlers_disconnect_by_func(dl,
 					     G_CALLBACK(cb_downloader_load_error),
 					     (gpointer)uri);
 }
@@ -311,7 +236,7 @@ cb_downloader_load_complete (KzDownloader *dl, const gchar *uri)
 	g_idle_add(idle_unref_dl, dl);
 
 	/* FIXME! Do not use kzfavicon_sigle object! */
-	g_signal_emit(G_OBJECT(kzfavicon_single),
+	g_signal_emit(kzfavicon_single,
 		      kz_favicon_signals[READY_SIGNAL],
 		      quark,
 		      uri);	
@@ -323,44 +248,30 @@ cb_downloader_load_error (KzDownloader *dl, const gchar *uri)
 {
 	gchar *hash_key;
 	KzFavicon *kzfav = kzfavicon_single;
+	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
 
 	kz_downloader_disconnect_signal(dl, uri);
 	g_idle_add(idle_unref_dl, dl);
 
 	hash_key = create_profile_key_from_uri(uri);
-	g_hash_table_remove(kzfav->priv->uri_hash, hash_key);
+	g_hash_table_remove(priv->uri_hash, hash_key);
 	g_free(hash_key);	
 }
 
 
-void
-kz_favicon_connect_signal (KzFavicon *kzfav, KzMozEmbed *kzembed)
-{
-	g_signal_connect(G_OBJECT(kzembed), "favicon",
-			 G_CALLBACK(cb_favicon_uri_notify), kzfav);
-}
-
-
-void
-kz_favicon_disconnect_signal (KzFavicon *kzfav, KzMozEmbed *kzembed)
-{
-	g_signal_handlers_disconnect_by_func(G_OBJECT(kzembed),
-					     G_CALLBACK(cb_favicon_uri_notify), kzfav);
-}
-
-
 GtkWidget *
 kz_favicon_get_widget (KzFavicon *kzfav, const gchar *uri, GtkIconSize size)
 {
 	GtkWidget *icon = NULL;
 	const gchar *favicon_file_name;
 	gchar *hash_key;
+	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
 
 	if (uri == NULL)
 		return NULL;
 
 	hash_key = create_profile_key_from_uri(uri);
-	favicon_file_name = g_hash_table_lookup(kzfav->priv->uri_hash, hash_key);
+	favicon_file_name = g_hash_table_lookup(priv->uri_hash, hash_key);
 	g_free(hash_key);
 
 	if (!favicon_file_name)
@@ -394,12 +305,13 @@ kz_favicon_get_pixbuf (KzFavicon *kzfav, const gchar *uri, GtkIconSize size)
 	GdkPixbuf *icon = NULL;
 	const gchar *favicon_file_name;
 	gchar *hash_key;
+	KzFaviconPrivate *priv = KZ_FAVICON_GET_PRIVATE (kzfav);
 
 	if (uri == NULL)
 		return NULL;
 
 	hash_key = create_profile_key_from_uri(uri);
-	favicon_file_name = g_hash_table_lookup(kzfav->priv->uri_hash, hash_key);
+	favicon_file_name = g_hash_table_lookup(priv->uri_hash, hash_key);
 	g_free(hash_key);
 
 	if (!favicon_file_name)
@@ -424,3 +336,68 @@ kz_favicon_get_pixbuf (KzFavicon *kzfav, const gchar *uri, GtkIconSize size)
 
 	return icon;
 }
+
+void
+kz_favicon_get_icon_from_uri (KzFavicon *kzfav, 
+			      const gchar *uri,
+			      const gchar *document_uri)
+{
+	gchar *favicon_filename;
+	gchar *favicon_file_location;
+	gchar *hash_key;
+	const gchar *old_value;
+	KzDownloader *dl;
+	KzFaviconPrivate *priv;
+
+ 	g_return_if_fail(KZ_IS_FAVICON(kzfav));
+	priv = KZ_FAVICON_GET_PRIVATE (kzfav);
+
+	if (!uri) return;
+	hash_key = create_profile_key_from_uri(document_uri);
+
+	favicon_filename = create_filename_from_uri(uri);
+	favicon_file_location = g_build_filename(g_get_home_dir(),
+					    	 "."PACKAGE,
+						 "favicon",
+					    	 favicon_filename,
+					    	 NULL);
+	g_free(favicon_filename);
+	
+	old_value = g_hash_table_lookup(priv->uri_hash,
+					hash_key);
+	
+	if (old_value && !strcmp(old_value, favicon_file_location))
+	{
+		GQuark quark;
+		quark = g_quark_from_string(document_uri);
+		
+		g_signal_emit(kzfav,
+			      kz_favicon_signals[READY_SIGNAL],
+			      quark,
+			      document_uri);
+		g_free(hash_key);
+		g_free(favicon_file_location);
+		return;
+	}
+
+	g_hash_table_insert(priv->uri_hash,
+			    g_strdup(hash_key),
+			    g_strdup(favicon_file_location));
+
+	/* start download */
+	dl = kz_downloader_new_with_filename(uri, favicon_file_location);
+	if (dl)
+	{
+		g_signal_connect(dl, "completed",
+				 G_CALLBACK(cb_downloader_load_complete),
+				 (gpointer)document_uri);
+		g_signal_connect(dl, "error",
+				 G_CALLBACK(cb_downloader_load_error),
+				 (gpointer)document_uri);
+		kz_downloader_to_file(dl);
+	}
+
+	g_free(hash_key);
+	g_free(favicon_file_location);
+}
+
