@@ -35,6 +35,7 @@
 #include "prefs_ui/prefs_tab.h"
 #include "prefs_ui/prefs_key_accel.h"
 #include "prefs_ui/prefs_gesture.h"
+#include "prefs_ui/prefs_entry.h"
 #include "prefs_ui/prefs_proxy.h"
 #include "prefs_ui/prefs_ui_editor.h"
 #include "prefs_ui/prefs_privacy.h"
@@ -135,11 +136,12 @@ kz_prefs_win_class_init (KzPrefsWinClass *klass)
 	ADD_PAGE_ENTRY(prefs_lang_get_entry);
 	ADD_PAGE_ENTRY(prefs_font_get_entry);
 	ADD_PAGE_ENTRY(prefs_tab_get_entry);
+	ADD_PAGE_ENTRY(prefs_entry_get_entry);
 	ADD_PAGE_ENTRY(prefs_key_accel_get_entry);
 	ADD_PAGE_ENTRY(prefs_gesture_get_entry);
 	ADD_PAGE_ENTRY(prefs_proxy_get_entry);
 	ADD_PAGE_ENTRY(prefs_privacy_get_entry); 
-	/* ADD_PAGE_ENTRY(prefs_ui_editor_get_entry); */ 
+	ADD_PAGE_ENTRY(prefs_ui_editor_get_entry); 
 	ADD_PAGE_ENTRY(prefs_external_program_get_entry);
 	ADD_PAGE_ENTRY(prefs_history_get_entry);
 }
@@ -205,7 +207,7 @@ kz_prefs_win_init (KzPrefsWin *win)
 	kz_prefs_win_reset_nav_tree(win);
 
 	/* observe UI Level */
-	g_signal_connect(G_OBJECT(kz_global_profile),
+	g_signal_connect(kz_global_profile,
 			 "changed::Global",
 			 G_CALLBACK(cb_profile_global_changed), win);
 }
@@ -216,7 +218,7 @@ kz_prefs_win_dispose (GObject *object)
 	KzPrefsWin *win = KZ_PREFS_WIN(object);
 
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_global_profile),
+		(kz_global_profile,
 		 G_CALLBACK(cb_profile_global_changed), win);
 
 	if (win->priv->page_list)
@@ -270,8 +272,6 @@ kz_prefs_win_response (GtkDialog *dialog, gint arg)
 static gboolean 
 kz_prefs_win_delete_event (GtkWidget *widget, GdkEventAny *event)
 {
-	g_return_val_if_fail(KZ_IS_PREFS_WIN(widget), FALSE);
-	
 	kz_prefs_win_store_state(KZ_PREFS_WIN(widget));
 	
 	return FALSE;
@@ -388,9 +388,9 @@ kz_prefs_win_create_nav_tree (KzPrefsWin *win)
 	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree), TRUE);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree), FALSE);
 
-	g_signal_connect (G_OBJECT (tree), "key_press_event",
+	g_signal_connect (tree, "key_press_event",
 			  G_CALLBACK (cb_tree_key_press), win);
-	g_signal_connect (G_OBJECT (tree), "cursor_changed",
+	g_signal_connect (tree, "cursor_changed",
 			  G_CALLBACK (cb_tree_cursor_changed), win);
 
 	/* name column */
@@ -627,7 +627,7 @@ kz_prefs_win_set_ui_level (KzPrefsWin *win)
 		response = KZ_RESPONSE_UI_LEVEL_BEGINNER;
 		break;
 	}
-	g_signal_emit_by_name(G_OBJECT(win), "response",
+	g_signal_emit_by_name(win, "response",
 			      response);
 }
 
@@ -641,8 +641,6 @@ cb_tree_key_press (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	GtkTreePath *treepath;
 	gboolean success, retval = FALSE;
 
-	g_return_val_if_fail (GTK_IS_TREE_VIEW (widget), FALSE);
-
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
 	if (!selection) return FALSE;
 	success = gtk_tree_selection_get_selected (selection, &model, &iter);
@@ -688,7 +686,6 @@ cb_tree_cursor_changed (GtkTreeView *treeview, gpointer data)
 	GtkTreeIter iter;
 	KzPrefsWinPagePriv *priv;
 
-	g_return_if_fail(treeview);
 	g_return_if_fail(KZ_IS_PREFS_WIN(data));
 
 	win = KZ_PREFS_WIN(data);
@@ -713,7 +710,6 @@ cb_profile_global_changed (KzProfile *profile,
 			   const gchar *old_value,
 			   KzPrefsWin *win)
 {
-	g_return_if_fail(KZ_IS_PROFILE(profile));
 	g_return_if_fail(KZ_IS_PREFS_WIN(win));
 
 	kz_prefs_win_reset_nav_tree(win);
