@@ -115,11 +115,6 @@ static void     cb_profile_changed              (KzProfile *profile,
 						 const gchar *key,
 						 const gchar *old_value,
 						 KzTabLabel *kztab);
-#if 0
-static void     cb_favicon_changed              (KzFavicon *kzfav,
-						 gchar *uri,
-						 KzTabLabel *kztab);
-#endif
 
 /* callbacks for embed */
 static void cb_title_changed (KzEmbed *embed, KzTabLabel *kztab);
@@ -266,7 +261,7 @@ kz_tab_label_init (KzTabLabel *kztab)
 
 	/* close button */
 	gtk_button_set_relief(GTK_BUTTON(kztab->close_button), GTK_RELIEF_NONE);
-	g_signal_connect(G_OBJECT(kztab->close_button), "clicked", 
+	g_signal_connect(kztab->close_button, "clicked", 
 			 G_CALLBACK(cb_close_button_clicked), kztab);
 
 	close_image = gtk_image_new_from_stock(GTK_STOCK_CLOSE,
@@ -312,7 +307,7 @@ kz_tab_label_init (KzTabLabel *kztab)
                           url_drag_types,n_url_drag_types,
 			  GDK_ACTION_MOVE);
 
-	g_signal_connect(G_OBJECT(kz_global_profile), "changed::Tab",
+	g_signal_connect(kz_global_profile, "changed::Tab",
 			 G_CALLBACK(cb_profile_changed), kztab);
 	kz_tab_label_sync_to_profile(kztab);
 	kz_tab_label_set_text(kztab, NULL);
@@ -334,15 +329,15 @@ kz_tab_label_constructor (GType                  type,
 	kztab = KZ_TAB_LABEL(object);
 
 	/* set signals */
-	g_signal_connect(G_OBJECT(kztab->kzembed), "kz-title",
+	g_signal_connect(kztab->kzembed, "kz-title",
 			 G_CALLBACK(cb_title_changed), kztab);
-	g_signal_connect(G_OBJECT(kztab->kzembed), "kz-net-start",
+	g_signal_connect(kztab->kzembed, "kz-net-start",
 			 G_CALLBACK(cb_net_start), kztab);
-	g_signal_connect(G_OBJECT(kztab->kzembed), "kz-net-stop",
+	g_signal_connect(kztab->kzembed, "kz-net-stop",
 			 G_CALLBACK(cb_net_stop), kztab);
-	g_signal_connect(G_OBJECT(kztab->kzembed), "kz-progress",
+	g_signal_connect(kztab->kzembed, "kz-progress",
 			 G_CALLBACK(cb_progress), kztab);
-	g_signal_connect(G_OBJECT(kztab->kzembed), "destroy",
+	g_signal_connect(kztab->kzembed, "destroy",
 			 G_CALLBACK(cb_destroy), kztab);
 
 	/* set label text */
@@ -359,25 +354,23 @@ kz_tab_label_dispose (GObject *object)
 {
 	KzTabLabel *kztab;
 
-	g_return_if_fail (KZ_IS_TAB_LABEL(object));
-
 	kztab = KZ_TAB_LABEL(object);
 
-	g_signal_handlers_disconnect_by_func(G_OBJECT(kz_global_profile),
+	g_signal_handlers_disconnect_by_func(kz_global_profile,
 					     G_CALLBACK(cb_profile_changed),
 					     kztab);
 	if (kztab->kzembed)
 	{
 	
-		g_signal_handlers_disconnect_by_func(G_OBJECT(kztab->kzembed),
+		g_signal_handlers_disconnect_by_func(kztab->kzembed,
 						     cb_net_start, kztab);
-		g_signal_handlers_disconnect_by_func(G_OBJECT(kztab->kzembed),
+		g_signal_handlers_disconnect_by_func(kztab->kzembed,
 						     cb_net_stop, kztab);
-		g_signal_handlers_disconnect_by_func(G_OBJECT(kztab->kzembed),
+		g_signal_handlers_disconnect_by_func(kztab->kzembed,
 						     cb_title_changed, kztab);
-		g_signal_handlers_disconnect_by_func(G_OBJECT(kztab->kzembed),
+		g_signal_handlers_disconnect_by_func(kztab->kzembed,
 						     cb_progress, kztab);
-		g_signal_handlers_disconnect_by_func(G_OBJECT(kztab->kzembed),
+		g_signal_handlers_disconnect_by_func(kztab->kzembed,
 						     cb_destroy, kztab);
 		g_object_unref(kztab->kzembed);
 		kztab->kzembed = NULL;
@@ -746,7 +739,6 @@ kz_tab_label_drag_motion (GtkWidget *widget,
 	KzEmbed *current_kzembed;
 	gint page_num;
 
-	g_return_val_if_fail(KZ_TAB_LABEL(widget), FALSE);
 	kztab = KZ_TAB_LABEL(widget);
 
 	g_return_val_if_fail (KZ_IS_EMBED(kztab->kzembed), FALSE);
@@ -773,7 +765,6 @@ kz_tab_label_drag_data_get (GtkWidget        *widget,
 	KzTabLabel *kztab;
 	const gchar *uri, *title;
 
-	g_return_if_fail(KZ_IS_TAB_LABEL(widget));
 	kztab = KZ_TAB_LABEL(widget);
 
 	g_return_if_fail (KZ_IS_EMBED(kztab->kzembed));
@@ -849,7 +840,6 @@ kz_tab_label_drag_data_received (GtkWidget *widget,
 {
 	KzTabLabel *kztab;
 
-	g_return_if_fail(KZ_IS_TAB_LABEL(widget));
 	kztab = KZ_TAB_LABEL(widget);
 
 	g_return_if_fail (KZ_IS_EMBED(kztab->kzembed));
@@ -1047,49 +1037,20 @@ cb_title_changed (KzEmbed *embed, KzTabLabel *kztab)
 {
 	gchar *title;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
 	title = kz_embed_ensure_title(kztab->kzembed);
 	kz_tab_label_set_text(kztab, title);
 	g_free(title);
-#if 0
-	if (!kztab->priv->favicon_signal)
-	{
-		gchar *detailed_signal;
-		const gchar *location;
-
-		location = kz_embed_get_location(kztab->kzembed);
-		if (!location)
-			return;
-
-		detailed_signal = g_strdup_printf("ready::%s", location);
-		kztab->priv->favicon_signal = g_signal_connect(G_OBJECT(kztab->kz->kzfav),
-							       detailed_signal,
-							       G_CALLBACK(cb_favicon_changed),
-							       kztab);
-		g_free(detailed_signal);
-	}
-#endif
 }
 
 static void
 cb_net_start (KzEmbed *embed, KzTabLabel *kztab)
 {
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
 	kz_tab_label_set_state(kztab, KZ_TAB_LABEL_STATE_LOADING);
 
-#if 0
-	/* if connected signal exists, disconnect it. */
-	if (kztab->priv->favicon_signal)
-	{
-		g_signal_handler_disconnect(kztab->kz->kzfav,
-					    kztab->priv->favicon_signal);
-		kztab->priv->favicon_signal = 0;
-	}
-#endif
 	if (kztab->favicon_pixbuf)
 	{
 		gtk_image_set_from_pixbuf(GTK_IMAGE(kztab->favicon), NULL);
@@ -1107,7 +1068,6 @@ cb_net_stop (KzEmbed *embed, KzTabLabel *kztab)
 	gboolean show_favicon;
 	gboolean save_session = FALSE;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
 	kz_embed_get_history(KZ_EMBED(embed), 
@@ -1178,7 +1138,6 @@ cb_progress (KzEmbed *embed, KzTabLabel *kztab)
 	GtkWidget *widget;	       
 	GdkGC *gc;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
 	widget = GTK_WIDGET(kztab);
@@ -1226,38 +1185,6 @@ cb_progress (KzEmbed *embed, KzTabLabel *kztab)
 	}
 }
 
-#if 0
-static void
-cb_favicon_changed (KzFavicon *kzfav, gchar *uri, KzTabLabel *kztab)
-{
-	gboolean show_favicon = TRUE;
-	
-	/* if connected signal exists, disconnect it. */
-	if (kztab->priv->favicon_signal)
-	{
-		g_signal_handler_disconnect(kztab->kz->kzfav,
-					    kztab->priv->favicon_signal);
-		kztab->priv->favicon_signal = 0;
-	}
-
-	if (kztab->favicon_pixbuf)
-	{
-		g_object_unref(kztab->favicon_pixbuf);
-		kztab->favicon_pixbuf = NULL;
-	}
-	
-	kztab->favicon_pixbuf = kz_favicon_get_pixbuf(kztab->kz->kzfav, uri,
-						      GTK_ICON_SIZE_MENU);
-	
-	if (kztab->favicon_pixbuf && 
-	    kz_tab_label_get_state(kztab) != KZ_TAB_LABEL_STATE_LOADING)
-	{
-		gtk_image_set_from_pixbuf(GTK_IMAGE(kztab->favicon),
-					  kztab->favicon_pixbuf);
-	}
-}
-#endif
-
 
 gboolean
 kz_tab_label_get_lock (KzTabLabel *kztab)
