@@ -221,6 +221,10 @@ static void     cb_find_keyword               (GtkWidget       *widget,
 static gboolean cb_find_key_release           (GtkWidget       *widget,
 					       GdkEventKey     *event,
 					       KzWindow        *kz);
+#if 0
+static void     cb_find_grab_focus            (GtkWidget       *widget,
+					       KzWindow        *kz);
+#endif
 static void     cb_find_direction_toggle      (GtkToggleButton *button,
 					       KzWindow        *kz);
 static void     cb_gesture_stack_motion       (KzGesture       *gesture,
@@ -233,6 +237,10 @@ static void     cb_sidebar_map                (GtkWidget       *widget,
 					       GtkToggleAction *action);
 static void     cb_sidebar_unmap              (GtkWidget       *widget,
 					       GtkToggleAction *action);
+static void     cb_bookmarkbars_map           (GtkWidget       *widget,
+					       GtkToggleAction *action);
+static void     cb_bookmarkbars_unmap         (GtkWidget       *widget,
+					       GtkToggleAction *action);
 static gboolean cb_focus_out_event            (GtkWidget       *widget,
 					       GdkEventFocus   *event,
 					       KzWindow        *kz);
@@ -385,8 +393,6 @@ kz_window_init (KzWindow *kz)
 	GtkAccelGroup *accel_group;
 	GtkSettings *settings;
 
-	g_return_if_fail(KZ_IS_WINDOW(kz));
-	
 	g_object_set(G_OBJECT(kz), "allow-shrink", TRUE, NULL);
 
 	gtk_window_set_title(GTK_WINDOW(kz), _("Kazehakase"));
@@ -451,13 +457,13 @@ kz_window_init (KzWindow *kz)
 	/* gesture */
 	{
 		kz_window_set_gesture_items(kz);
-		g_signal_connect(G_OBJECT(kz->priv->gesture),
+		g_signal_connect(kz->priv->gesture,
 				 "stack_motion",
 				 G_CALLBACK(cb_gesture_stack_motion), kz);
-		g_signal_connect(G_OBJECT(kz_global_profile),
+		g_signal_connect(kz_global_profile,
 				 "changed::Gesture",
 				 G_CALLBACK(cb_profile_gesture_changed), kz);
-		g_signal_connect(GTK_WINDOW(kz),
+		g_signal_connect(kz,
 				 "focus-out-event",
 				 G_CALLBACK(cb_focus_out_event), kz);
 	}
@@ -471,7 +477,7 @@ kz_window_init (KzWindow *kz)
 
 	/* menu & toolbar */
 	{
-		menu_box = gtk_vbox_new (FALSE, 0);
+		kz->menu_box = menu_box = gtk_vbox_new (FALSE, 0);
 		gtk_box_pack_start(GTK_BOX(kz->top_vbox), menu_box,
 				   FALSE, FALSE, 0);   
 		gtk_widget_show(menu_box);
@@ -491,10 +497,10 @@ kz_window_init (KzWindow *kz)
 	
 		kz_window_sync_ui_level(kz);
 		gtk_ui_manager_ensure_update(kz->menu_merge);
-		g_signal_connect(G_OBJECT(kz_global_profile),
+		g_signal_connect(kz_global_profile,
 				 "changed::Global",
 				 G_CALLBACK(cb_profile_global_changed), kz);
-		g_signal_connect(G_OBJECT(kz_proxy),
+		g_signal_connect(kz_proxy,
 				 "changed",
 				 G_CALLBACK(cb_profile_proxy_changed), kz);
 
@@ -513,13 +519,13 @@ kz_window_init (KzWindow *kz)
 	}
 
 	/* smart bookmark */
-	g_signal_connect_after(G_OBJECT(kz_bookmarks->smarts),
+	g_signal_connect_after(kz_bookmarks->smarts,
 			       "insert-child",
 			       G_CALLBACK(cb_smartbookmark_insert_child), kz);
-	g_signal_connect_after(G_OBJECT(kz_bookmarks->smarts),
+	g_signal_connect_after(kz_bookmarks->smarts,
 			       "remove-child",
 			       G_CALLBACK(cb_smartbookmark_remove_child), kz);
-	g_signal_connect_after(G_OBJECT(kz_bookmarks->smarts),
+	g_signal_connect_after(kz_bookmarks->smarts,
 			       "children-reordered",
 			       G_CALLBACK(cb_smartbookmark_reordered), kz);
 	kz_actions_update_smartbookmarks(kz, kz_bookmarks->smarts);
@@ -527,7 +533,7 @@ kz_window_init (KzWindow *kz)
 	/* bookmark bar */
 	gtk_box_pack_start(GTK_BOX(kz->top_vbox), 
 			   kz->bookmark_bars_area, FALSE, FALSE, 0);
-	gtk_widget_show(kz->bookmark_bars_area);
+	/* gtk_widget_show(kz->bookmark_bars_area); */
 
 	for (node = kz->bookmark_bars;
 	     node;
@@ -538,13 +544,13 @@ kz_window_init (KzWindow *kz)
 		gtk_widget_show(node->data);
 	}
 
-	g_signal_connect_after(G_OBJECT(kz_bookmarks->bookmark_bars),
+	g_signal_connect_after(kz_bookmarks->bookmark_bars,
 			       "insert-child",
 			       G_CALLBACK(cb_bookmark_bars_insert_child), kz);
-	g_signal_connect_after(G_OBJECT(kz_bookmarks->bookmark_bars),
+	g_signal_connect_after(kz_bookmarks->bookmark_bars,
 			       "remove-child",
 			       G_CALLBACK(cb_bookmark_bars_remove_child), kz);
-	g_signal_connect_after(G_OBJECT(kz_bookmarks->bookmark_bars),
+	g_signal_connect_after(kz_bookmarks->bookmark_bars,
 			       "children-reordered",
 			       G_CALLBACK(cb_bookmark_bars_reordered), kz);
 
@@ -559,16 +565,16 @@ kz_window_init (KzWindow *kz)
 	{
 		gtk_notebook_set_show_tabs(GTK_NOTEBOOK(kz->notebook), TRUE);
 		gtk_notebook_set_scrollable(GTK_NOTEBOOK(kz->notebook), TRUE);
-		g_signal_connect(G_OBJECT(kz->notebook), "switch-page", 
+		g_signal_connect(kz->notebook, "switch-page", 
 				 G_CALLBACK(cb_notebook_switch_page), kz);
-		g_signal_connect(G_OBJECT(kz->notebook), "scroll-event",
+		g_signal_connect(kz->notebook, "scroll-event",
 				 G_CALLBACK(cb_notebook_scroll_event), kz);
 
 		gtk_drag_dest_set(GTK_WIDGET(kz->notebook),
 				  GTK_DEST_DEFAULT_ALL,
 				  url_drag_types, G_N_ELEMENTS (url_drag_types),
 				  GDK_ACTION_MOVE);
-		g_signal_connect(G_OBJECT(kz->notebook), "drag-data-received",
+		g_signal_connect(kz->notebook, "drag-data-received",
 				 G_CALLBACK(cb_notebook_drag_data_received),
 				 kz);
 		gtk_paned_add2(GTK_PANED(kz->pane), kz->notebook);
@@ -583,10 +589,16 @@ kz_window_init (KzWindow *kz)
 			GtkAction *action;
 			action = gtk_action_group_get_action(kz->actions,
 							     "ShowHideSidebar");
-			g_signal_connect(G_OBJECT(kz->sidebar), "map",
+			g_signal_connect(kz->sidebar, "map",
 					 G_CALLBACK(cb_sidebar_map), action);
-			g_signal_connect(G_OBJECT(kz->sidebar), "unmap",
+			g_signal_connect(kz->sidebar, "unmap",
 					 G_CALLBACK(cb_sidebar_unmap), action);
+			action = gtk_action_group_get_action(kz->actions,
+							     "ShowHideBookmarkbars");
+			g_signal_connect(kz->bookmark_bars_area, "map",
+					 G_CALLBACK(cb_bookmarkbars_map), action);
+			g_signal_connect(kz->bookmark_bars_area, "unmap",
+					 G_CALLBACK(cb_bookmarkbars_unmap), action);
 		}
 
 		/* embed tab */
@@ -618,9 +630,9 @@ kz_window_init (KzWindow *kz)
 		kz_entry_set_icon_from_stock(KZ_ENTRY(kz->find_area),
 					     GTK_STOCK_FIND,
 					     GTK_ICON_SIZE_MENU);
-		g_signal_connect(G_OBJECT(GTK_ENTRY(kz->find_area)), "activate",
+		g_signal_connect(kz->find_area, "activate",
 				 G_CALLBACK(cb_find_keyword), kz);
-		g_signal_connect(G_OBJECT(toggle), "toggled",
+		g_signal_connect(toggle, "toggled",
 				 G_CALLBACK(cb_find_direction_toggle), kz);
 
 		g_object_ref(G_OBJECT(tips));
@@ -636,9 +648,14 @@ kz_window_init (KzWindow *kz)
 
 		gtk_box_pack_start(GTK_BOX(kz->statusbar_area), kz->find_area,
 				   FALSE, FALSE, 0); 
-		g_signal_connect(G_OBJECT(GTK_ENTRY(kz->find_area)), 
+		g_signal_connect(kz->find_area, 
 				 "key-release-event",
 				 G_CALLBACK(cb_find_key_release), kz);
+		/*
+		g_signal_connect(kz->find_area, 
+				 "grab-focus",
+				 G_CALLBACK(cb_find_grab_focus), kz);
+		*/
 		gtk_widget_show(kz->find_area);
 
 		g_object_ref(G_OBJECT(tips));
@@ -739,25 +756,33 @@ kz_window_sync_ui_level (KzWindow *kz)
 	GtkAction *action;
 	const gchar *action_str;
 	GError *err = NULL;
-	gchar *ui_file, *level = NULL;
+	gchar *ui_file;
 	GtkWidget *widget;
 	KzEmbed *kzembed;
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	switch (kz_ui_level()) {
+	switch (kz_ui_level()) 
+	{
 	case KZ_UI_LEVEL_CUSTOM:
 		action_str = "UILevelCustom";
+		ui_file = g_build_filename(g_get_home_dir(),
+				           "."PACKAGE,
+					   "kz-ui.xml",
+				           NULL);
 		break;
 	case KZ_UI_LEVEL_EXPERT:
 		action_str = "UILevelExpert";
+		ui_file = g_strdup(KZ_SYSCONFDIR"/kz-ui-expert.xml");
 		break;
 	case KZ_UI_LEVEL_MEDIUM:
 		action_str = "UILevelMedium";
+		ui_file = g_strdup(KZ_SYSCONFDIR"/kz-ui-medium.xml");
 		break;
 	case KZ_UI_LEVEL_BEGINNER:
 	default:
 		action_str = "UILevelBeginner";
+		ui_file = g_strdup(KZ_SYSCONFDIR"/kz-ui-beginner.xml");
 		break;
 	}
 
@@ -765,10 +790,7 @@ kz_window_sync_ui_level (KzWindow *kz)
 	if (!gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action)))
 		gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), TRUE);
 
-
-	level = KZ_CONF_GET_STR("Global", "ui_level");
-
-	if (kz->priv->merge_id)
+	if (kz->priv->merge_id != 0)
 	{
 		gtk_ui_manager_remove_ui(kz->menu_merge, kz->priv->merge_id);
 		kz->priv->merge_id = 0;
@@ -776,17 +798,6 @@ kz_window_sync_ui_level (KzWindow *kz)
         	gtk_ui_manager_ensure_update(kz->menu_merge);
 	}
 
-	if (level && !strcmp(level, "custom"))
-		ui_file = g_strconcat(g_get_home_dir(),
-				      "/.kazehakase/kz-ui.xml",
-				      NULL);
-	else if (level && !strcmp(level, "expert"))
-		ui_file = g_strdup(KZ_SYSCONFDIR"/kz-ui-expert.xml");
-	else if (level && !strcmp(level, "medium"))
-		ui_file = g_strdup(KZ_SYSCONFDIR"/kz-ui-medium.xml");
-	else
-		ui_file = g_strdup(KZ_SYSCONFDIR"/kz-ui-beginner.xml");
-
 	kz->priv->merge_id
 		= gtk_ui_manager_add_ui_from_file(kz->menu_merge,
 						  ui_file, &err);
@@ -853,7 +864,6 @@ kz_window_sync_ui_level (KzWindow *kz)
 	kz_actions_update_smartbookmarks(kz, kz_bookmarks->smarts);
 
 	g_free(ui_file);
-	g_free(level);
 }
 
 void
@@ -977,7 +987,7 @@ kz_window_open_new_tab_at_tail (KzWindow *kz, const gchar *url)
 
 	kz_bookmark_append(kz->tabs, kztab->history);
 
-	g_signal_emit(G_OBJECT(kz), kz_window_signals[APPEND_TAB_SIGNAL],
+	g_signal_emit(kz, kz_window_signals[APPEND_TAB_SIGNAL],
 		      0, kzembed, NULL);
 
 	return GTK_WIDGET(kzembed);
@@ -1051,6 +1061,7 @@ kz_window_open_new_tab_with_parent (KzWindow *kz, const gchar *url,
 	gint pos;
 
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), NULL);
+	if (url) g_return_val_if_fail(g_utf8_validate(url, strlen(url), NULL), NULL);
 
 	kzembed = kz_window_create_embed(kz, url);
 	kztab = KZ_TAB_LABEL(kz_tab_label_new(kz, kzembed));
@@ -1092,7 +1103,7 @@ kz_window_open_new_tab_with_parent (KzWindow *kz, const gchar *url,
 	else
 		g_node_append(kz->priv->tab_tree, node);
 
-	g_signal_emit(G_OBJECT(kz), kz_window_signals[APPEND_TAB_SIGNAL],
+	g_signal_emit(kz, kz_window_signals[APPEND_TAB_SIGNAL],
 		      0, kzembed, parent);
 
 	return GTK_WIDGET(kzembed);
@@ -1235,7 +1246,7 @@ kz_window_reorder_tab (KzWindow *kz, GtkWidget *widget, gint pos)
 
 	kz_window_store_session(kz);
 
-	g_signal_emit(G_OBJECT(kz), kz_window_signals[REORDER_TAB_SIGNAL],
+	g_signal_emit(kz, kz_window_signals[REORDER_TAB_SIGNAL],
 		      0, widget, pos);
 }
 
@@ -1315,10 +1326,10 @@ kz_window_move_tab (KzWindow *kz, GtkWidget *widget)
 			kz->priv->tab_tree = g_node_new(NULL);
 		g_node_append(kz->priv->tab_tree, node);
 		
-		g_signal_emit(G_OBJECT(src_kz),
+		g_signal_emit(src_kz,
 			      kz_window_signals[REMOVE_TAB_SIGNAL],
 			      0, kzembed);
-		g_signal_emit(G_OBJECT(kz),
+		g_signal_emit(kz,
 			      kz_window_signals[APPEND_TAB_SIGNAL],
 			      0, kzembed, NULL);
 	}
@@ -1334,8 +1345,6 @@ kz_window_delete_event (GtkWidget *widget, GdkEventAny *event)
 {
 	KzWindow *kz;
 
-	g_return_val_if_fail(KZ_IS_WINDOW(widget), FALSE);
-
 	kz = KZ_WINDOW(widget);
 
 	kz_window_store_state(kz);
@@ -1377,8 +1386,6 @@ kz_window_key_press_event(GtkWidget *widget, GdkEventKey *event)
 	gboolean handled;
 	guint modifier;
 
-	g_return_val_if_fail(KZ_IS_WINDOW(widget), FALSE);
-
 	kz = KZ_WINDOW(widget);
 
 	/* In an attempt to get the mozembed playing nice with things like emacs keybindings
@@ -1474,8 +1481,6 @@ kz_window_destroy (GtkObject *object)
 {
 	KzWindow *kz = KZ_WINDOW(object);
 
-	g_return_if_fail (KZ_IS_WINDOW(kz));
-
 	if (GTK_OBJECT_CLASS (parent_class)->destroy)
 		GTK_OBJECT_CLASS (parent_class)->destroy(object);
 
@@ -1544,33 +1549,33 @@ kz_window_destroy (GtkObject *object)
 	kz->history_search = NULL;
 
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_bookmarks->bookmark_bars),
+		(kz_bookmarks->bookmark_bars,
 		 G_CALLBACK(cb_bookmark_bars_insert_child), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_bookmarks->bookmark_bars),
+		(kz_bookmarks->bookmark_bars,
 		 G_CALLBACK(cb_bookmark_bars_remove_child), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_bookmarks->bookmark_bars),
+		(kz_bookmarks->bookmark_bars,
 		 G_CALLBACK(cb_bookmark_bars_reordered), kz);
 
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_bookmarks->smarts),
+		(kz_bookmarks->smarts,
 		 G_CALLBACK(cb_smartbookmark_insert_child), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_bookmarks->smarts),
+		(kz_bookmarks->smarts,
 		 G_CALLBACK(cb_smartbookmark_remove_child), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_bookmarks->smarts),
+		(kz_bookmarks->smarts,
 		 G_CALLBACK(cb_smartbookmark_reordered), kz);
 
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_global_profile),
+		(kz_global_profile,
 		 G_CALLBACK(cb_profile_global_changed), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_global_profile),
+		(kz_global_profile,
 		 G_CALLBACK(cb_profile_gesture_changed), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz_proxy),
+		(kz_proxy,
 		 G_CALLBACK(cb_profile_proxy_changed), kz);
 
 	if (!kz_window_get_window_list())
@@ -1633,7 +1638,7 @@ cb_window_map (KzWindow *kz, GtkAction *action)
 {
 	gtk_action_activate(action);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz), G_CALLBACK(cb_window_map), action);
+		(kz, G_CALLBACK(cb_window_map), action);
 }
 
 
@@ -1667,7 +1672,7 @@ kz_window_restore_session (KzWindow *kz)
 		if (GTK_WIDGET_MAPPED(kz))
 			gtk_action_activate(action);
 		else
-			g_signal_connect(G_OBJECT(kz), "map",
+			g_signal_connect(kz, "map",
 					 G_CALLBACK(cb_window_map), action);
 	}
 }
@@ -1739,6 +1744,12 @@ kz_window_store_state (KzWindow *kz)
 	active = gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action));
 	KZ_CONF_SET("MainWindow", "show_sidebar", active, BOOL);
 
+	/* bookmarkbar */
+	action = gtk_action_group_get_action(kz->actions,
+					     "ShowHideBookmarkbars");
+	active = gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action));
+	KZ_CONF_SET("MainWindow", "show_bookmarkbars", active, BOOL);
+
 
 	/*
 	 * tab position
@@ -1771,7 +1782,7 @@ kz_window_restore_state (KzWindow *kz)
 {
 	GtkAction *action = NULL;
 	gint width = 640, height = 450, sidebar_width = 150;
-	gboolean active = FALSE;
+	gboolean active = FALSE, bookmarkbar = TRUE;
 	gchar *tab_pos, *label, *sidebar_pos;
 	gint i;
 
@@ -1802,26 +1813,31 @@ kz_window_restore_state (KzWindow *kz)
 	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), active);
 	if (active)
 	{
-	sidebar_pos = KZ_CONF_GET_STR("MainWindow", "sidebar_pos");
-	for (i = 0; sidebar_pos && i < G_N_ELEMENTS(positems); i++)
-	{
-		if (strcasecmp(sidebar_pos, positems[i].pos)) continue;
+		sidebar_pos = KZ_CONF_GET_STR("MainWindow", "sidebar_pos");
+		for (i = 0; sidebar_pos && i < G_N_ELEMENTS(positems); i++)
+		{
+			if (strcasecmp(sidebar_pos, positems[i].pos)) continue;
 
-		/* width */
-		KZ_CONF_GET("MainWindow", "sidebar_width", sidebar_width, INT);
-		action = gtk_action_group_get_action(kz->actions,
-						     positems[i].sidebar_act);
-		gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action),
-					     TRUE);
-		/*
-		 * On startup time, allocation.width and allocation.height are not set
-		 * correctly(maybe both 1), so we should use sidebar or notebook width
-		 * according to sidebar position.
-		 */
-		gtk_paned_set_position(GTK_PANED(kz->pane), sidebar_width);
-	}
-	g_free(sidebar_pos);
+			/* width */
+			KZ_CONF_GET("MainWindow", "sidebar_width", sidebar_width, INT);
+			action = gtk_action_group_get_action(kz->actions,
+							     positems[i].sidebar_act);
+			gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action),
+						     TRUE);
+			/*
+			 * On startup time, allocation.width and allocation.height are not set
+			 * correctly(maybe both 1), so we should use sidebar or notebook width
+			 * according to sidebar position.
+			 */
+			gtk_paned_set_position(GTK_PANED(kz->pane), sidebar_width);
+		}
+		g_free(sidebar_pos);
 	}
+	KZ_CONF_GET("MainWindow", "show_bookmarkbars", bookmarkbar, BOOL);
+	action = gtk_action_group_get_action(kz->actions,
+					     "ShowHideBookmarkbars");
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), bookmarkbar);
+	
 	/*
 	 * tab position
 	 */
@@ -1846,48 +1862,48 @@ kz_window_set_cur_embed_callbacks(KzWindow *kz, KzEmbed *kzembed)
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 	g_return_if_fail(KZ_IS_EMBED(kzembed));
 
-	g_signal_connect(G_OBJECT(kz),
+	g_signal_connect(kz,
 			 "motion_notify_event",
 			 G_CALLBACK(cb_window_motion_notify_event), kzembed);
-	g_signal_connect(G_OBJECT(kz),
+	g_signal_connect(kz,
 			 "button_release_event",
 			 G_CALLBACK(cb_window_button_release_event), kzembed);
 
 	/*
 	 * key event signal
 	 */
-	g_signal_connect(G_OBJECT(kzembed),
+	g_signal_connect(kzembed,
 			 "kz-dom-key-down",
 			 G_CALLBACK(cb_embed_dom_key_down), kz);
-	g_signal_connect(G_OBJECT(kzembed),
+	g_signal_connect(kzembed,
 			 "kz-dom-key-up",
 			 G_CALLBACK(cb_embed_dom_key_up), kz);
 
 	/*
 	 * mouse event signal
 	 */
-	g_signal_connect(G_OBJECT(kzembed),
+	g_signal_connect(kzembed,
 			 "kz-dom-mouse-down",
 			 G_CALLBACK(cb_embed_dom_mouse_down), kz);
-	g_signal_connect(G_OBJECT(kzembed),
+	g_signal_connect(kzembed,
 			 "kz-dom-mouse-up",
 			 G_CALLBACK(cb_embed_dom_mouse_up), kz);
-	g_signal_connect(G_OBJECT(kzembed),
+	g_signal_connect(kzembed,
 			 "kz-dom-mouse-over",
 			 G_CALLBACK(cb_embed_dom_mouse_over), kz);
-	g_signal_connect(G_OBJECT(kzembed), "kz-dom-mouse-click",
+	g_signal_connect(kzembed, "kz-dom-mouse-click",
 			 G_CALLBACK(cb_embed_dom_mouse_click), kz);
-	g_signal_connect(G_OBJECT(kzembed), "kz-dom-mouse-dbl-click",
+	g_signal_connect(kzembed, "kz-dom-mouse-dbl-click",
 			 G_CALLBACK(cb_embed_dom_mouse_dbl_click), kz);
 
 	/*
 	 * other callbacks
 	 */
-	g_signal_connect(G_OBJECT(kzembed), "kz-title",
+	g_signal_connect(kzembed, "kz-title",
 			 G_CALLBACK(cb_embed_title_changed), kz);
-	g_signal_connect(G_OBJECT(kzembed), "kz-location",
+	g_signal_connect(kzembed, "kz-location",
 			 G_CALLBACK(cb_embed_location_changed), kz);
-	g_signal_connect(G_OBJECT(kzembed), "kz-link-message",
+	g_signal_connect(kzembed, "kz-link-message",
 			 G_CALLBACK(cb_embed_link_message), kz);
 }
 
@@ -1899,52 +1915,52 @@ kz_window_unset_cur_embed_callbacks(KzWindow *kz, KzEmbed *kzembed)
 	g_return_if_fail(KZ_IS_EMBED(kzembed));
 
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz),
+		(kz,
 		 G_CALLBACK(cb_window_motion_notify_event), kzembed);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kz),
+		(kz,
 		 G_CALLBACK(cb_window_button_release_event), kzembed);
 
 	/*
 	 * key event signal
 	 */
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_dom_key_down), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_dom_key_up), kz);
 
 	/*
 	 * mouse event signal
 	 */
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_dom_mouse_down), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_dom_mouse_up), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_dom_mouse_over), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_dom_mouse_click), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_dom_mouse_dbl_click), kz);
 
 	/*
 	 * other callbacks
 	 */
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_title_changed), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_location_changed), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_link_message), kz);
 }
 
@@ -1958,13 +1974,13 @@ kz_window_set_embed_callbacks(KzWindow *kz, KzEmbed *kzembed)
 	/*
 	 * other callbacks
 	 */
-	g_signal_connect(G_OBJECT(kzembed), "kz-net-start",
+	g_signal_connect(kzembed, "kz-net-start",
 			 G_CALLBACK(cb_embed_load_started), kz);
-	g_signal_connect(G_OBJECT(kzembed), "kz-net-stop",
+	g_signal_connect(kzembed, "kz-net-stop",
 			 G_CALLBACK(cb_embed_load_finished), kz);
-	g_signal_connect(G_OBJECT(kzembed), "kz-new-window",
+	g_signal_connect(kzembed, "kz-new-window",
 			 G_CALLBACK(cb_embed_new_window), kz);
-	g_signal_connect(G_OBJECT(kzembed), "destroy",
+	g_signal_connect(kzembed, "destroy",
 			 G_CALLBACK(cb_embed_close_tab), kz);
 }
 
@@ -1979,16 +1995,16 @@ kz_window_unset_embed_callbacks(KzWindow *kz, KzEmbed *kzembed)
 	 * other callbacks
 	 */
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_load_started), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_load_finished), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_new_window), kz);
 	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(kzembed),
+		(kzembed,
 		 G_CALLBACK(cb_embed_close_tab), kz);
 }
 
@@ -2085,7 +2101,6 @@ cb_profile_global_changed (KzProfile *profile,
 			   const gchar *old_value,
 			   KzWindow *kz)
 {
-	g_return_if_fail(KZ_IS_PROFILE(profile));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	switch (key[0])
@@ -2117,7 +2132,6 @@ cb_profile_proxy_changed (KzProfile *profile,
 			  const gchar *old_value,
 			  KzWindow *kz)
 {
-	g_return_if_fail(KZ_IS_PROFILE(profile));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kz_window_sync_proxy(kz);
@@ -2129,7 +2143,6 @@ cb_profile_gesture_changed (KzProfile *profile,
 			   const gchar *old_value,
 			   KzWindow *kz)
 {
-	g_return_if_fail(KZ_IS_PROFILE(profile));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kz_window_set_gesture_items(kz);
@@ -2145,7 +2158,6 @@ cb_bookmark_bars_insert_child (KzBookmark *bookmark,
 	GList *children;
 	gint pos;
 
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_BOOKMARK(child));
 	g_return_if_fail(KZ_IS_BOOKMARK(sibling));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
@@ -2170,7 +2182,6 @@ cb_bookmark_bars_remove_child (KzBookmark *bookmark, KzBookmark *child,
 {
 	GList *node;
 
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_BOOKMARK(child));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
@@ -2223,7 +2234,6 @@ cb_bookmark_bars_reordered (KzBookmark *bookmark, KzWindow *kz)
 	GList *children, *node;
 	gint pos = 0;
 
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	children = kz_bookmark_get_children(bookmark);
@@ -2253,7 +2263,6 @@ cb_smartbookmark_insert_child (KzBookmark *bookmark,
 			       KzBookmark *child, KzBookmark *sibling,
 			       KzWindow *kz)
 {
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_BOOKMARK(child));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
@@ -2265,7 +2274,6 @@ static void
 cb_smartbookmark_remove_child (KzBookmark *bookmark, KzBookmark *child,
 			       KzWindow *kz)
 {
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_BOOKMARK(child));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
@@ -2276,7 +2284,6 @@ cb_smartbookmark_remove_child (KzBookmark *bookmark, KzBookmark *child,
 static void
 cb_smartbookmark_reordered (KzBookmark *bookmark, KzWindow *kz)
 {
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kz_actions_update_smartbookmarks(kz, bookmark);	
@@ -2413,9 +2420,8 @@ search_found(GtkWidget* widget, KzWindow *kz)
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	if(kz->statusbar)
-		gtk_statusbar_push(GTK_STATUSBAR(kz->statusbar),
-				   STATUS_SEARCH,
-				   "");
+		gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar),
+				  STATUS_SEARCH);
 	gtk_widget_modify_base(widget, GTK_STATE_NORMAL, &white);
 	gtk_widget_modify_text(widget, GTK_STATE_NORMAL, &black);
 }
@@ -2432,10 +2438,14 @@ search_not_found(GtkWidget* widget, KzWindow *kz)
 
 	search_word = gtk_entry_get_text(GTK_ENTRY(widget));
 	message = g_strdup_printf(_("%s not found"), search_word);
-	if(kz->statusbar)
+	if(kz->statusbar) 
+	{
+		gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar),
+				  STATUS_SEARCH);
 		gtk_statusbar_push(GTK_STATUSBAR(kz->statusbar),
 				   STATUS_SEARCH,
 				   message);
+	}
 	g_free(message);
 
 	gtk_widget_modify_base(widget, GTK_STATE_NORMAL, &red);
@@ -2450,6 +2460,8 @@ cb_find_keyword (GtkWidget *widget, KzWindow *kz)
 	const gchar *text = gtk_entry_get_text(GTK_ENTRY(widget));
 	gboolean back = gtk_toggle_button_get_active(toggle);
 
+	if (!embed) return;
+
 	if (!text || !(*text))
 	{
 		search_found(widget, kz);
@@ -2473,6 +2485,8 @@ cb_find_key_release (GtkWidget *widget, GdkEventKey *event, KzWindow *kz)
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
 
 	embed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz));
+	if (!embed) return FALSE;
+
 	toggle = GTK_TOGGLE_BUTTON(kz->find_direction);
 	text = gtk_entry_get_text(GTK_ENTRY(widget));
 	if (!text || !(*text))
@@ -2509,13 +2523,23 @@ cb_find_key_release (GtkWidget *widget, GdkEventKey *event, KzWindow *kz)
 	return FALSE;
 }
 
+#if 0
+static void
+cb_find_grab_focus (GtkWidget *widget, KzWindow *kz)
+{
+	KzEmbed *embed ;
+
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+	g_warning("grab");
+}
+#endif
+
 static void
 cb_find_direction_toggle (GtkToggleButton *button, KzWindow *kz)
 {
 	GtkArrow *arrow;
 	gboolean active;
 
-	g_return_if_fail(GTK_IS_TOGGLE_BUTTON(button));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	arrow = GTK_ARROW(GTK_BIN(button)->child);
@@ -2536,7 +2560,6 @@ cb_gesture_stack_motion (KzGesture *gesture, KzGestureMotion motion,
 	const gchar *label;
 	gchar buf1[256], buf2[256];
 
-	g_return_if_fail(KZ_IS_GESTURE(gesture));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kz_gesture_create_gesture_string(gesture, buf1, G_N_ELEMENTS(buf1));
@@ -2548,6 +2571,7 @@ cb_gesture_stack_motion (KzGesture *gesture, KzGestureMotion motion,
 		g_snprintf(buf2, G_N_ELEMENTS(buf2),
 			   _("Gesture: %s"), buf1);
 
+	gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar), STATUS_GESTURE);
 	gtk_statusbar_push(GTK_STATUSBAR(kz->statusbar),
 			   STATUS_GESTURE, buf2);
 }
@@ -2624,6 +2648,25 @@ cb_sidebar_unmap (GtkWidget *widget, GtkToggleAction *action)
 
 
 
+static void
+cb_bookmarkbars_map (GtkWidget *widget, GtkToggleAction *action)
+{
+	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
+
+	gtk_toggle_action_set_active(action, TRUE);
+}
+
+
+static void
+cb_bookmarkbars_unmap (GtkWidget *widget, GtkToggleAction *action)
+{
+	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
+
+	gtk_toggle_action_set_active(action, FALSE);
+}
+
+
+
 /*****************************************************************************
  *                                                                           *
  *                        Callbacks for Embed                                *
@@ -2648,7 +2691,6 @@ cb_embed_location_changed (KzEmbed *embed, KzWindow *kz)
 {
 	const char *newLocation;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	newLocation = kz_embed_get_location(KZ_EMBED(embed));
@@ -2678,13 +2720,16 @@ cb_embed_link_message (KzEmbed *embed, KzWindow *kz)
 {
 	gchar *newMessage;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	newMessage = kz_embed_get_link_message(KZ_EMBED(embed));
-	if(kz->statusbar)
+	if(kz->statusbar) 
+	{
+		gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar),
+				  STATUS_LINK_MESSAGE);
 		gtk_statusbar_push(GTK_STATUSBAR(kz->statusbar),
 				   STATUS_LINK_MESSAGE, newMessage);
+	}
 
 	g_free(newMessage);
 }
@@ -2695,7 +2740,6 @@ cb_embed_load_started (KzEmbed *embed, KzWindow *kz)
 {
 	KzEmbed *kzembed;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kzembed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz));
@@ -2708,7 +2752,6 @@ cb_embed_load_finished (KzEmbed *embed, KzWindow *kz)
 {
 	KzEmbed *kzembed;
 
-	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	kzembed = KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz));
@@ -2733,7 +2776,6 @@ cb_embed_close_tab (GtkObject *obj, KzWindow *kz)
 	KzEmbed *kzembed;
 	GNode *node, *child;
 
-	g_return_if_fail(KZ_IS_EMBED(obj));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 	g_return_if_fail(kz->priv->tab_tree);
 
@@ -2745,6 +2787,8 @@ cb_embed_close_tab (GtkObject *obj, KzWindow *kz)
 	kz->priv->view_hist = g_list_remove(kz->priv->view_hist, kzembed);
 	kz->priv->open_hist = g_list_remove(kz->priv->open_hist, kzembed);
 
+	gtk_statusbar_pop(GTK_STATUSBAR(kz->statusbar), STATUS_LINK_MESSAGE);
+
 	node = g_node_find(kz->priv->tab_tree,
 			   G_IN_ORDER, G_TRAVERSE_ALL, kzembed);
 	/* probably destroy handler is already called */
@@ -2763,7 +2807,7 @@ cb_embed_close_tab (GtkObject *obj, KzWindow *kz)
 	/* FIXME! should move to specifing tab like kz_window_close_tab() */
 	g_node_destroy(node);
 	gtk_widget_destroy(GTK_WIDGET(kzembed));
-	g_signal_emit(G_OBJECT(kz), kz_window_signals[REMOVE_TAB_SIGNAL],
+	g_signal_emit(kz, kz_window_signals[REMOVE_TAB_SIGNAL],
 		      0, kzembed);
 }
 
@@ -2772,7 +2816,6 @@ static gint
 cb_embed_dom_key_down (KzEmbed *embed, KzEmbedEventKey *event, KzWindow *kz)
 {
 
-	g_return_val_if_fail(KZ_IS_EMBED(embed), FALSE);
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
 
 	kz_actions_set_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
@@ -2784,7 +2827,6 @@ cb_embed_dom_key_down (KzEmbed *embed, KzEmbedEventKey *event, KzWindow *kz)
 static gint
 cb_embed_dom_key_up (KzEmbed *embed, KzEmbedEventKey *event, KzWindow *kz)
 {
-	g_return_val_if_fail(KZ_IS_EMBED(embed), FALSE);
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
 
 	kz_actions_set_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
@@ -2804,7 +2846,6 @@ cb_embed_dom_mouse_click (KzEmbed *embed, KzEmbedEventMouse *event,
 	KzTabLabel *kztab = NULL;
 	GtkWidget *widget = KZ_WINDOW_CURRENT_PAGE(kz);
 
-	g_return_val_if_fail(KZ_IS_EMBED(embed), FALSE);
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
 
 	time = GDK_CURRENT_TIME;
@@ -2841,8 +2882,17 @@ cb_embed_dom_mouse_click (KzEmbed *embed, KzEmbedEventMouse *event,
 	case 1:
 		if ((type & KZ_CONTEXT_LINK) && event->cinfo.link)
 		{
-			kz_window_open_new_tab_with_parent(kz, event->cinfo.link,
-							   GTK_WIDGET(embed));
+			gboolean focus_mid_click_link = FALSE;
+			KZ_CONF_GET("Tab", "focus_mid_click_link", focus_mid_click_link, BOOL);
+
+			widget = kz_window_open_new_tab_with_parent(kz, event->cinfo.link,
+							   	    GTK_WIDGET(embed));
+
+			if(((event->modifier & KZ_SHIFT_KEY) != 0) ^ focus_mid_click_link)
+			{
+				gtk_notebook_set_current_page(GTK_NOTEBOOK(kz->notebook),
+							      gtk_notebook_page_num(GTK_NOTEBOOK(kz->notebook), widget));
+			}
 		}
 		else if (!(type & KZ_CONTEXT_INPUT))
 		{
@@ -2874,7 +2924,6 @@ cb_embed_dom_mouse_dbl_click (KzEmbed *embed, KzEmbedEventMouse *event,
      	KzEmbedEventMouse *info;
 	gint button;
 
-	g_return_val_if_fail(KZ_IS_EMBED(embed), FALSE);
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
 
      	type = kz_embed_get_mouse_event_info(KZ_MOZ_EMBED(embed), event, &info);
@@ -2902,7 +2951,6 @@ cb_embed_dom_mouse_down (KzEmbed *kzembed, KzEmbedEventMouse *event,
      	glong type;
 
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
-	g_return_val_if_fail(KZ_IS_EMBED(kzembed), FALSE);
 
 	type = event->cinfo.context;
 	button = event->button;
@@ -3023,7 +3071,6 @@ cb_embed_dom_mouse_up (KzEmbed *embed, KzEmbedEventMouse *event,
 		       KzWindow *kz)
 {
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
-	g_return_val_if_fail(KZ_IS_EMBED(embed), FALSE);
 
 	kz_actions_set_selection_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
 
@@ -3036,9 +3083,12 @@ cb_embed_dom_mouse_over (KzEmbed *embed, KzEmbedEventMouse *event,
 {
 	static glong previous_event_context = KZ_CONTEXT_NONE;
 	glong type;
+	gboolean popup_thumbnail;
 
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
-	g_return_val_if_fail(KZ_IS_EMBED(embed), FALSE);
+
+	KZ_CONF_GET("Global", "popup_thumbnail", popup_thumbnail, BOOL);
+	if (!popup_thumbnail) return FALSE;
 
 	type = event->cinfo.context;
 	if ((type & KZ_CONTEXT_LINK) && event->cinfo.link)
@@ -3050,7 +3100,7 @@ cb_embed_dom_mouse_over (KzEmbed *embed, KzEmbedEventMouse *event,
 		display = gtk_widget_get_display (widget);
 		gdk_display_get_pointer (display, NULL, &x, &y, NULL);
 
-		kz_popup_preview_start(kz->popup, event->cinfo.link, x, y);
+		kz_popup_preview_start(kz->popup, event->cinfo.link, event->cinfo.img, x, y);
 	}
 	else if(!(type & KZ_CONTEXT_LINK) && (previous_event_context & KZ_CONTEXT_LINK))
 	{
@@ -3070,12 +3120,13 @@ cb_window_motion_notify_event (GtkWidget *widget,
 {
 	KzWindow *kz;
 	gint x, y;
+	/* GdkModifierType state; */
 
-	g_return_val_if_fail(KZ_IS_WINDOW(widget), FALSE);
 	g_return_val_if_fail(KZ_IS_EMBED(kzembed), FALSE);
 
 	kz = KZ_WINDOW(widget);
 
+	/*gdk_window_get_pointer (GTK_WIDGET(kzembed)->window, &x, &y, &state);*/
 	gtk_widget_get_pointer (GTK_WIDGET(kzembed), &x, &y);
 
 	if (abs(x - kz->priv->start_x) > 2 ||
@@ -3086,7 +3137,27 @@ cb_window_motion_notify_event (GtkWidget *widget,
 
 	if (kz_gesture_is_started(kz->priv->gesture))
 	{
+		/* if(state == GDK_BUTTON3_MASK) */
 		kz_gesture_update_position(kz->priv->gesture, x, y);
+		/*
+		else
+		{
+			if (gdk_pointer_is_grabbed ())
+			{
+				gdk_pointer_ungrab (gtk_get_current_event_time ());
+			}
+			kz_gesture_perform(kz->priv->gesture);
+			gtk_statusbar_push(GTK_STATUSBAR(KZ_WINDOW(widget)->statusbar),
+				   STATUS_GESTURE, "");
+			kz->priv->start_x = 0;
+			kz->priv->start_y = 0;
+			kz->priv->is_gesture = FALSE;
+
+			if (kz->priv->event)
+				kz_embed_event_free((KzEmbedEvent *) kz->priv->event);
+			kz->priv->event = NULL;
+		}
+		*/
 	}
 
 	kz_actions_set_selection_sensitive(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
@@ -3103,7 +3174,6 @@ cb_window_button_release_event (GtkWidget *widget,
 	KzWindow *kz;
 	gboolean retval = FALSE;
 
-	g_return_val_if_fail(KZ_IS_WINDOW(widget), FALSE);
 	g_return_val_if_fail(KZ_IS_EMBED(kzembed), FALSE);
 
 	kz = KZ_WINDOW(widget);
@@ -3119,8 +3189,8 @@ cb_window_button_release_event (GtkWidget *widget,
 			kz_gesture_perform(kz->priv->gesture);
 		else
 			kz_gesture_cancel(kz->priv->gesture);
-		gtk_statusbar_push(GTK_STATUSBAR(KZ_WINDOW(widget)->statusbar),
-				   STATUS_GESTURE, "");
+		gtk_statusbar_pop(GTK_STATUSBAR(KZ_WINDOW(widget)->statusbar),
+				  STATUS_GESTURE);
 	}
 
 	if (!kz->priv->is_gesture && event->button == 3)
@@ -3215,14 +3285,12 @@ cb_focus_out_event            (GtkWidget       *widget,
 			       GdkEventFocus   *event,
 			       KzWindow        *kz)
 {
-	g_return_val_if_fail(KZ_IS_WINDOW(widget), FALSE);
-
 	if(!event->in) {/* focus is out */
 		if (kz_gesture_is_started(kz->priv->gesture))
 		{
 			kz_gesture_cancel(kz->priv->gesture);
-			gtk_statusbar_push(GTK_STATUSBAR(KZ_WINDOW(widget)->statusbar),
-				   STATUS_GESTURE, "");
+			gtk_statusbar_pop(GTK_STATUSBAR(KZ_WINDOW(widget)->statusbar),
+					  STATUS_GESTURE);
 		}
 
 		if (gdk_pointer_is_grabbed ())
