@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.5 2004/09/30 00:06:07 ikezoe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.7 2005/03/14 14:17:45 ikezoe Exp $
  */
 
 /*
@@ -49,7 +49,9 @@
 #include <nsICRLInfo.h>
 #include <nsISimpleEnumerator.h>
 #include <nsIArray.h>
-#include <nsString.h>
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIDOMWindow.h>
 
 #include <gtk/gtk.h>
@@ -266,14 +268,16 @@ GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
 	char *ttTargetUrl, *ttCommonName, *first, *second, *msg;
 	int res;
 
-	nsAutoString commonName;
+	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
 
+	nsEmbedCString cTargetURL(targetURL);
+
  	ttTargetUrl = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-                                               PromiseFlatCString(targetURL).get());
+                                               cTargetURL.get());
 
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-						NS_ConvertUCS2toUTF8(commonName).get());
+						commonName.get());
 
         first = g_strdup_printf (_("The site %s returned security information for "
 				   "%s. It is possible that someone is intercepting "
@@ -311,11 +315,11 @@ GtkNSSDialogs::ConfirmUnknownIssuer (nsIInterfaceRequestor *ctx,
 	char *ttCommonName, *secondary, *tertiary, *msg;
 	int res;
 
-	nsAutoString commonName;
+	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
 
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-						NS_ConvertUCS2toUTF8(commonName).get());
+						commonName.get());
 
 	secondary = g_strdup_printf
 		           (_("Your browser was unable to trust %s. "
@@ -406,7 +410,7 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 		timeToUse = notBefore;
 	}
 	
-	nsAutoString commonName;
+	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
 
 	LL_DIV (normalizedTime, timeToUse, PR_USEC_PER_SEC);
@@ -419,7 +423,7 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 	fdate = g_locale_to_utf8 (formattedDate, -1, NULL, NULL, NULL);
 
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-					        NS_ConvertUCS2toUTF8(commonName).get());
+					        commonName.get());
 
 	secondary = g_strdup_printf (text, ttCommonName, fdate);
 
@@ -461,14 +465,16 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_ERROR,
 			    &label, NULL);
 
-	nsAutoString commonName;
+	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
 
+	nsEmbedCString cTargetURL(targetURL);
+
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"", 
-						NS_ConvertUCS2toUTF8(commonName).get());
+						commonName.get());
 
 	ttTargetUrl = g_markup_printf_escaped ("\"<tt>%s</tt>\"",
-				               PromiseFlatCString(targetURL).get());
+				               cTargetURL.get());
 
 	primary = g_strdup_printf (_("Cannot establish connection to %s."),
 				   ttTargetUrl);
@@ -490,7 +496,7 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 
 	gtk_widget_show_all (dialog);
 
-	g_signal_connect (G_OBJECT (dialog),
+	g_signal_connect (dialog,
 			  "response",
 			  (GCallback)gtk_widget_destroy, NULL);
 
@@ -524,11 +530,11 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 			    &label, &content_vbox);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
-	nsAutoString commonName;
+	nsEmbedString commonName;
 	cert->GetCommonName (commonName);
 
 	ttCommonName = g_markup_printf_escaped ("\"<tt>%s</tt>\"",
-						NS_ConvertUCS2toUTF8(commonName).get());
+						commonName.get());
 
 	tertiary = g_strdup_printf (_("Trust %s to identify:"), ttCommonName);
 	g_free (ttCommonName);
@@ -621,7 +627,7 @@ GtkNSSDialogs::NotifyCACertExists (nsIInterfaceRequestor *ctx)
 	gtk_label_set_markup (GTK_LABEL (label), msg);
 	g_free (msg);
 
-	g_signal_connect (G_OBJECT (dialog),
+	g_signal_connect (dialog,
 			  "response",
 			  (GCallback)gtk_widget_destroy, NULL);
 
@@ -816,7 +822,8 @@ GtkNSSDialogs::SetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 	else
 	{
 		gchar *text = gtk_editable_get_chars (GTK_EDITABLE (entry1), 0, -1);
-		_password = NS_ConvertUTF8toUCS2(text);
+		NS_CStringToUTF16(nsEmbedCString(text),
+				  NS_CSTRING_ENCODING_UTF8, _password);
 		g_free (text);
 		*_retval = PR_TRUE;
 	}
@@ -876,7 +883,8 @@ GtkNSSDialogs::GetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 	else
 	{
 		gchar * text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-		_password = NS_ConvertUTF8toUCS2(text);
+		NS_CStringToUTF16(nsEmbedCString(text),
+				  NS_CSTRING_ENCODING_UTF8, _password);
 		g_free (text);
 		*_retval = PR_TRUE;
 	}
@@ -935,7 +943,7 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 6);
 
-	nsAutoString org, orgUnit, nextUpdate;
+	nsEmbedString org, orgUnit, nextUpdate;
 	rv = crl->GetOrganization (org);
 	if (NS_FAILED(rv)) return rv;
 
@@ -945,19 +953,25 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 	rv = crl->GetNextUpdateLocale (nextUpdate);
 	if (NS_FAILED(rv)) return rv;
 
-	label = gtk_label_new (NS_ConvertUCS2toUTF8(org).get());
+	nsEmbedCString cOrg;
+	NS_UTF16ToCString(org, NS_CSTRING_ENCODING_UTF8, cOrg);
+	label = gtk_label_new (cOrg.get());
 	set_table_row (table, 0, _("Organization:"), label);
 
-	label = gtk_label_new (NS_ConvertUCS2toUTF8(orgUnit).get());
+	nsEmbedCString cOrgUnit;
+	NS_UTF16ToCString(org, NS_CSTRING_ENCODING_UTF8, cOrgUnit);
+	label = gtk_label_new (cOrgUnit.get());
 	set_table_row (table, 1, _("Unit:"), label);
 
-	label = gtk_label_new (NS_ConvertUCS2toUTF8(nextUpdate).get());
+	nsEmbedCString cNextUpdate;
+	NS_UTF16ToCString(org, NS_CSTRING_ENCODING_UTF8, cNextUpdate);
+	label = gtk_label_new (cNextUpdate.get());
 	set_table_row (table, 2, _("Next Update:"), label);
 
 	gtk_box_pack_start (GTK_BOX (vbox), higgy_indent_widget (table), FALSE, FALSE, 0);
 
 	gtk_widget_show_all (dialog);
-	g_signal_connect (G_OBJECT (dialog),
+	g_signal_connect (dialog,
 			  "response",
 			  (GCallback)gtk_widget_destroy, NULL);
 
@@ -983,9 +997,11 @@ set_label_cert_attribute (GtkWidget *widget, nsAString &value)
 	}
 	else
 	{
+		nsEmbedCString cValue;
+		NS_UTF16ToCString(value, NS_CSTRING_ENCODING_UTF8, cValue);
 		gtk_label_set_use_markup (GTK_LABEL (widget), FALSE);
 		gtk_label_set_text (GTK_LABEL (widget), 
-				    NS_ConvertUCS2toUTF8(value).get());
+				    cValue.get());
 	}
 }
 
@@ -1014,15 +1030,18 @@ fill_cert_chain_tree (GtkTreeView *treeview, nsIArray *certChain)
 		gtk_tree_store_append (GTK_TREE_STORE (model), &iter, 
 				       (i == (int)numCerts-1) ? NULL : &parent);
 
-		nsAutoString value;
+		nsEmbedString value;
 		rv = nsCert->GetCommonName (value);
 		if (NS_FAILED(rv)) return FALSE;
 
+		nsEmbedCString cValue;
+		NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cValue);
+
 		nsIX509Cert *nsCertP = nsCert;
 		if (value.Length())
 		{
 			gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
-					    0, NS_ConvertUCS2toUTF8(value).get(),
+					    0, cValue.get(),
 					    1, nsCertP,
 					    -1);
 		}
@@ -1056,14 +1075,17 @@ fill_cert_chain_tree (GtkTreeView *treeview, nsIArray *certChain)
 static void
 add_asn1_object_to_tree(GtkTreeModel *model, nsIASN1Object *object, GtkTreeIter *parent)
 {
-	nsAutoString dispNameU;
+	nsEmbedString dispNameU;
 	object->GetDisplayName(dispNameU);
 
+	nsEmbedCString cDispNameU;
+	NS_UTF16ToCString (dispNameU, NS_CSTRING_ENCODING_UTF8, cDispNameU);
+
 	GtkTreeIter iter;
 	gtk_tree_store_append (GTK_TREE_STORE (model), &iter, parent);
 
 	gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
-			    0, NS_ConvertUCS2toUTF8(dispNameU).get(),
+			    0, cDispNameU.get(),
 			    1, object,
 			    -1);
 
@@ -1135,11 +1157,14 @@ field_tree_view_selection_changed_cb (GtkTreeSelection *selection,
 
 		gtk_tree_model_get (model, &iter, 1, &object, -1);
 
-		nsAutoString dispValU;
+		nsEmbedString dispValU;
 		object->GetDisplayValue(dispValU);
 
+		nsEmbedCString cDispValU;
+		NS_UTF16ToCString(dispValU, NS_CSTRING_ENCODING_UTF8, cDispValU);
+
 		gtk_text_buffer_set_text (text_buffer, 
-					  NS_ConvertUCS2toUTF8(dispValU).get(), -1);
+					  cDispValU.get(), -1);
 	}
 	else
 	{
@@ -1178,7 +1203,7 @@ setup_view_cert_tree (GtkWidget *dialog,
 	GtkTreeSelection *select = gtk_tree_view_get_selection (GTK_TREE_VIEW (chain_tree_view));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
 
-	g_signal_connect (G_OBJECT (select), "changed",
+	g_signal_connect (select, "changed",
 			  G_CALLBACK (cert_chain_tree_view_selection_changed_cb),
 			  field_tree_view);
 
@@ -1199,7 +1224,7 @@ setup_view_cert_tree (GtkWidget *dialog,
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (field_tree_view));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
 
-	g_signal_connect (G_OBJECT (select), "changed",
+	g_signal_connect (select, "changed",
 			  G_CALLBACK (field_tree_view_selection_changed_cb),
 			  text_view);
 
@@ -1215,7 +1240,7 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 	GtkWidget *dialog, *widget, *vbox, *notebook, *label;
 	GtkWidget *main_vbox, *hbox;
 	GtkWidget *chain_tree_view, *field_tree_view, *text_view;
-	nsAutoString value;
+	nsEmbedString value;
 	nsresult rv;
 	PRUint32 verifystate, count;
 	PRUnichar ** usage;
@@ -1458,7 +1483,10 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 		GtkWidget *indent;
 		for (PRUint32 i = 0 ; i < count ; i++)
 		{
-			GtkWidget *label = gtk_label_new(NS_ConvertUCS2toUTF8(usage[i]).get());
+			nsEmbedCString msg;
+			NS_UTF16ToCString(nsEmbedString(usage[i]),
+					  NS_CSTRING_ENCODING_UTF8, msg);
+			GtkWidget *label = gtk_label_new(msg.get());
 			gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 			gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 			nsMemory::Free (usage[i]);
