@@ -53,8 +53,7 @@
 #include <gtk/gtkhbbox.h>
 #include <gtk/gtkoptionmenu.h>
 #include <gtk/gtkmessagedialog.h>
-
-#include "intl.h"
+#include <glib/gi18n.h>
 
 #include "nsIFilePicker.h"
 
@@ -63,8 +62,9 @@
 #include "nsISupportsArray.h"
 #include "nsIServiceManager.h"
 
-#include "nsString.h"
-#include "nsXPIDLString.h"
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include "nsIPrefService.h"
 #include "nsIURI.h"
 #include "nsIFileURL.h"
@@ -73,7 +73,6 @@
 #include "nsNetCID.h"
 #include "nsILocalFile.h"
 #include "nsIPromptService.h"
-#include "nsReadableUtils.h"
 
 #include "kz-mozfilepicker.h"
 #include "kz-mozutils.h"
@@ -81,6 +80,8 @@
 /* Implementation file */
 NS_IMPL_ISUPPORTS1(KzFilePicker, nsIFilePicker)
 
+nsEmbedCString KzFilePicker::mPrevDirectory;
+
 KzFilePicker::KzFilePicker()
 {
 	NS_INIT_ISUPPORTS();
@@ -88,7 +89,11 @@ KzFilePicker::KzFilePicker()
 	/* member initializers and constructor code */
 	mFile = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
 	mDisplayDirectory = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
-	mDisplayDirectory->InitWithNativePath(nsDependentCString(g_get_home_dir()));
+	if (!mPrevDirectory.Length())
+	{
+		mPrevDirectory = nsEmbedCString(g_get_home_dir());
+	}
+	mDisplayDirectory->InitWithNativePath(mPrevDirectory);
 }
 
 KzFilePicker::~KzFilePicker()
@@ -101,7 +106,7 @@ KzFilePicker::~KzFilePicker()
 ////////////////////////////////////////////////////////////////////////////////
 
 /* void init (in nsIDOMWindowInternal parent, in wstring title, in short mode); */
-#if MOZILLA_SNAPSHOT > 15
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
 NS_IMETHODIMP KzFilePicker::Init(nsIDOMWindow *aParent,
 				 const nsAString &aTitle,
 				 PRInt16 aMode)
@@ -112,7 +117,11 @@ NS_IMETHODIMP KzFilePicker::Init(nsIDOMWindowInternal *aParent,
 {
 	mParent = do_QueryInterface(aParent);
 	mParentWidget = GetGtkWindowForDOMWindow(mParent);
-	mTitle = NS_ConvertUCS2toUTF8(aTitle);
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
+	NS_UTF16ToCString(aTitle, NS_CSTRING_ENCODING_UTF8, mTitle);
+#else
+	mTitle = nsEmbedCString(aTitle);
+#endif
 	mMode = aMode;
 	
 	return NS_OK;
@@ -128,7 +137,7 @@ NS_IMETHODIMP KzFilePicker::AppendFilters(PRInt32 aFilterMask)
 }
 
 /* void appendFilter (in wstring title, in wstring filter); */
-#if MOZILLA_SNAPSHOT > 15
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
 NS_IMETHODIMP KzFilePicker::AppendFilter(const nsAString &aTitle,
 					 const nsAString &aFilter)
 #else
@@ -139,7 +148,11 @@ NS_IMETHODIMP KzFilePicker::AppendFilter(const PRUnichar *aTitle,
 	//GtkFileSelection is crippled, so we can't provide a short-list
 	//of filters to choose from. We provide minimal functionality
 	//by using the most recent AppendFilter call as the active filter.
-	mFilter = NS_ConvertUCS2toUTF8(aFilter);
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
+	NS_UTF16ToCString(aFilter, NS_CSTRING_ENCODING_UTF8, mFilter);
+#else
+	mFilter = nsEmbedCString(aFilter);
+#endif
 	return NS_OK;
 }
 
@@ -154,53 +167,34 @@ NS_IMETHODIMP KzFilePicker::SetFilterIndex(PRInt32 aFilterIndex)
 }
 
 /* attribute wstring defaultString; */
-#if MOZILLA_SNAPSHOT > 15
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
 NS_IMETHODIMP KzFilePicker::GetDefaultString(nsAString &aDefaultString)
 #else
 NS_IMETHODIMP KzFilePicker::GetDefaultString(PRUnichar * *aDefaultString)
 #endif
 {
-	gsize bytesWritten;
-	gchar *utf8DefaultString = g_filename_to_utf8(mDefaultString.get(), -1,
-						      NULL,
-						      &bytesWritten, NULL);
-#if MOZILLA_SNAPSHOT > 15
-	aDefaultString.Assign(NS_ConvertUTF8toUCS2(utf8DefaultString));
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
+	aDefaultString = mDefaultString;
 #else
-	*aDefaultString = ToNewUnicode(NS_ConvertUTF8toUCS2(utf8DefaultString));
+	*aDefaultString = mDefaultString.get();
 #endif
-	g_free(utf8DefaultString);
 	return NS_OK;
 }
-#if MOZILLA_SNAPSHOT > 15
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
 NS_IMETHODIMP KzFilePicker::SetDefaultString(const nsAString &aDefaultString)
 #else
 NS_IMETHODIMP KzFilePicker::SetDefaultString(const PRUnichar *aDefaultString)
 #endif
 {
-#if MOZILLA_SNAPSHOT > 15
-	if (aDefaultString.Length())
-#else
-	if (aDefaultString)
-#endif
-	{
-		gsize bytesWritten;
-		gchar *localeDefaultString =
-			g_filename_from_utf8(NS_ConvertUCS2toUTF8(aDefaultString).get(),
-					     -1, NULL,
-					     &bytesWritten, NULL);
-		mDefaultString = localeDefaultString;					     
-		g_free(localeDefaultString);
-	}
-	else
-		mDefaultString = "";
+	mDefaultString.Assign(aDefaultString);
+
 	return NS_OK;
 }
 
 /* attribute wstring defaultExtension; */
 // Again, due to the crippled file selector, we can't really
 // do anything here.
-#if MOZILLA_SNAPSHOT > 15
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
 NS_IMETHODIMP KzFilePicker::GetDefaultExtension(nsAString &aDefaultExtension)
 #else
 NS_IMETHODIMP KzFilePicker::GetDefaultExtension(PRUnichar * *aDefaultExtension)
@@ -208,7 +202,7 @@ NS_IMETHODIMP KzFilePicker::GetDefaultExtension(PRUnichar * *aDefaultExtension)
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
-#if MOZILLA_SNAPSHOT > 15
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
 NS_IMETHODIMP KzFilePicker::SetDefaultExtension(const nsAString &aDefaultExtension)
 #else
 NS_IMETHODIMP KzFilePicker::SetDefaultExtension(const PRUnichar *aDefaultExtension)
@@ -255,45 +249,78 @@ NS_IMETHODIMP KzFilePicker::GetFiles(nsISimpleEnumerator * *aFiles)
 /* short show (); */
 NS_IMETHODIMP KzFilePicker::Show(PRInt16 *_retval)
 {
-	mFileSelector = gtk_file_selection_new(mTitle.get());
+	GtkFileChooserAction action;
+	GtkFileFilter *filter = NULL;
+	const gchar *stock;
 
-	nsCAutoString cFileName;
-	if(mMode == nsIFilePicker::modeGetFolder)
-		cFileName.Assign("");
-	else
-		cFileName = mDefaultString;
-
-	nsCAutoString cDirName;
-	mDisplayDirectory->GetNativePath(cDirName);
-
-	nsCAutoString cFullPath;
-	cFullPath.Assign(cDirName + NS_LITERAL_CSTRING("/") + cFileName);
-	gtk_file_selection_set_filename(GTK_FILE_SELECTION(mFileSelector),
-				 	cFullPath.get());
-
-	if (!mFilter.IsEmpty())
+	switch (mMode)
 	{
-		gtk_file_selection_complete(GTK_FILE_SELECTION(mFileSelector),
-					    mFilter.get());
+	 case nsIFilePicker::modeSave:
+		action = GTK_FILE_CHOOSER_ACTION_SAVE;
+		stock = GTK_STOCK_SAVE;
+		break;
+	 case nsIFilePicker::modeGetFolder:
+		action = GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER;
+		stock = GTK_STOCK_OPEN;
+		break;
+	 case nsIFilePicker::modeOpenMultiple:
+		action = GTK_FILE_CHOOSER_ACTION_OPEN;
+		stock = GTK_STOCK_OPEN;
+		break;
+	 case nsIFilePicker::modeOpen:
+	 default:
+		action = GTK_FILE_CHOOSER_ACTION_OPEN;
+		stock = GTK_STOCK_OPEN;
+		break;
+	}
+			
+	mFileDialog = gtk_file_chooser_dialog_new(mTitle.get(),
+						  NULL,
+						  action,
+						  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						  stock, GTK_RESPONSE_ACCEPT,
+						  NULL);
+
+	if(mMode == nsIFilePicker::modeSave)
+	{
+		nsEmbedCString cFileName;
+		NS_UTF16ToCString(mDefaultString,
+				  NS_CSTRING_ENCODING_UTF8, cFileName);
+
+		gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(mFileDialog),
+				 		  cFileName.get());
+		nsEmbedCString dir;
+	
+		mDisplayDirectory->GetNativePath (dir);
+
+		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(mFileDialog),
+						    dir.get());
+
+	}
+
+	if (mFilter.Length())
+	{
+		filter = gtk_file_filter_new();
+		gtk_file_filter_add_pattern(filter, mFilter.get());
 	}
 
 	if (mParentWidget)
-		gtk_window_set_transient_for(GTK_WINDOW(mFileSelector),
+		gtk_window_set_transient_for(GTK_WINDOW(mFileDialog),
 					     GTK_WINDOW(mParentWidget));
 
-	if (mMode == nsIFilePicker::modeGetFolder)
+	if (mMode == nsIFilePicker::modeOpenMultiple)
 	{
-		gtk_widget_set_sensitive(GTK_FILE_SELECTION(mFileSelector)
-					 ->file_list, FALSE);
+		gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(mFileDialog)
+					 	     , TRUE);
 	}
 
-	gtk_window_set_modal(GTK_WINDOW(mFileSelector), TRUE);
+	gtk_window_set_modal(GTK_WINDOW(mFileDialog), TRUE);
 
-	gint retVal = gtk_dialog_run(GTK_DIALOG(mFileSelector));
+	gint retVal = gtk_dialog_run(GTK_DIALOG(mFileDialog));
 	
 	HandleFilePickerResult();
 
-	if (retVal != GTK_RESPONSE_OK)
+	if (retVal != GTK_RESPONSE_ACCEPT)
 	{
 		*_retval = returnCancel;
 	}
@@ -302,7 +329,10 @@ NS_IMETHODIMP KzFilePicker::Show(PRInt16 *_retval)
 		ValidateFilePickerResult(_retval);
 	}
 
-	gtk_widget_destroy(mFileSelector);
+	if (filter)
+		g_object_unref(filter);
+
+	gtk_widget_destroy(mFileDialog);
 
 	return NS_OK;
 }
@@ -316,7 +346,7 @@ NS_METHOD KzFilePicker::InitWithGtkWidget (GtkWidget *aParentWidget,
 {
 	mParentWidget = aParentWidget;
 
-	mTitle = nsDependentCString(aTitle);
+	mTitle = nsEmbedCString(aTitle);
 
 	mMode = aMode;
 
@@ -364,7 +394,7 @@ NS_METHOD KzFilePicker::SanityCheck (PRBool *retIsSane)
 
 		if (mParentWidget)
 			gtk_window_set_transient_for(GTK_WINDOW(errorDialog),
-						     GTK_WINDOW(mFileSelector));
+						     GTK_WINDOW(mFileDialog));
 
 		gtk_window_set_modal (GTK_WINDOW(errorDialog), TRUE);
 		gtk_dialog_run (GTK_DIALOG(errorDialog));
@@ -401,7 +431,7 @@ NS_METHOD KzFilePicker::SanityCheck (PRBool *retIsSane)
 
 		if (mParentWidget)
 			gtk_window_set_transient_for(GTK_WINDOW(errorDialog),
-						     GTK_WINDOW(mFileSelector));
+						     GTK_WINDOW(mFileDialog));
 
 		gtk_window_set_modal (GTK_WINDOW(errorDialog), TRUE);
 		gtk_dialog_run (GTK_DIALOG(errorDialog));
@@ -419,26 +449,31 @@ NS_METHOD KzFilePicker::SanityCheck (PRBool *retIsSane)
 
 NS_METHOD KzFilePicker::HandleFilePickerResult()
 {
-	const char *fileName = gtk_file_selection_get_filename(GTK_FILE_SELECTION(mFileSelector));
+	char *fileName = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(mFileDialog));
 
 	if (!fileName || strlen(fileName) == 0) return NS_ERROR_FAILURE;
 
-	const nsACString &cFileName = nsDependentCString(fileName);
+	nsEmbedCString cFileName(fileName);
 	mFile->InitWithNativePath(cFileName);
 
 	if (mMode == nsIFilePicker::modeGetFolder)
 	{
 		mDisplayDirectory->InitWithNativePath(cFileName);
-		mDefaultString = "";
+		
+		const PRUnichar tmp[] = { '\0' };
+		mDefaultString = nsEmbedString(tmp);
 	}
 	else
 	{
 		nsCOMPtr<nsIFile> directory;
 		mFile->GetParent(getter_AddRefs(directory));
 		mDisplayDirectory = do_QueryInterface(directory);
-		mFile->GetNativeLeafName(mDefaultString);
+		mDisplayDirectory->GetNativePath(mPrevDirectory);
+		mFile->GetLeafName(mDefaultString);
 	}
 
+	g_free (fileName);
+	
 	return NS_OK;
 }
 
