@@ -26,23 +26,27 @@
 #endif
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <nsCOMPtr.h>
-#include <nsString.h>
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIURI.h>
 #include <nsIURL.h>
 #include <nsIMIMEInfo.h>
+#include <nsMemory.h>
 
-#include "intl.h"
 #include "kz-mozlauncher.h"
 #include "kz-mozfilepicker.h"
 
-
 NS_IMPL_ISUPPORTS1(KzContentHandler, nsIHelperAppLauncherDialog)
 
 
 KzContentHandler::KzContentHandler() :
 	mUri(nsnull),
+#ifndef MOZ_NSIMIMEINFO_NSACSTRING_
 	mMimeType(nsnull),
+#endif
 	mDownloadCanceled(PR_FALSE)
 {
 	NS_INIT_ISUPPORTS();
@@ -50,17 +54,18 @@ KzContentHandler::KzContentHandler() :
 
 KzContentHandler::~KzContentHandler()
 {
+#ifndef MOZ_NSIMIMEINFO_NSACSTRING_
 	nsMemory::Free (mMimeType);
+#endif
 }
 
 
-#if MOZILLA_SNAPSHOT > 9
 NS_IMETHODIMP KzContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 				     nsISupports *aContext,
+#ifdef MOZ_NSIHELPERAPPLAUNCHERDIALOG_NSPRBOOL_
 				     PRBool aForced)
 #else
-NS_IMETHODIMP KzContentHandler::Show(nsIHelperAppLauncher *aLauncher,
-				     nsISupports *aContext)
+				     PRUint32 aForced)
 #endif
 {
 	nsresult rv;
@@ -76,9 +81,7 @@ NS_IMETHODIMP KzContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 }
 
 NS_IMETHODIMP KzContentHandler::PromptForSaveToFile(
-#if MOZILLA_SNAPSHOT > 10
 				    nsIHelperAppLauncher *aLauncher,
-#endif				    
 				    nsISupports *aWindowContext,
 				    const PRUnichar *aDefaultFile,
 				    const PRUnichar *aSuggestedFileExtension,
@@ -98,7 +101,7 @@ NS_IMETHODIMP KzContentHandler::PromptForSaveToFile(
 		dirName = g_strdup(g_get_home_dir());
 
 	saveDir = do_CreateInstance(NS_LOCAL_FILE_CONTRACTID);
-	saveDir->InitWithPath(NS_ConvertUTF8toUCS2(dirName));
+	saveDir->InitWithNativePath(nsEmbedCString(dirName));
 
 	nsCOMPtr <nsILocalFile> saveFile(do_CreateInstance(NS_LOCAL_FILE_CONTRACTID));
 
@@ -107,13 +110,17 @@ NS_IMETHODIMP KzContentHandler::PromptForSaveToFile(
 	nsCOMPtr<nsIFilePicker> filePicker =
 				do_CreateInstance(KZ_FILEPICKER_CONTRACTID);
 
-	const nsAString &title = NS_ConvertUTF8toUCS2(_("Select the destination filename"));
+	nsEmbedCString cTitle(_("Select the destination filename"));
 
-#if MOZILLA_SNAPSHOT > 15
+	nsEmbedString title;
+	NS_CStringToUTF16(cTitle,
+			  NS_CSTRING_ENCODING_UTF8, title);
+
+#ifdef MOZ_NSIFILEPICKER_NSASTRING_
 	filePicker->Init(windowInternal,
 			 title, 
 			 nsIFilePicker::modeSave);
-	nsAutoString defaultFile(aDefaultFile);
+	nsEmbedString defaultFile(aDefaultFile);
 	filePicker->SetDefaultString(defaultFile);
 #else
 	filePicker->Init(windowInternal,
@@ -129,12 +136,15 @@ NS_IMETHODIMP KzContentHandler::PromptForSaveToFile(
 	{
 		filePicker->GetFile(getter_AddRefs(saveFile));
 
-		nsString uFileName;
+		nsEmbedString uFileName;
 		saveFile->GetPath(uFileName);
-		const nsCString &aFileName = NS_ConvertUCS2toUTF8(uFileName);
+		nsEmbedCString cFileName;
+		
+		NS_UTF16ToCString(uFileName,
+				  NS_CSTRING_ENCODING_UTF8, cFileName);
 
 		g_free(dirName);
-		dirName = g_path_get_dirname(aFileName.get());
+		dirName = g_path_get_dirname(cFileName.get());
 
 		nsCOMPtr<nsIFile> directory;
 		rv = saveFile->GetParent(getter_AddRefs(directory));
@@ -147,13 +157,6 @@ NS_IMETHODIMP KzContentHandler::PromptForSaveToFile(
 	return NS_ERROR_FAILURE;
 }
 
-#if MOZILLA_SNAPSHOT < 10
-NS_METHOD KzContentHandler::ShowProgressDialog(nsIHelperAppLauncher *aLauncher,
-					       nsISupports *aContext)
-{
-	return NS_ERROR_NOT_IMPLEMENTED;
-}
-#endif
 
 NS_METHOD KzContentHandler::Init (void)
 {
@@ -161,18 +164,14 @@ NS_METHOD KzContentHandler::Init (void)
 
 	nsCOMPtr<nsIMIMEInfo> MIMEInfo;
 	rv = mLauncher->GetMIMEInfo(getter_AddRefs(MIMEInfo));
-#if MOZILLA_SNAPSHOT < 15
+#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
+	rv = MIMEInfo->GetMIMEType(mMimeType);
+#else
 	rv = MIMEInfo->GetMIMEType(&mMimeType);
 #endif
 
-#if MOZILLA_SNAPSHOT > 11
 	rv = mLauncher->GetSource(getter_AddRefs(mUri));
 	rv = mLauncher->GetTargetFile(getter_AddRefs(mTempFile));
-#else
-	rv = mLauncher->GetDownloadInfo(getter_AddRefs(mUri),
-					&mTimeDownloadStarted,
-					getter_AddRefs(mTempFile));
-#endif
 	
 	rv = mUri->GetSpec(mUrl);
 	rv = mUri->GetScheme(mScheme);
