@@ -21,9 +21,11 @@
  */
 
 #include <stdlib.h>
+#include <string.h>
 #define __USE_XOPEN
 #include <time.h>
 #include <glib/gi18n.h>
+#include <unistd.h>
 
 #include "gobject-utils.h"
 #include "kz-http.h"
@@ -38,6 +40,7 @@ enum {
 	PROP_0,
 	PROP_METHOD,
 	PROP_HOSTNAME,
+	PROP_PORT,
 	PROP_PATH
 };
 
@@ -57,6 +60,7 @@ struct _KzHTTPPrivate
 	KzHTTPMethodType method; /* Access Method */
 	
 	gchar *hostname;
+	guint port;
 	gchar *path;
 
 	gboolean header;
@@ -67,6 +71,8 @@ struct _KzHTTPPrivate
 
 	gboolean redirection; /* for Redirection 3xx */
 	gchar    *location;   /* Redirect-URI */
+	gchar    *content_type;
+	gchar    *content_encoding;
 
 	gchar *post_data;
 };
@@ -167,6 +173,17 @@ kz_http_class_init (KzHTTPClass *klass)
 			_("The Hostname of the URI"),
 			NULL,
 			G_PARAM_READWRITE));
+	g_object_class_install_property(
+		object_class,
+		PROP_PORT,
+		g_param_spec_uint(
+			"port",
+			_("Port"),
+			_("The Port number of the URI"),
+			0,
+			65535,
+			80,
+			G_PARAM_READWRITE));
 	g_object_class_install_property(
 		object_class,
 		PROP_PATH,
@@ -187,11 +204,15 @@ kz_http_init (KzHTTP *http)
 	http->priv->socket          = NULL;
 
 	http->priv->hostname        = NULL;
+	http->priv->port            = 80;
 	http->priv->path            = NULL;
 	
 	http->priv->header          = TRUE;
 	http->priv->chunked         = FALSE;
 	http->priv->redirection     = FALSE;
+	http->priv->location        = NULL;
+	http->priv->content_type    = NULL;
+	http->priv->content_encoding = NULL;
 
 	http->priv->chunk_size      = 0;
 
@@ -204,8 +225,6 @@ kz_http_dispose (GObject *object)
 {
 	KzHTTP *http;
 
-	g_return_if_fail(KZ_IS_HTTP(object));
-
 	http = KZ_HTTP(object);
 
 	if (http->priv->socket)
@@ -214,12 +233,21 @@ kz_http_dispose (GObject *object)
 		g_free(http->priv->hostname);
 	if (http->priv->path)
 		g_free(http->priv->path);
+	if (http->priv->location)
+		g_free(http->priv->location);
+	if (http->priv->content_type)
+		g_free(http->priv->content_type);
+	if (http->priv->content_encoding)
+		g_free(http->priv->content_encoding);
 	if (http->priv->post_data)
 		g_free(http->priv->post_data);
-	
+
 	http->priv->socket    = NULL;
 	http->priv->hostname  = NULL;
 	http->priv->path      = NULL;
+	http->priv->location  = NULL;
+	http->priv->content_type = NULL;
+	http->priv->content_encoding = NULL;
 	http->priv->post_data = NULL;
 
 	if (G_OBJECT_CLASS (parent_class)->dispose)
@@ -247,6 +275,9 @@ kz_http_set_property (GObject *object,
 		g_free(http->priv->hostname);
 		http->priv->hostname = g_value_dup_string(value);
 		break;
+	case PROP_PORT:
+		http->priv->port = g_value_get_uint(value);
+		break;
 	case PROP_PATH:
 		g_free(http->priv->path);
 		http->priv->path = g_value_dup_string(value);
@@ -274,6 +305,9 @@ kz_http_get_property (GObject *object,
 	case PROP_HOSTNAME:
 		g_value_set_string(value, http->priv->hostname);
 		break;
+	case PROP_PORT:
+		g_value_set_uint(value, http->priv->port);
+		break;
 	case PROP_PATH:
 		g_value_set_string(value, http->priv->path);
 		break;
@@ -290,12 +324,19 @@ kz_http_new (const gchar *uri)
 	KzHTTP *http;
 	GURI *guri;
 	gchar *path = NULL, *hostname = NULL;
+	guint port = 80;
 
 	guri = gnet_uri_new(uri);
 
 	if (guri)
 	{
 		hostname = guri->hostname;
+		if (guri->port)
+			port = guri->port;
+		else if (strncmp(guri->scheme, "https", 5) == 0)
+			port = 443;
+		else
+			port = 80;
 		if (guri->query)
 			path = g_strdup_printf("%s?%s",
 					       guri->path, guri->query);
@@ -307,6 +348,7 @@ kz_http_new (const gchar *uri)
 	http = g_object_new(KZ_TYPE_HTTP,
 			   "uri",      uri,
 			   "hostname", hostname,
+			   "port",     port,
 			   "path",     path,
 			   NULL);
 	
@@ -321,35 +363,10 @@ kz_http_new (const gchar *uri)
 KzHTTP *
 kz_http_post_new (const gchar *uri, const gchar *post_data)
 {
-	KzHTTP *http;
-	GURI *guri;
-	gchar *path = NULL, *hostname = NULL;
+	KzHTTP *http = kz_http_new(uri);
 
-	guri = gnet_uri_new(uri);
-
-	if (guri)
-	{
-		hostname = guri->hostname;
-		if (guri->query)
-			path = g_strdup_printf("%s?%s",
-					       guri->path, guri->query);
-		else
-			path = g_strdup(guri->path);
-	}
-
-	
-	http = g_object_new(KZ_TYPE_HTTP,
-			    "method",   KZ_HTTP_METHOD_POST,
-			    "uri",      uri,
-			    "hostname", hostname,
-			    "path",     path,
-			    NULL);
-	
+	g_object_set(G_OBJECT(http), "method", KZ_HTTP_METHOD_POST, NULL);
 	http->priv->post_data = g_strdup(post_data);
-	
-	if (guri)
-		gnet_uri_delete(guri);
-	g_free(path);
 
 	return http;
 }
@@ -391,26 +408,46 @@ kz_http_in_header(KzHTTP *http, GIOChannel *iochannel)
 			}
 		}
 	}
-	else if (strncmp(buffer->str, "Content-Length:", 15) == 0)
+	else if (g_ascii_strncasecmp(buffer->str, "Content-Length:", 15) == 0)
 	{
 		guint size = (guint)strtol(buffer->str + 15, NULL, 10);
 		g_object_set(G_OBJECT(KZ_IO(http)),
 			     "file_size", size, NULL);
 	}
-	else if (strncmp(buffer->str, "Transfer-Encoding:", 18) == 0)
+	else if (g_ascii_strncasecmp(buffer->str, "Transfer-Encoding:", 18) == 0)
 	{
-		if(strncasecmp(buffer->str + 19, "chunked", 7) == 0)  
+		const gchar *value = buffer->str + 18;
+		while (*value && g_ascii_isspace(*value))
+			++value;
+		if (g_str_has_prefix(value, "chunked"))
 			kz_http_set_chunked_mode(http);
 	}
-	else if (strncmp(buffer->str, "Location:", 9) == 0)
+	else if (g_ascii_strncasecmp(buffer->str, "Content-Type:", 13) == 0)
 	{
-		http->priv->location = g_strdup(buffer->str + 10);
+		const gchar *value = buffer->str + 13;
+		while (*value && g_ascii_isspace(*value))
+			++value;
+		http->priv->content_type = g_strchomp(g_strdup(value));
 	}
-	else if (strncmp(buffer->str, "Last-Modified:", 15) == 0)
+	else if (g_ascii_strncasecmp(buffer->str, "Content-Encoding:", 17) == 0)
+	{
+		const gchar *value = buffer->str + 17;
+		while (*value && g_ascii_isspace(*value))
+			++value;
+		http->priv->content_encoding = g_strchomp(g_strdup(value));
+	}
+	else if (g_ascii_strncasecmp(buffer->str, "Location:", 9) == 0)
+	{
+		const gchar *value = buffer->str + 9;
+		while (*value && g_ascii_isspace(*value))
+			++value;
+		http->priv->location = g_strdup(value);
+	}
+	else if (g_ascii_strncasecmp(buffer->str, "Last-Modified:", 15) == 0)
 	{
 		struct tm t;
 		strptime(buffer->str + 15,
-			 "%a, %d %b %Y %H:%M:%S %z", &t);
+			 " %a, %d %b %Y %H:%M:%S %z", &t);
 		g_object_set(G_OBJECT(KZ_IO(http)),
 			     "last_modified", (guint)mktime(&t), NULL);
 	}
@@ -424,7 +461,6 @@ kz_http_in_header(KzHTTP *http, GIOChannel *iochannel)
 	return iostatus;
 }
 
-
 static GIOStatus
 kz_http_in_chunked_body(KzHTTP *http, GIOChannel *iochannel)
 {
@@ -538,11 +574,19 @@ kz_http_read_from_io (KzIO *io, GIOChannel *iochannel)
 	else 		/* Entity-Body Section */
 		iostatus = kz_http_in_body(http, iochannel);
 	
-	if (iostatus == G_IO_STATUS_EOF && kz_http_is_redirection(http))
+	if (iostatus == G_IO_STATUS_EOF)
 	{
-		g_object_set(G_OBJECT(http),
-			     "uri", g_strchomp(http->priv->location), NULL);
-		iostatus = G_IO_STATUS_AGAIN;
+		if (kz_http_is_redirection(http))
+		{
+			g_object_set(G_OBJECT(http),
+				     "uri", g_strchomp(http->priv->location),
+				     NULL);
+			iostatus = G_IO_STATUS_AGAIN;
+		}
+		else if (http->priv->content_encoding)
+		{
+			return kz_io_decode_buffer(KZ_IO(http), http->priv->content_encoding);
+		}
 	}
 
 	return iostatus;
@@ -560,6 +604,7 @@ cb_http_connect(GTcpSocket *socket,
 	const gchar *method = methods[0];
 	gsize n;
 	gchar *URL;
+	gchar *host_header;
 
 	http = KZ_HTTP(data);
 
@@ -587,8 +632,9 @@ cb_http_connect(GTcpSocket *socket,
 	/* proxy */
 	if (kz_http_use_proxy(http))
 	{
-		URL = g_strdup_printf("http://%s%s",
+		URL = g_strdup_printf("http://%s:%u%s",
 				      http->priv->hostname,
+				      http->priv->port,
 				      http->priv->path);
 	}
 	else
@@ -601,7 +647,10 @@ cb_http_connect(GTcpSocket *socket,
 		method = methods[http->priv->method];
 	else
 		g_warning("KzHTTP: Invalid method type was specified!");
-		
+
+
+	host_header = g_strdup_printf("Host: %s:%u\r\n",
+				    http->priv->hostname, http->priv->port);
 	/* Send GET command */
 	if (http->priv->method == KZ_HTTP_METHOD_POST)
 	{
@@ -613,10 +662,12 @@ cb_http_connect(GTcpSocket *socket,
 
 		command = g_strconcat(method, " ",
 				      URL, " HTTP/1.1\r\n",
-				      "Host: ", http->priv->hostname, "\r\n",
+				      host_header,
 				      "User-Agent: Kazehakase/"VERSION "\r\n",
 				      "Content-Type: text/xml\r\n",
-				      "Content-Length: ", c_len, "\r\n\r\n", 
+				      "Content-Length: ", c_len, "\r\n",
+				      "Accept-Encoding: gzip,deflate\r\n",
+				      "Connection: close\r\n\r\n",
 				      http->priv->post_data, "\r\n", NULL);
 		g_free(c_len);
 	}
@@ -624,8 +675,9 @@ cb_http_connect(GTcpSocket *socket,
 	{
 		command = g_strconcat(method, " ",
 				      URL, " HTTP/1.1\r\n",
-				      "Host: ", http->priv->hostname, "\r\n",
+				      host_header,
 				      "User-Agent: Kazehakase/"VERSION "\r\n",
+				      "Accept-Encoding: gzip,deflate\r\n",
 				      "Connection: close\r\n\r\n", NULL);
 	}
 
@@ -636,6 +688,7 @@ cb_http_connect(GTcpSocket *socket,
 					    NULL);
 
 	g_free(command);
+	g_free(host_header);
 	g_free(URL);
 
 	if (iostatus != G_IO_STATUS_NORMAL)
@@ -691,7 +744,7 @@ kz_http_start (KzIO *io)
 	
 NO_PROXY:
 	http_host = http->priv->hostname;
-	http_port = 80;
+	http_port = http->priv->port;
 	gnet_tcp_socket_connect_async(http_host, http_port,
 				      cb_http_connect, http);
 	return;
