@@ -21,13 +21,13 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <glib/gi18n.h>
 
 #include "gobject-utils.h"
-#include "intl.h"
 #include "kz-io.h"
 #include "kz-http.h"
 #include "kz-file.h"
-#include "egg-marshalers.h"
+#include "kz-marshalers.h"
 
 #define BUFFER_SIZE 1024
 
@@ -43,7 +43,7 @@ enum {
 	PROP_URI,
 	PROP_MODE,
 	PROP_LASTMODIFIED,
-	PROP_FILESIZE,
+	PROP_FILESIZE
 };
 
 static void kz_io_class_init      (KzIOClass *klass);
@@ -85,6 +85,7 @@ struct _KzIOPrivate
 	gchar *uri;
 
 	KzIOMode mode;
+	guint source_id;
 
 	guint file_size;
 	guint loaded_size;	
@@ -124,7 +125,7 @@ static GObjectClass *parent_class = NULL;
 static gint kz_io_signals[IO_LAST_SIGNAL] = {0};
 
 static GQuark error_quark     = 0;
-static GQuark redirect_quark  = 0;
+/* static GQuark redirect_quark  = 0; */
 
 KZ_OBJECT_GET_TYPE(kz_io, "KzIO", KzIO,
 		   kz_io_class_init, kz_io_init,
@@ -203,7 +204,7 @@ kz_io_class_init (KzIOClass *klass)
 				G_SIGNAL_RUN_LAST,
 				G_STRUCT_OFFSET (KzIOClass, io_progress),
 				NULL, NULL,
-				_egg_marshal_VOID__UINT_STRING,
+				_kz_marshal_VOID__UINT_STRING,
 				G_TYPE_NONE, 2,
 				G_TYPE_UINT, G_TYPE_STRING);
 	kz_io_signals[IO_COMPLETED_SIGNAL]
@@ -226,7 +227,9 @@ kz_io_init (KzIO *io)
 	io->priv = g_new0(KzIOPrivate, 1);
 	
 	io->priv->uri         = NULL;
-	
+
+	io->priv->source_id   = 0;
+
 	io->priv->file_size   = 0;
 	io->priv->loaded_size = 0;
 
@@ -247,12 +250,13 @@ kz_io_dispose (GObject *object)
 {
 	KzIO *io;
 
-	g_return_if_fail(KZ_IS_IO(object));
-
 	io = KZ_IO(object);
 
 	if (io->iochannel)
+	{
 		g_io_channel_unref(io->iochannel);
+		io->iochannel = NULL;
+	}
 	if (io->priv->localfileio)
 		g_io_channel_unref(io->priv->localfileio);
 	if (io->priv->localfile)
@@ -266,6 +270,9 @@ kz_io_dispose (GObject *object)
 	if (io->priv->error)
 		g_error_free(io->priv->error);
 
+	if (io->priv->source_id)
+		g_source_remove(io->priv->source_id);
+	io->priv->source_id = 0;
 	io->priv->uri       = NULL;
 	io->priv->localfile = NULL;
 	io->priv->buffer    = NULL;
@@ -378,7 +385,7 @@ io_error (KzIO *io)
 				      KZ_IO_ERROR,
 				      _("Error"));
 				      
-	g_signal_emit(G_OBJECT(io),
+	g_signal_emit(io,
 		      kz_io_signals[IO_COMPLETED_SIGNAL],
 		      0,
 		      io->priv->error);
@@ -402,7 +409,7 @@ io_to_buffer (KzIO *io, gsize len, const gchar *buf)
 	}
 	io->priv->loaded_size += len;
 
-	g_signal_emit(G_OBJECT(io),
+	g_signal_emit(io,
 		      kz_io_signals[IO_PROGRESS_SIGNAL],
 		      0,
 		      len, buf);
@@ -423,7 +430,7 @@ buffer_to_io (KzIO *io, gsize len, const gchar *buf)
 					    count,
 					    &bytes_written,
 					    NULL);
-	g_signal_emit(G_OBJECT(io),
+	g_signal_emit(io,
 		      kz_io_signals[IO_PROGRESS_SIGNAL],
 		      0,
 		      len, buf);
@@ -463,7 +470,7 @@ cb_io_in(GIOChannel *iochannel, GIOCondition condition,
 		{
 			if(io->priv->localfile)
 				g_io_channel_flush(io->priv->localfileio, NULL);
-			g_signal_emit(G_OBJECT(io),
+			g_signal_emit(io,
 				      kz_io_signals[IO_COMPLETED_SIGNAL],
 				      0, NULL);
 			return FALSE;
@@ -474,7 +481,7 @@ cb_io_in(GIOChannel *iochannel, GIOCondition condition,
 		}
 	 case G_IO_STATUS_AGAIN :
 		{
-			g_signal_emit(G_OBJECT(io),
+			g_signal_emit(io,
 				      kz_io_signals[IO_COMPLETED_SIGNAL],
 				      0, NULL);
 			return FALSE;
@@ -518,7 +525,7 @@ cb_io_out(GIOChannel *iochannel, GIOCondition condition,
 	 case G_IO_STATUS_EOF:
 		{
 			g_io_channel_flush(iochannel, NULL);		
-			g_signal_emit(G_OBJECT(io),
+			g_signal_emit(io,
 				      kz_io_signals[IO_COMPLETED_SIGNAL],
 				      0, NULL);
 			return FALSE;
@@ -574,7 +581,7 @@ io_set_iochannel(KzIO *io)
 		if (iostatus != G_IO_STATUS_NORMAL)
 			io_error(io);
 
-		g_io_add_watch(io->iochannel,
+		io->priv->source_id = g_io_add_watch(io->iochannel,
 			       G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP,
 			       cb_io_in, io);
 
@@ -726,3 +733,98 @@ kz_io_stop (KzIO *io)
 	return;
 }
 
+#include <zlib.h>
+#define OUTBUFSIZ 1024
+
+static GString *
+kz_io_decode_string(GString *string)
+{
+	z_stream z;
+	gint status = Z_OK;
+	GString *outstring;
+	gchar outbuf[OUTBUFSIZ] = "";
+
+	g_return_val_if_fail(string, NULL);
+
+	z.zalloc = Z_NULL;
+	z.zfree = Z_NULL;
+	z.opaque = Z_NULL;
+	z.next_in = string->str;
+	z.avail_in = string->len;
+	z.next_out = outbuf;
+	z.avail_out = OUTBUFSIZ;
+
+	/* windowBits+32 means to enable zlib and gzip decoding
+	 * with automatic header detection. (see zlib.h) */
+	if (inflateInit2(&z, MAX_WBITS + 32) != Z_OK) 
+	{
+		g_warning("inflateInit2: %s", z.msg);
+		return NULL;
+	}
+
+	outstring = g_string_sized_new(string->len);
+
+	while (status != Z_STREAM_END)
+	{
+		status = inflate(&z, Z_SYNC_FLUSH);
+		if (status == Z_STREAM_END || status == Z_OK)
+		{
+			g_string_append_len(outstring, outbuf, OUTBUFSIZ - z.avail_out);
+			z.next_out = outbuf;
+			z.avail_out = OUTBUFSIZ;
+		}
+		else
+		{
+			g_warning("inflate: %s", z.msg);
+			g_string_free(outstring, TRUE);
+			outstring = NULL;
+			break;
+		}
+	}
+
+	/* XXX: should call inflate(&z, Z_FINISH) for checking errors? */
+
+	status = inflateEnd(&z);
+	if (status != Z_OK)
+	{
+		g_warning("inflateEnd: %s", z.msg);
+		if (outstring)
+			g_string_free(outstring, TRUE);
+		outstring = NULL;
+	}
+
+	return outstring;
+}
+
+GIOStatus
+kz_io_decode_buffer(KzIO *io, const gchar *content_encoding)
+{
+	GIOStatus status = G_IO_STATUS_EOF;
+	GString *decoded = NULL;
+
+	g_return_val_if_fail(KZ_IS_IO(io), status);
+	if (!kz_io_is_buffer_mode(io)) {
+		g_warning("kz_io_decode_buffer: cannot decode io when io is not buffer mode");
+		return status;
+	}
+	g_return_val_if_fail(content_encoding, status);
+	g_return_val_if_fail(io->priv->buffer, status);
+
+	if ((g_ascii_strcasecmp(content_encoding, "x-gzip") == 0) ||
+	    (g_ascii_strcasecmp(content_encoding, "gzip") == 0) ||
+	    (g_ascii_strcasecmp(content_encoding, "deflate") == 0))
+	{
+		decoded = kz_io_decode_string(io->priv->buffer);
+	}
+
+	if (decoded)
+	{
+		g_string_free(io->priv->buffer, TRUE);
+		io->priv->buffer = decoded;
+		/* reset buffer length */
+		io->priv->loaded_size = decoded->len;
+		io->priv->file_size = decoded->len;
+	}
+
+	return status;
+}
