@@ -194,7 +194,7 @@ font_combo_set (GtkComboBox *combo,
 		const gchar *lang, const gchar *type,
 		const gchar *font)
 {
-	GList *fonts, *node;
+	GList *fonts, *all_fonts = NULL, *node;
 	const gchar *use_font = NULL;
 	gchar *default_font = NULL;
 	GtkListStore *store;
@@ -204,7 +204,9 @@ font_combo_set (GtkComboBox *combo,
 	store = GTK_LIST_STORE(gtk_combo_box_get_model(combo));
 	gtk_list_store_clear(store);
 	
-	mozilla_prefs_get_font_list(lang, type, &fonts, &default_font);
+	mozilla_prefs_get_font_list(lang, type, 
+				    &fonts, &all_fonts,
+				    &default_font);
 
 	if (!fonts) return;
 
@@ -224,6 +226,12 @@ font_combo_set (GtkComboBox *combo,
 
 	g_list_foreach (fonts, (GFunc)g_free, NULL);
 	g_list_free (fonts);
+	
+	if (all_fonts)
+	{
+		g_list_foreach (all_fonts, (GFunc)g_free, NULL);
+		g_list_free (all_fonts);
+	}
 }
 
 
@@ -333,7 +341,6 @@ prefs_font_destroy (gpointer data)
 static void
 cb_font_lang_changed (GtkComboBox *option_menu, KzPrefsFont *prefsui)
 {
-	g_return_if_fail(GTK_IS_COMBO_BOX(option_menu));
 	font_prefs_reset(prefsui);
 }
 
@@ -523,7 +530,7 @@ prefs_font_create (void)
 
 	GTKUTIL_CREATE_MENU(option_menu, fonts_language, n_fonts_languages, title);
 
-	g_signal_connect (G_OBJECT(option_menu), "changed",
+	g_signal_connect (option_menu, "changed",
 			  G_CALLBACK (cb_font_lang_changed), prefsui);
 
 	table = gtk_table_new(3, 2, FALSE);
@@ -572,7 +579,7 @@ prefs_font_create (void)
 			 3, 4, 0, 1,
 			 GTK_FILL, 0,
 			 2, 2);
-	g_signal_connect (G_OBJECT(spin), "value-changed",
+	g_signal_connect (spin, "value-changed",
 			  G_CALLBACK(cb_var_font_spin_changed), prefsui);
 	gtk_widget_show(spin);
 
@@ -594,7 +601,7 @@ prefs_font_create (void)
 	prefsui->serif_combo = GTK_COMBO_BOX(combo);
 	gtk_widget_set_size_request(combo, 90, -1);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
-	g_signal_connect (G_OBJECT(combo), "changed",
+	g_signal_connect (combo, "changed",
 			  G_CALLBACK(cb_serif_entry_changed), prefsui);
 	gtk_table_attach(GTK_TABLE(table), combo,
 			 1, 2, 1, 2,
@@ -620,7 +627,7 @@ prefs_font_create (void)
 	prefsui->sans_serif_combo = GTK_COMBO_BOX(combo);
 	gtk_widget_set_size_request(combo, 90, -1);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
-	g_signal_connect (G_OBJECT(combo), "changed",
+	g_signal_connect (combo, "changed",
 			  G_CALLBACK(cb_sans_serif_entry_changed), prefsui);
 	gtk_table_attach(GTK_TABLE(table), combo,
 			 1, 2, 2, 3,
@@ -646,7 +653,7 @@ prefs_font_create (void)
 	prefsui->monospace_combo = GTK_COMBO_BOX(combo);
 	gtk_widget_set_size_request(combo, 90, -1);
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), combo);
-	g_signal_connect (G_OBJECT(combo), "changed",
+	g_signal_connect (combo, "changed",
 			  G_CALLBACK(cb_monospace_entry_changed), prefsui);
 	gtk_table_attach(GTK_TABLE(table), combo,
 			 1, 2, 3, 4,
@@ -670,7 +677,7 @@ prefs_font_create (void)
 			 3, 4, 3, 4,
 			 GTK_FILL, 0,
 			 2, 2);
-	g_signal_connect (G_OBJECT(spin), "value-changed",
+	g_signal_connect (spin, "value-changed",
 			  G_CALLBACK(cb_fixed_font_spin_changed), prefsui);
 	gtk_widget_show(spin);
 
@@ -688,7 +695,7 @@ prefs_font_create (void)
 	prefsui->min_size_spin = GTK_SPIN_BUTTON(spin);
 	gtk_widget_set_size_request(spin, 50, -1);
 	gtk_box_pack_end(GTK_BOX(hbox), spin, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT(spin), "value-changed",
+	g_signal_connect (spin, "value-changed",
 			  G_CALLBACK(cb_min_font_spin_changed), prefsui);
 	gtk_widget_show(spin);
 
