@@ -21,7 +21,7 @@
 #include "prefs_gesture.h"
 
 #include <ctype.h>
-#include "utils/intl.h"
+#include <glib/gi18n.h>
 #include "kazehakase.h"
 #include "kz-window.h"
 #include "kz-gesture.h"
@@ -41,6 +41,7 @@ enum
 typedef struct _KzPrefsGesture
 {
 	GtkWidget    *main_vbox;
+	GtkWidget    *use_gesture_check;
 
 	GtkWidget    *treeview;
 	GtkTreeStore *treestore;
@@ -88,7 +89,8 @@ valid_char (gint c)
 	gint valid[] = {
 		'U', 'D', 'L', 'R',
 	};
-	gint i, src;
+	gint src;
+	guint i;
 
 	src = toupper(c);
 
@@ -259,7 +261,7 @@ static void
 cb_realize (GtkWidget *widget, KzPrefsGesture *self)
 {
 	reset_gesture_items(self);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(widget),
+	g_signal_handlers_disconnect_by_func(widget,
 					     G_CALLBACK(cb_realize), self);
 }
 
@@ -271,7 +273,6 @@ cb_selection_changed (GtkTreeSelection *selection, KzPrefsGesture *self)
 	GtkTreeIter iter;
 	gchar *gesture = NULL;
 
-	g_return_if_fail(GTK_IS_TREE_SELECTION(selection));
 	g_return_if_fail(self);
 
 	if (!gtk_tree_selection_get_selected(selection, &model, &iter))
@@ -403,10 +404,10 @@ cb_button_release (GtkWidget *widget,
         {
                 gdk_pointer_ungrab (gtk_get_current_event_time ());
         }
-	g_signal_handlers_disconnect_by_func(G_OBJECT(widget),
+	g_signal_handlers_disconnect_by_func(widget,
 					     G_CALLBACK(cb_button_release),
 					     self);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(widget),
+	g_signal_handlers_disconnect_by_func(widget,
 					     G_CALLBACK(cb_motion_notify),
 					     self);
 
@@ -442,7 +443,7 @@ cb_button_press (GtkButton *button, GdkEventButton *event,
 		gtk_widget_get_pointer (GTK_WIDGET(top), &x, &y);
 
 		self->gesture = kz_gesture_new();
-		g_signal_connect(G_OBJECT(self->gesture), "stack_motion",
+		g_signal_connect(self->gesture, "stack_motion",
 				 G_CALLBACK(cb_gesture_stack_motion), self);
 		kz_gesture_start(self->gesture, 0, x, y);
 
@@ -453,9 +454,9 @@ cb_button_press (GtkButton *button, GdkEventButton *event,
 				  GDK_BUTTON_RELEASE_MASK |
 				  GDK_BUTTON_PRESS_MASK,
 				  NULL, cursor, gtk_get_current_event_time ());
-		g_signal_connect(G_OBJECT(top), "button-release-event",
+		g_signal_connect(top, "button-release-event",
 				 G_CALLBACK(cb_button_release), self);
-		g_signal_connect(G_OBJECT(top), "motion-notify-event",
+		g_signal_connect(top, "motion-notify-event",
 				 G_CALLBACK(cb_motion_notify), self);
 
 		return TRUE;
@@ -494,16 +495,16 @@ cb_insert_text (GtkEditable *editable,
 
 	if (length > 0)
 	{
-		g_signal_handlers_block_by_func(GTK_OBJECT (editable), 
+		g_signal_handlers_block_by_func(editable, 
 						G_CALLBACK(cb_insert_text),
 						self);
 		gtk_editable_insert_text(editable, result, length, position);
-		g_signal_handlers_unblock_by_func(GTK_OBJECT (editable), 
+		g_signal_handlers_unblock_by_func(editable, 
 						  G_CALLBACK(cb_insert_text),
 						  self);
 	}
 
-	g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text"); 
+	g_signal_stop_emission_by_name (editable, "insert_text"); 
 }
 
 
@@ -516,6 +517,15 @@ cb_entry_changed (GtkEntry *entry, KzPrefsGesture *self)
 }
 
 
+static void
+cb_use_gesture_toggled(GtkToggleButton *button, KzPrefsGesture *self)
+{
+	gtk_widget_set_sensitive(self->treeview,
+				 gtk_toggle_button_get_active(button));
+	gtk_widget_set_sensitive(self->edit_area,
+				 gtk_toggle_button_get_active(button));
+}
+
 typedef struct _CheckDupl
 {
 	KzPrefsGesture *self;
@@ -559,7 +569,7 @@ check_dupl_func (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter,
 				 GTK_BUTTONS_YES_NO,
 				 _("Specified gesture is duplicated with \"%s\" action. "
 				   "Replace?"), action);
-		g_signal_connect(G_OBJECT(dialog), "response",
+		g_signal_connect(dialog, "response",
 				 G_CALLBACK(cb_response), dupl);
 		gtk_dialog_run(GTK_DIALOG(dialog));
 		gtk_widget_destroy(dialog);
@@ -641,21 +651,23 @@ prefs_gesture_create (void)
 {
 	KzPrefsGesture *self = g_new0(KzPrefsGesture, 1);
 	GtkWidget *main_vbox, *swin;
-	GtkWidget *label;
+	GtkWidget *label, *check, *frame, *frame_vbox;
 	GtkTreeModel *model;
 	GtkTreeView *treeview;
 	GtkTreeSortable *sortable;
 	GtkTreeViewColumn *col;
 	GtkCellRenderer *renderer;
 	GtkWidget *table, *hbox, *vbox, *button, *arrow, *entry, *ebox;
+	gboolean use_gesture = TRUE;
 
 	self->gesture = NULL;
 
+
 	main_vbox = gtk_vbox_new(FALSE, 0);
 	self->main_vbox = main_vbox;
 	g_object_set_data_full(G_OBJECT(main_vbox), DATA_KEY,
 			       self, (GDestroyNotify) prefs_gesture_destroy);
-	g_signal_connect(G_OBJECT(main_vbox), "realize",
+	g_signal_connect(main_vbox, "realize",
 			 G_CALLBACK(cb_realize), self);
 
 	label = kz_prefs_ui_utils_create_title(_("Gesture"));
@@ -663,6 +675,26 @@ prefs_gesture_create (void)
 			   FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
+	KZ_CONF_GET("Gesture", "use_gesture", use_gesture, BOOL);
+	self->use_gesture_check = check =
+		gtk_check_button_new_with_label(_("Use gestures"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
+				     TRUE);
+	g_signal_connect(check, "toggled",
+			 G_CALLBACK(cb_use_gesture_toggled), self);
+	frame = gtk_frame_new("");
+	gtk_frame_set_label_widget(GTK_FRAME(frame), check);
+	gtk_frame_set_label_align(GTK_FRAME(frame), 0.03, 0.5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
+	gtk_box_pack_start(GTK_BOX(main_vbox), frame, TRUE, TRUE, 2);
+	gtk_widget_show(frame);
+	gtk_widget_show(check);
+
+	frame_vbox = gtk_vbox_new(FALSE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(frame_vbox), 4);
+	gtk_container_add(GTK_CONTAINER(frame), frame_vbox);
+	gtk_widget_show(frame_vbox);
+
 	/*
 	 *  Tree view
 	 */
@@ -683,7 +715,7 @@ prefs_gesture_create (void)
         gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(swin),
 					    GTK_SHADOW_IN);
 	gtk_container_set_border_width(GTK_CONTAINER(swin), 5);
-	gtk_box_pack_start(GTK_BOX(main_vbox), swin, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(frame_vbox), swin, TRUE, TRUE, 0);
 	gtk_widget_show(swin);
 
 	self->treeview = gtk_tree_view_new_with_model(model);
@@ -727,12 +759,12 @@ prefs_gesture_create (void)
 	hbox = gtk_hbox_new(FALSE, 0);
 	self->edit_area = hbox;
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-	gtk_box_pack_start(GTK_BOX(main_vbox), hbox, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(frame_vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
 	ebox = kz_input_event_box_new();
 	gtk_box_pack_start(GTK_BOX(hbox), ebox, FALSE, FALSE, 2);
-	g_signal_connect(G_OBJECT(ebox), "button-press-event",
+	g_signal_connect(ebox, "button-press-event",
 			 G_CALLBACK(cb_button_press), self);
 	gtk_widget_show(ebox);
 
@@ -750,9 +782,9 @@ prefs_gesture_create (void)
 			 1, 2, 0, 1,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND,
 			 2, 2);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_up_clicked), self);
-	g_signal_connect(G_OBJECT(button), "button-press-event",
+	g_signal_connect(button, "button-press-event",
 			 G_CALLBACK(cb_button_press), self);
 	gtk_widget_show(button);
 
@@ -766,9 +798,9 @@ prefs_gesture_create (void)
 			 0, 1, 1, 2,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND,
 			 2, 2);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_left_clicked), self);
-	g_signal_connect(G_OBJECT(button), "button-press-event",
+	g_signal_connect(button, "button-press-event",
 			 G_CALLBACK(cb_button_press), self);
 	gtk_widget_show(button);
 
@@ -783,9 +815,9 @@ prefs_gesture_create (void)
 			 1, 2, 1, 2,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND,
 			 2, 2);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_bs_clicked), self);
-	g_signal_connect(G_OBJECT(button), "button-press-event",
+	g_signal_connect(button, "button-press-event",
 			 G_CALLBACK(cb_button_press), self);
 	gtk_widget_show(button);
 
@@ -799,9 +831,9 @@ prefs_gesture_create (void)
 			 2, 3, 1, 2,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND,
 			 2, 2);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_right_clicked), self);
-	g_signal_connect(G_OBJECT(button), "button-press-event",
+	g_signal_connect(button, "button-press-event",
 			 G_CALLBACK(cb_button_press), self);
 	gtk_widget_show(button);
 
@@ -815,9 +847,9 @@ prefs_gesture_create (void)
 			 1, 2, 2, 3,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND,
 			 2, 2);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_down_clicked), self);
-	g_signal_connect(G_OBJECT(button), "button-press-event",
+	g_signal_connect(button, "button-press-event",
 			 G_CALLBACK(cb_button_press), self);
 	gtk_widget_show(button);
 
@@ -842,13 +874,13 @@ prefs_gesture_create (void)
 
 	button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 2);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_apply_button_clicked), self);
 	gtk_widget_show(button);
 
 	button = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 2);
-	g_signal_connect(G_OBJECT(button), "clicked",
+	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_clear_button_clicked), self);
 	gtk_widget_show(button);
 
@@ -856,14 +888,16 @@ prefs_gesture_create (void)
 	entry = gtk_entry_new();
 	self->entry = entry;
 	gtk_box_pack_end(GTK_BOX(vbox), entry, FALSE, FALSE, 2);
-	g_signal_connect(G_OBJECT(entry), "insert-text",
+	g_signal_connect(entry, "insert-text",
 			 G_CALLBACK(cb_insert_text), self);
-	g_signal_connect(G_OBJECT(entry), "changed",
+	g_signal_connect(entry, "changed",
 			 G_CALLBACK(cb_entry_changed), self);
 	gtk_widget_show(entry);
 
 	gtk_widget_set_sensitive(self->edit_area, FALSE);
 
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
+				     use_gesture);
 	return main_vbox;
 }
 
@@ -904,6 +938,7 @@ ERROR:
 static void
 prefs_gesture_response (GtkWidget *widget, gint response)
 {
+	gboolean use_gesture = TRUE;
 	KzPrefsGesture *self = g_object_get_data(G_OBJECT(widget), DATA_KEY);
 
 	g_return_if_fail(self);
@@ -913,6 +948,11 @@ prefs_gesture_response (GtkWidget *widget, gint response)
 	case GTK_RESPONSE_APPLY:
 		gtk_tree_model_foreach(GTK_TREE_MODEL(self->treestore),
 				       apply_config_func, self);
+
+		use_gesture = gtk_toggle_button_get_active
+				(GTK_TOGGLE_BUTTON(self->use_gesture_check));
+		KZ_CONF_SET("Gesture", "use_gesture", use_gesture, BOOL);
+		
 		break;
 	case GTK_RESPONSE_REJECT:
 		break;
